***********************************************************************************

* File: airpol04_in_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/* 
Objective: Insheet and clean 2004 air pollution data so it can be added to the complete air pollution dataset

Structure: 
1. Data Input
2. Cleaning the month variable
3. Cleaning the location variables (state, city, empty obs)
4. Measurement cleanup
5. Save other dataset formats

Note:
This raw data was received before it was systematically compiled by the CPCB. Because of this, the format is very different.
*/

***********************************************************************************

clear all
set more off
set mem 500m


*************************************************************************************
* 1. Data Input

* Changing directory
cd "${mypath}Data/Air Data/Raw Data/2004data_air"

* Insheeting all 42 2004 raw files and save them in Stata format temporarily
foreach y in "AHM2004" "ankaleshwar" "Assam04" "Bangalore 04" "BIH04" "chennaicalc" "coimbatore" "delhi final cpcb" "delhineerii" "FAR04" "Guj 2004 rajkot" "Guj 2004 surat" "Guj 2004 vadodara" "Himachal Pradesh" "hyderabad" "jaipur" "jamnagar" "KOLfinal" "korba" "ludhiana" "LUK04" "madhya pradesh" "madurai" "MEG04" "MP2004 bhop" "MP2004 indo" "MP2004 jabal" "mumbaicalc" "mysore04" "neerihyderabad" "orissa2004" "PUNE2004" "RAJ04" "solapur" "thane" "Tn2004" "UP04calc" "UTCL2004" "vapi" "vnit" "westbengal" "YAM04" {
	insheet using "`y'.csv", clear
	save "${mypath}Data/Air Data/Intermediate Data/temp`y'.dta", replace
}

* Cleaning so2_1 variable

cd "${mypath}Data/Air Data/Intermediate Data"

u "tempHimachal Pradesh.dta", clear
destring so2_1, replace
save, replace
	*This was done to make so2_1 numeric in line with the other data sets

* Cleaning so2_2 variable

u "tempvapi.dta", clear
replace so2_2="25.72" if so2_2=="25.72."
destring so2_2, replace
save, replace
	*This was done to make so2_2 numeric in line with the other data sets

* Cleaning so2_3 variable

u "tempBangalore 04.dta", clear
replace so2_3="11.7" if so2_3=="11..7"
destring so2_3, replace
save, replace
	*This was done to make so2_3 numeric in line with the other data sets

u "tempvapi.dta", clear
replace so2_3="32.55" if so2_3==".32.55"
destring so2_3, replace
save, replace
	*This was done to make so2_3 numeric in line with the other data sets

* Cleaning so2_5 variable

u "tempvapi.dta", clear
replace so2_5="25.39" if so2_5=="25..39"
destring so2_5, replace
save, replace
	*This was done to make so2_5 numeric in line with the other data sets

* Cleaning spm_1 variable

u "tempkorba", clear
destring spm_1, replace
save, replace
	*This was done to make spm_1 numeric in line with the other data sets

* Cleaning spm_2 variable

u "tempHimachal Pradesh.dta", clear
destring spm_2, replace
save, replace
	*This was done to make spm_2 numeric in line with the other data sets

u "tempkorba", clear
destring spm_2, replace
save, replace
	*This was done to make rspm_1 numeric in line with the other data sets	

* Cleaning spm_3 variable

u "tempGuj 2004 rajkot.dta", clear
destring spm_3, replace
save, replace
	*This was done to make spm_3 numeric in line with the other data sets

u "tempHimachal Pradesh.dta", clear
destring spm_3, replace
save, replace
	*This was done to make spm_3 numeric in line with the other data sets
	
* Opening the first raw dataset
u tempAHM2004.dta, clear 

* Appending all other files to this first dataset, delete temporary datasets
foreach y in "ankaleshwar" "Assam04" "Bangalore 04" "BIH04" "chennaicalc" "coimbatore" "delhi final cpcb" "delhineerii" "FAR04" "Guj 2004 rajkot" "Guj 2004 surat" "Guj 2004 vadodara" "Himachal Pradesh" "hyderabad" "jaipur" "jamnagar" "KOLfinal" "korba" "ludhiana" "LUK04" "madhya pradesh" "madurai" "MEG04" "MP2004 bhop" "MP2004 indo" "MP2004 jabal" "mumbaicalc" "mysore04" "neerihyderabad" "orissa2004" "PUNE2004" "RAJ04" "solapur" "thane" "Tn2004" "UP04calc" "UTCL2004" "vapi" "vnit" "westbengal" "YAM04" {
	keep stncode type city state agency date so2_1 so2_2 so2_3 so2_4 so2_5 so2_6 nox_1 nox_2 nox_3 nox_4 nox_5 nox_6 spm_1 spm_2 spm_3
	append using "temp`y'.dta"
	erase "temp`y'.dta"
}

* Erasing the last temp dataset
erase tempAHM2004.dta

* Save
save airpol2004.dta, replace

******************************************************************************************
* 2. Cleaning (the MONTH variable)

* Keeping only identifying information and raw monitor readings
keep stncode type city state agency date so2_1 so2_2 so2_3 so2_4 so2_5 so2_6 nox_1 nox_2 nox_3 nox_4 nox_5 nox_6 spm_1 spm_2 spm_3

* Creating a variable for the length of the date string to help identify incorrectly formatted dates.
* This is important because the month will be cleaned from this date variable below.
g length = length(date)
ta length

* Want all dates to be consistent. Making sure all date strings are 8 characters in length.
replace date = "06/03/04" if date == "06/03/204"
replace date = "04/28/04" if date == "04/28/204"
replace date = "08/20/04" if date == "08/20/204"
replace date = "04/06/04" if date == "04/0/62004"
replace date = "05/07/04" if date == "05/0/72004"
replace date = "03/05/04" if date == "03/0/52004"
replace date = "12/23/04" if date == "23/12/2004"
replace date = "19.02.04" if date == "19.204"
replace date = "01.06.04" if date == "1.6.04"
replace date = "03.06.04" if date == "3.6.04"
replace date = "05.06.04" if date == "5.6.04"
replace date = "08.06.04" if date == "8.6.04"
replace date = "20.02.04" if date == "20.2.4"
replace date = "24.05.04" if date == "243.05.04"
replace date = "02.06.04" if date == "2.6.04"
replace date = "04.06.04" if date == "4.6.04"
replace date = "07.06.04" if date == "7.6.04"
replace date = "09.06.04" if date == "9.6.04"
replace date = "12.11.04" if date == "12.1104"
replace date = "21.04.04" if date == "21.04.4"
replace date = "06/18/04" if date == "18//06/04"

* These dates do not match up with their surroundings, that is they buck the chronological order found in all the raw files. Changing them to reflect their surroundings.
replace date = "6/30/04" if city == "JAL" & date == "4/30/04"
replace date = "5/30/04" if city == "HYD" & date == "11/04/04"

* This code cuts the date string in an attempt to leave only the month portion.
g month = substr(date, 1, 2)

* However, there are inconsistencies in the date formatting of the raw files. Specifically, some dates have day before month.
* For these, cutting in a different place to get the month
replace month = substr(date, 4, 2) if _n >= 79 & _n <= 82
replace month = substr(date, 4, 2) if _n == 186 | _n == 187 
replace month = substr(date, 4, 2) if _n >= 194 & _n <= 197
replace month = substr(date, 4, 2) if _n >= 294 & _n <= 297
replace month = substr(date, 4, 2) if _n >= 302 & _n <= 305
replace month = substr(date, 4, 2) if _n == 310 | _n == 311
replace month = substr(date, 4, 2) if _n == 2068
replace month = substr(date, 4, 2) if _n == 3271 | _n == 3272
replace month = substr(date, 4, 2) if _n == 3375 | _n == 3376
replace month = substr(date, 4, 2) if _n >= 3479 & _n <= 3483
replace month = substr(date, 4, 2) if _n == 3487 | _n == 3488
replace month = substr(date, 4, 2) if _n >= 678 & _n <= 1038
replace month = substr(date, 4, 2) if _n >= 3497 & _n <= 4665
replace month = substr(date, 4, 2) if _n >= 10485 & _n <= 10792

* These are leftover non-numeric dates. Examining their full dates and coding them accordingly.
replace month = "6" if month == "18" | month == "6."
replace month = "2" if month == "2."
replace month = "5" if month == "5." | month == "5/"

* This date reads "12/13/04", but it is surrounded by November readings, so changing it to 11/13/04 and recoding month as "11"
replace month = "11" if month == "13"

* Destring the month variable
destring month, replace

* Generate variable that signals when a month value doesn't match up with either the next obs or the previous obs
g q = 0
replace q = 1 if month == month[_n-1] | month == month[_n+1]

* Going through this list of 23 flagged observations and changing whatever doesn't make sense. -stncode date- is not necessarily unique, but checking to make sure in each case
replace month = 8 if stncode == 77 & date == "07/07/04"
replace month = 7 if stncode == 78 & date == "05/03/04"
replace month = 11 if stncode == 55 & date == "01/18/04"
replace month = 5 if stncode == 345 & date == "10/30/04"
replace month = 11 if stncode == 47 & date == "12/11/04"
replace month = 11 if stncode == 50 & date == "12/11/04"
replace month = 12 if stncode == 118 & date == "18.11.04"
replace month = 7 if stncode == 271 & date == "27.04.07"
* one observation has a unique stncode. I am dropping it.
drop if stncode == 356
replace month = 11 if stncode == 393 & date == "5/30/04"
replace month = 11 if stncode == 394 & date == "5/30/04"
replace month = 5 if stncode == 163 & date == "07/05/04"
replace month = 6 if stncode == 176 & date == "04/30/04"
replace month = 11 if stncode == 151 & date == "5/30/04"
replace month = 11 if stncode == 152 & date == "5/30/04"

* Drop temporary variables
drop q length

* Moving the month variable so it is next to the date variable
order stncode type city state agency date month

*************************************************************************
* 3. Location cleanup

* Whenever a stncode is blank, the rest of the observation is also blank. Drop these.
drop if stncode >= .

* Clean state names
ta state
replace state = "Andhra Pradesh" if state == "AND" | state == "ANP"
replace state = "Assam" if state == "ASM"
replace state = "Bihar" if state == "BHI" | state == "BIH" | state == "JHA" | state == "JKH"
replace state = "Chandigarh" if state == "CND"
replace state = "Delhi" if state == "DEL"
replace state = "Gujarat" if state == "GJT" | state == "GUJ"
replace state = "Goa" if state == "GOA"
replace state = "Haryana" if state == "HAR" | state == "HRY"
replace state = "Himachal Pradesh" if state == "HIP"
replace state = "Karnataka" if state == "KAR"
replace state = "Kerala" if state == "KER"
replace state = "Maharashtra" if state == "MAH"
replace state = "Meghalaya" if state == "MEG"
replace state = "Madhya Pradesh" if state == "MPH" | state == "CHG" | state == "CGH"
replace state = "Nagaland" if state == "NAG"
replace state = "Orissa" if state == "ORI"
replace state = "Punjab" if state == "PJB"
replace state = "Pondicherry" if state == "PND" | state == "PON"
replace state = "Rajasthan" if state == "RAJ"
replace state = "Tamil Nadu" if state == "TN" | state == "TND"
replace state = "Uttar Pradesh" if state == "UTP"
replace state = "West Bengal" if state == "WB" | state == "WBL"


* Clean city names - the following is taken from air_pollution_electronic.do. Many city abbreviations remain unchanged, so I will fix those myself.
replace city = "Agra" if city == "AGR"
replace city = "Ahmedabad" if city == "AMD"
replace city = "Alwar" if city == "ALW"
replace city = "Angul" if city == "ANG"
replace city = "ANK" if city == "Ankaleshwar"
replace city = "Ankaleshwar" if city == "ANK"
replace city = "Anpara" if city == "ANP"
replace city = "Bangalore" if city == "BAG"
replace city = "Baroda" if city == "Vadodara"
replace city = "Baroda" if city == "VAD" | city == "BAR" 
replace city = "Bhilai" if city == "BHI"
replace city = "Bhopal" if city == "BHO" | city == "BPL"
replace city = "Bhubaneshwar" if city == "BHU"
replace city = "Mumbai" if city == "MUM" | city == "BOM" | city == "Bombay"
replace city = "Bongaigaon" if city == "BON"
replace city = "Calcutta" if city == "Kolkatta"
replace city = "Calcutta" if city == "Kolkata"
replace city = "Calcutta" if city == "CAL" | city == "KOL"
replace city = "Chandigarh" if city == "CND"
replace city = "Chandrapur" if city == "CHR"
replace city = "Chittorgarh" if city == "CTR"
replace city = "Cochin" if city == "COH"
replace city = "Coimbatore" if city == "COM" | city == "CBE"
replace city = "Chingavanam" if city == "CVM"
replace city = "Damtal" if city == "DAM"
replace city = "Dehradoon" if city == "DEH"
replace city = "Delhi" if city == "DEL"
replace city = "Dhanbad" if city == "DHN"
replace city = "Dharuhera" if city == "DRU"
replace city = "Dimapur" if city == "DMP"
replace city = "Dombivali" if city == "DBL"
replace city = "Faridabad" if city == "FRI"
replace city = "Gajroula" if city == "GAJ"
replace city = "Guwahati" if city == "GVT"
replace city = "Haldia" if city == "HAL"
replace city = "Howrah" if city == "HOW"
replace city = "Hyderabad" if city == "HYD"
replace city = "Indore" if city == "IND"
replace city = "Jabalpur" if city == "JAB" | city == "JBL"
replace city = "Jaipur" if city == "JAP"
replace city = "Jalandhar" if city == "JAL"
replace city = "Jamnagar" if city == "JAM"
replace city = "Jamshedpur" if city == "JSR" | city == "JSD"
replace city = "Jaykaypur" if city == "JAY"
replace city = "Jharia" if city == "JHA"
replace city = "Jodhpur" if city == "JDH"
replace city = "Kanpur" if city == "KNP"
replace city = "Korba" if city == "KOR"
replace city = "Kota" if city == "KOT"
replace city = "Kottayam" if city == "KOM"
replace city = "Kozhikode" if city == "KOZ"
replace city = "Lucknow" if city == "LUK"
replace city = "Ludhiana" if city == "LUD"
replace city = "Mysore" if city == "MYS"
replace city = "Nagda" if city == "NAG"
replace city = "Nagpur" if city == "NGP"
replace city = "Nashik" if city == "NSK"
replace city = "Noida" if city == "NOI"
replace city = "Paonta Sahib" if city == "PSB"
replace city = "Parwanoo" if city == "PAR"
replace city = "Pondicherry" if city == "PON" & state == "Pondicherry"
replace city = "Pondicherry" if city == "PND"
replace city = "Pune" if city == "PUN"
replace city = "Rourkela" if city == "ROU"
replace city = "Salem" if city == "SAL"
replace city = "Salem" if city == "SLM"
replace city = "Satna" if city == "SAT"
replace city = "Shillong" if city == "SHL"
replace city = "Shillong" if city == "SHI" & state == "Meghalaya"
replace city = "Sindri" if city == "SIN"
replace city = "Surat" if city == "SUR"
replace city = "Talcher" if city == "TAL"
replace city = "Trivendrum" if city == "TRV"
replace city = "Tuticorin" if city == "TUT" | city == "Tuticorin"
replace city = "Vasco" if city == "VAS"
replace city = "Visakhapatnam" if city == "VPN"
replace city = "Patna" if city == "PAT"
replace city = "Rajkot" if city == "RJT"
replace city = "Vapi" if city == "VAP"
replace city = "Yamunanagar" if city == "YMN"
replace city = "Palakkad" if city == "PAD"
replace city = "Solapur" if city == "SPL"
replace city = "Thane" if city == "THN"
replace city = "Gobindgarh" if city == "GBD"
replace city = "Raipur" if city == "RAI"
replace city = "Udaipur" if city == "UDP"
replace city = "Rajkot" if city == "RJT"
replace city = "Ghaziabad" if city == "GZB"
replace city = "Varanasi" if city == "VNS"
replace city = "Panjim" if city == "PJM"
replace city = "Bharuch" if city == "BRC"
replace city = "Jammu" if city == "JMU"

* Supplementary code starts here
replace city = "Asansol" if city == "ASN"
replace city = "Bangalore" if city == "BAN"
replace city = "Chandrapur" if city == "CHD"
replace city = "Chennai" if city == "CHE"
replace city = "Dharwad" if city == "DHW"
replace city = "Dimapur" if city == "DIM"
replace city = "Durgapur" if city == "DRG" | city == "DUR"
replace city = "Faridabad" if city == "FAR"
replace city = "Firozabad" if city == "FRZ"
replace city = "Ghaziabad" if city == "GHA"
replace city = "Hubballi" if city == "HUB"
replace city = "Jamnagar" if city == "JAN"
replace city = "Jodhpur" if city == "JOD"
replace city = "Cochin" if city == "KOC"
replace city = "Lucknow" if city == "LUC"
replace city = "Madurai" if city == "MAD"
replace city = "Mormugao" if city == "MOM"
replace city = "Palakkad" if city == "PAL"
replace city = "Ponda" if city == "POD"
replace city = "Pune" if city == "PUE"
replace city = "Ranchi" if city == "RAN"
replace city = "Rayagada" if city == "RAY"
replace city = "Shimla" if city == "SHI"
replace city = "Surat" if city == "SRT"
replace city = "Tirupati" if city == "TIR"
replace city = "Trivendrum" if city == "TRI"
replace city = "Varanasi" if city == "VAR"
replace city = "Visakhapatnam" if city == "VSK"
replace city = "Deoband" if city == "DAB"
replace city = "Jamshedpur" if city == "JHR"
replace city = "Kottayam" if city == "KOY"

* Hubballi and Dharwad are one city id in 2005 and 2006. I am renaming the 2004 obs to match this convention
replace city = "Hubli-Dharwad" if city == "Hubballi" | city == "Dharwad"

* Do not need agency or date anymore
drop agency date

******************************************************************
* 4. Measurement cleanup

* Change -1 to missing
foreach var of varlist so2_1 so2_2 so2_3 so2_4 so2_5 so2_6 nox_1 nox_2 nox_3 nox_4 nox_5 nox_6 spm_1 spm_2 spm_3 {
	recode `var' -1 = . 
}

* Make sure there are no other negative values	
foreach var of varlist so2_1 so2_2 so2_3 so2_4 so2_5 so2_6 nox_1 nox_2 nox_3 nox_4 nox_5 nox_6 spm_1 spm_2 spm_3 {
	assert `var' >= 0 
}

* Create variables for later tabulation of measurements per monitor
egen temp_spm = rownonmiss(spm_1 spm_2 spm_3)
egen temp_so2 = rownonmiss(so2_1 so2_2 so2_3 so2_4 so2_5 so2_6)
egen temp_no2 = rownonmiss(nox_1 nox_2 nox_3 nox_4 nox_5 nox_6)
g spm_n = 1 if temp_spm > 0
g so2_n = 1 if temp_so2 > 0
g no2_n = 1 if temp_no2 > 0
drop temp*

* Drop observations if they have no data 
drop if spm_n >= . & so2_n >= . & no2_n >= .

* Create mean, max, min
egen spm_mean = rowmean(spm_1 spm_2 spm_3)
egen so2_mean = rowmean(so2_1 so2_2 so2_3 so2_4 so2_5 so2_6)
egen no2_mean = rowmean(nox_1 nox_2 nox_3 nox_4 nox_5 nox_6)
egen spm_max = rowmax(spm_1 spm_2 spm_3)
egen so2_max = rowmax(so2_1 so2_2 so2_3 so2_4 so2_5 so2_6)
egen no2_max = rowmax(nox_1 nox_2 nox_3 nox_4 nox_5 nox_6)
egen spm_min = rowmin(spm_1 spm_2 spm_3)
egen so2_min = rowmin(so2_1 so2_2 so2_3 so2_4 so2_5 so2_6)
egen no2_min = rowmin(nox_1 nox_2 nox_3 nox_4 nox_5 nox_6)

* Drop individual readings (only need one per measurement period [day])
drop so2_1 so2_2 so2_3 so2_4 so2_5 so2_6 nox_1 nox_2 nox_3 nox_4 nox_5 nox_6 spm_1 spm_2 spm_3

* Collapse into monitor-months
collapse (mean) spm_mean so2_mean no2_mean (max) so2_max no2_max spm_max (min) so2_min no2_min spm_min (sum) spm_n so2_n no2_n, by(stncode type state city month)

* -Type- is sometimes coded as Critical and sometimes as Sensitive. These are the same; I am recoding Critical as Sensitive.
replace type = "S" if type == "C"

* Some monitors change type. Following Joe Shapiro's code in air_pollution_electronic.do, I am keeping type consistent, and thus taking the mode of type in all cases where the type changes.
egen temp = mode(type), by(stncode)
replace type = temp
drop temp

* Extrapolating -type- into three different dummy variables
g resid = type == "R" if type ~= ""
g indus = type == "I" if type ~= ""
g sensit = type == "S" if type ~= ""

* There are two missing state-city observations. The stationcode of each observation is coded as Hyderabad in all other observations.
replace state = "Andhra Pradesh" if stncode == 151 | stncode == 152
replace city = "Hyderabad" if stncode == 151 | stncode == 152

* Label variables
la var stncode "original CPCB data station code"
la var type "Type of Area (Residential, Industrial, Sensitive)"
la var city "city full name"
la var state "state full name"
la var month "Month in which measurement was taken"
la var so2_max "Maximum observed SO2 in the given time period"
la var so2_min "Minimum observed SO2 in the given time period"
la var so2_mean "Average across SO2 observations in the given time period"
la var so2_n "number of days of SO2 observations in the given time period"
la var no2_max "Maximum observed NO2 in the given time period"
la var no2_min "Minimum observed NO2 in the given time period"
la var no2_mean "Average across NO2 observations in the given time period"
la var no2_n "number of days of NO2 observations in the given time period"
la var spm_max "Maximum observed SPM in the given time period"
la var spm_min "Minimum observed SPM in the given time period"
la var spm_mean "Average across SPM observations in the given time period"
la var spm_n "number of days of SPM observations in the given time period"

* Rename each variable to start with e_, which denotes that it is a reading taken from electronic sources (as opposed to taken from a book).
foreach var of varlist spm_mean-no2_n  {
	ren `var' e_`var'
}

* (From air_pollution_electronic.do) Count n for industrial/sensitive so we know the share of each city which is of each type. Count it for residential to achieve that goal and also to calculate residential pollution across pollution measurements.
g e_spm_n_r = e_spm_n if resid == 1
g e_no2_n_r = e_no2_n if resid == 1
g e_so2_n_r = e_so2_n if resid == 1
g e_spm_n_i = e_spm_n if indus == 1
g e_no2_n_i = e_no2_n if indus == 1
g e_so2_n_i = e_so2_n if indus == 1
g e_spm_n_s = e_spm_n if sensit == 1
g e_no2_n_s = e_no2_n if sensit == 1
g e_so2_n_s = e_so2_n if sensit == 1

g e_spm_mean_r = e_spm_mean if resid == 1
g e_no2_mean_r = e_no2_mean if resid == 1
g e_so2_mean_r = e_so2_mean if resid == 1
g e_spm_min_r = e_spm_min if resid == 1
g e_no2_min_r = e_no2_min if resid == 1
g e_so2_min_r = e_so2_min if resid == 1
g e_spm_max_r = e_spm_max if resid == 1
g e_no2_max_r = e_no2_max if resid == 1
g e_so2_max_r = e_so2_max if resid == 1

* Need to define what year these data are from
* 16 observations in the 2004 files from 2004data_air were listed as from other years. 
* We recoded these as 2004 since they were from the 2004 file. The results are robust to dropping them. 
g year = 2004

*************************************************************************************
* Order variables
order stncode type state city year month

* Sort	
so state city stncode year

* Save as monitor-month dataset (this can only be used in conjunction with book data; electronic data from before 2004 is not disaggregated to months, only years.
save e_ap04_mm.dta, replace
***************************************************************************************
* 5. Save and erase other datasets

collapse (mean) *mean* (max) *max* (min) *min* resid sensit indus (sum) e_spm_n-e_no2_n e_spm_n_r-e_so2_n_s, by(state city stncode type year)

* Define the 1994 National Ambient Air Quality Standards
g spm_naaqs_r = 140 if resid == 1
g spm_naaqs_i = 360 if indus == 1
g no2_naaqs_r = 60 if resid == 1
g no2_naaqs_i = 80 if indus == 1
g so2_naaqs_r = 60 if resid == 1
g so2_naaqs_i = 80 if indus == 1

* Save as monitor-year dataset
save e_ap04_my.dta, replace

* Erase obsolete/earlier datasets
erase airpol2004.dta
