***********************************************************************************

* File: clean_districts_1961_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This file cleans district names from the air temp/precip dataset that Olivier Deschenes sent (temp_prcp.dta)
*/

***********************************************************************************

/* These changes are run-of-the-mill, reconciling 1961 borders with the borders of the dataset (~1981) */
replace district = "Bhojpur + Rohtas" if district == "Shahabad" & state == "Bihar"
replace district = "Santhal Pargana" if district == "Santhal Parganas" & state == "Bihar"
replace state = "Goa" if district == "Goa, Daman & Diu" & state == "Goa, Daman And Diu" & dist61_id == 2401
replace state = "Daman & Diu" if district == "Goa, Daman & Diu" & state == "Goa, Daman And Diu" & (dist61_id == 2402 | dist61_id == 2403)
replace district = "Bharuch" if district == "Broach" & state == "Gujarat"
replace district = "Panch Mahals" if district == "Panchmahals" & state == "Gujarat"
replace district = "Vadodara (Baroda)" if district == "Baroda" & state == "Gujarat"
replace state = "Haryana" if district == "Ambala" & state == "Punjab"
replace state = "Haryana" if district == "Hissar" & state == "Punjab"
replace district = "Hisar + Sirsa" if district == "Hissar" & state == "Haryana"
replace state = "Haryana" if district == "Rohtak + Sonipat" & state == "Punjab"
replace district = "Chamba" if district == "Champa" & state == "Himachal Pradesh"
replace district = "Kheda" if district == "Kaira" & state == "Gujarat"
replace district = "Kangra + Hamirpur + Una + Ku" if district == "Kangara" & state == "Punjab"
replace state = "Himachal Pradesh" if district == "Kangra + Hamirpur + Una + Ku" & state == "Punjab"
replace state = "Himachal Pradesh" if district == "Shimla + Solan" & state == "Punjab"
replace state = "Karnataka" if state == "Mysore"
replace state = "Tamil Nadu" if state == "Madras"

/* Here I'm duplicating certain observations because I need one set for, e.g. Ahmadabad, and one set for Gandhinagar which was carved out of Ahmadabad after 1961 */
foreach k in "Kozhikode" "Cannanore" "Patiala" "Ahmadabad" {
	expand 2 if district == "`k'"
}

/* Goa, Daman & Diu is hard because somehow the district names aren't the same in both air and water datasets. I am duplicating the Goa obs and making one set each for air and water correspondence */
expand 2 if state == "Goa"
bys state district year month airtemp totprcp: g n = _n // this step is key, it differentiates duplicates so I can pick one set based on the variable -n-
replace district = "Goa" if district == "Goa, Daman & Diu" & state == "Goa" & n == 2

/* Here I'm renaming the duplicate sets of data to correspond to newer districts */
foreach k in "Kozhikode" "Cannanore" {
	replace district = "Wayanad" if district == "`k'" & n == 2
}

replace district = "Rupnagar (Ropar)" if district == "Patiala" & n == 2
replace district = "Gandhinagar" if district == "Ahmadabad" & n == 2

/* Back to run of the mill changes */
replace district = "Dhule" if district == "Dhulia" & state == "Maharashtra"
replace district = "Pune (Poona)" if district == "Poona" & state == "Maharashtra"
replace district = "Raigarh (Kolaba)" if district == "Kolaba" & state == "Maharashtra"
replace district = "Salapur (Sholapur)" if district == "Sholapur" & state == "Maharashtra"
replace district = "Balangir" if district == "Bolangir" & state == "Orissa"
replace district = "Kendujhar" if district == "Keonjhar" & state == "Orissa"
replace district = "Jalandhar (Jullundur)" if district == "Jullundur" & state == "Punjab"
replace district = "Barddhaman (Burdwan)" if district == "Burdwan" & state == "West Bengal"
replace district = "Medinipur" if district == "Midnapore" & state == "West Bengal"
replace district = "Puruliya" if district == "Purulia" & state == "West Bengal"
replace district = "Twenty Four Parganas" if district == "Twety Four Parganas" & state == "West Bengal"
replace district = "Belgaum" if district == "Belgaon" & state == "Karnataka"
replace district = "Kodagu (Coorg)" if district == "Coorg" & state == "Karnataka"
replace district = "Tiruchchirappalli" if district == "Tiruchirapalli" & state == "Tamil Nadu"
replace state = "Dadra & Nagar Haveli" if state == "Dadra And Nagar Haveli"
replace district = "Dadra & Nagar Haveli" if district == "Dadra And Nagar Haveli" & state == "Dadra & Nagar Haveli"
replace state = "Haryana" if district == "Gurgaon + Faridabad" & state == "Punjab"
replace state = "Haryana" if district == "Mahendragarh" & state == "Punjab"
replace district = "Sirmaur" if district == "Sirmur" & state == "Himachal Pradesh"
replace state = "Jammu & Kashmir" if state == "Jammu And Kashmir"
replace district = "Dakshin Kannad (South Kanara" if district == "South Kanara" & state == "Karnataka"
replace district = "Dehradun" if district == "Dehra Dun" & state == "Uttar Pradesh"
