***********************************************************************************

* File: controls_merge_01102014.do
* Date: August 6, 2012
* Contact: Jon Petkun - petkunj@nber.org

/*
Objective: 
 This program's objective is to merge the final India pollution/mortality data
	with additional additional state*year controls, including newspaper references to 
	pollution and corruption, industry compliance, and corruption index scores. These 
	data were prepared in newspaper_prep.do, industry_compliance_prep.do, and
	corruption_prep.do, respectively.

Structure:
0. Set-up
1. Merge together the new data
2. Merge existing data w/ new data; generate new variables
3. Clean-up

Note: 

*/

***********************************************************************************

***********************************************************************************
* Section 0: Set-up
***********************************************************************************
cap log close 

clear all
set more off
set mem 500m
version 11.0

log using "${mypath}Log/controls_merge_01102014.txt", replace t

***********************************************************************************
* Section 1: Merge together the new data
***********************************************************************************

use "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta"
merge 1:1 state year using "${mypath}Data/Controls/Industry Compliance/Intermediate Data/industry_compliance_stateyear.dta", gen(indust_merge)
merge m:1 state using "${mypath}Data/Controls/Corruption/Intermediate Data/corruption_bystate.dta", gen(corrupt_merge)
merge 1:1 state year using "${mypath}Data/Controls/Income/Raw Data/inc_state.dta", gen(inc_merge)
drop if inc_merge == 2
drop *merge

* Apply SPCB acronyms to all years
bys state: egen modal_acronym = mode(acronym), maxmode
replace acronym = modal_acronym
drop modal_acronym

* Save the new controls data
save "${mypath}Data/Air Data/Intermediate Data/new_data.dta", replace

***********************************************************************************
* Section 2: Merge existing data w/ new data; generate new variables
***********************************************************************************
* Section 2a: Merge air pollution w/ new data *
use "${mypath}Data/Air Data/Final Data/combined.dta"
merge m:1 state year using "${mypath}Data/Air Data/Intermediate Data/new_data.dta", nogen

* Drop 1986 and the state of tripura, which don't exist in the pollution/policy data
drop if year == 1986
drop if state == "Tripura"

* Generate constants for each observation preceding the first year of data.
*	The constants are assigned the value of the earliest year of data.
foreach var of varlist closed_industries-compliance_top25 {
	gen `var'_1995 = `var' if year == 1995
	bys state (`var'_1995): replace `var' = `var'_1995[1] if `var' == . & year < 1995
	drop `var'_1995
}
* Apply SPCB acronyms to all years
bys state: egen modal_acronym = mode(acronym), maxmode
replace acronym = modal_acronym
drop modal_acronym

* Save merged air data
save "${mypath}Data/Air Data/Final Data/combined.dta", replace

* Section 2b: Merge water pollution w/ new data *
*use "${mypath}Infant Mortality/IM City/Datasets/im_water.dta", clear
use "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta"
merge m:1 state year using "${mypath}Data/Air Data/Intermediate Data/new_data.dta", nogen

* Generate constants for each observation preceding the first year of data.
*	The constants are assigned the value of the earliest year of data.
foreach var of varlist closed_industries-compliance_top25 {
	gen `var'_1995 = `var' if year == 1995
	bys state (`var'_1995): replace `var' = `var'_1995[1] if `var' == . & year < 1995
	drop `var'_1995
}
* Apply SPCB acronyms to all years
bys state: egen modal_acronym = mode(acronym), maxmode
replace acronym = modal_acronym
drop modal_acronym

* Save merged water data
save "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", replace


***********************************************************************************
* Section 3: Clean-up
***********************************************************************************
log close
