***********************************************************************************

* File: corruption_prep_01102014.do
* Date: August 3, 2012
* Contact: Jon Petkun - petkunj@nber.org

/*
Objective: 
This program's objective is to prepare state corruption scores from Transparency
	International, and to merge those new data with the existing India Pollution datasets.

Structure:
0. Set-up
1. Insheet and perform basic cleaning on raw corruption data
2. Summary tables and graphs
3. Clean-up

Note: 

*/

***********************************************************************************

***********************************************************************************
* Section 0: Set-up
***********************************************************************************
cap log close 

clear all
set more off
set mem 500m
version 11.0

log using "${mypath}Log/corruption_prep_01102014.txt", replace t

***********************************************************************************
* Section 1: Insheet and perform basic cleaning on raw corruption data
***********************************************************************************

* Insheet corruption scores
insheet using "${mypath}Data/Controls/Corruption/Raw Data/CorruptionRank_India.csv", clear names

***********************************************************************************
* Section 2: Basic cleaning and reformatting
***********************************************************************************
* Rename corruption variables
rename state_corruption2005_score corruption_score05 
rename state_corruption2005_rank corruption_rank05
rename state_corruption2007_string corruption_level07

* Generate add'l variables
gen top5_corrupt = corruption_rank05 > 15
label var top5_corrupt "one of the five most corrupt states, as per Transparency Int'l 2005"
gen bottom5_corrupt = corruption_rank05 < 6
label var bottom5_corrupt "one of the five least corrupt states, as per Transparency Int'l 2005"

* Save full dataset (just in case we want to use it later)
save "${mypath}Data/Controls/Corruption/Intermediate Data/corruption_bystate_full.dta", replace

* Drop states that are not present in the existing air/water data
drop if state == "Arunachal Pradesh" | state == "Chhattisgarh" | state == "Jharkhand" | ///
	state == "Sikkim" | state == "Uttarakhand"

* Save state-level corruption dataset
save "${mypath}Data/Controls/Corruption/Intermediate Data/corruption_bystate.dta", replace
	
***********************************************************************************
* Section 3: Summary tables and graphs
***********************************************************************************

***********************************************************************************
* Section 4: Clean-up
***********************************************************************************

log close
