***********************************************************************************

* File: im_addpolicy_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: The objective of this program is to merge relevant air and water policy variables with the infant
	 mortality data.

Structure:
1. Air
2. Water
3. Prepare air/water data for merging; Merge IM with air and water data

Notes:
1. This file is necessary because air policy variables have only been added previously to cities in air data, and water policy variables have 
	only been added previously to cities in water data. Thus cities in the IM dataset, when merged with air and water datasets, would otherwise 
	only get air policies if they happen to be in the air dataset, and correspondingly so for water.
2. City spelling is an issue. The cities listed in the for-loops below are taken from (air) airpolicydictionary.doc file and (water) 
	waterpollutionusersguide.doc file. I change spellings between these doc files and this do-file by tabbing the -city- variable in the IM dataset.
*/

***********************************************************************************

clear all
set more off
set mem 500m

cd "${mypath}"
u "Data/Infant Mortality/IM City/Intermediate Data/cityIMdata.dta", clear

****************
* AIR 

* Catalytic Converters
g catconverter = 0
g catyear = .
replace catconverter = 1 if year>=1995 & (city=="Delhi" | city=="Mumbai" | city=="Chennai" | city=="Kolkata")
replace catyear = 1995 if (city=="Delhi" | city=="Mumbai" | city=="Chennai" | city=="Kolkata")
foreach p in Hyderabad Visakhapatnam Itanagar Dispur Patna Jamshedpur Ranchi Chandigarh Panaji Gandhinagar Surat Vadodara Gurgaon Hisar Ambala Shimla Jammu Srinagar Bangalore Thiruvananthapuram Kochi Kozhikode Bhopal Indore Pune Nagpur Imphal Shilong Aizawl Kohima Bhubaneshwar Amritsar Ludhiana Jalandhar Jaipur Jodhpur Udaipur Gangtok Agartala Lucknow Allahabad Kanpur Silvassa `Port Blair' Pondicherry {	
	replace catconverter = 1 if year>=1998 & city=="`p'"
	replace catyear = 1998 if city=="`p'"
}
replace catconverter = 1 if year>=1998 & city=="Pune Corp"
replace catyear = 1998 if city=="Pune Corp"

* Supreme Court Action Plans
g actionplan_sc = 0
g scapyear = .
replace actionplan_sc = 1 if year>=1997 & city=="Delhi"
replace scapyear = 1997 if city=="Delhi"

foreach q in Agra Jodhpur Jharia Pune Varanasi Faridabad Patna Lucknow Kanpur Kolkata Ahmedabad {
	replace actionplan_sc = 1 if year>=2003 & city=="`q'"
	replace scapyear = 2003 if city=="`q'"
}

foreach r in Solapur Bangalore Chennai Hyderabad Mumbai {
	replace actionplan_sc = 1 if year>=2004 & city=="`r'"
	replace scapyear = 2004 if city=="`r'"
}

egen yearone = rowmin(catyear scapyear)

***************
* WATER

* NRCP
g action = 0
/* GAP-1 */
g gap1 = .
foreach s in Bhagalpur Chapra Munger Patna Allahabad Fatehbad Fatehgarh Kanpur `Mirzapur-Cum-Vindhyachal' Varanasi Hardwar Rishikesh Baharampur Bally Baranagar Bhatpara Kolkata Chandanagar Howrah `Hugli-Chinaurah' Kalyani Kamarhati Nabadwip Naihati Panihat Serampore Titagarh {
	// note: there is a 'Fatehabad' in the IM dataset but it is in Haryana, so it can't match the 'Fatehbad' in GAP1
	replace action = 1 if year>=1985 & city=="`s'"
	replace gap1 = 1985 if city=="`s'" 
}

/* GAP-2 */
g gap2 = .
foreach t in Allahabad Anupshaher Arrah Bhadreshwar Champdani Badrinath Baidyabati Bansberia Barahya Barh Barrackpur Bhagalpur Bijnore `Budge-Budge' Buxar Chakdaha Chapra Chunar `Circular Canal' Deoprayag Dhulian `Diamond Harbour' Farrukhabad Fatwah Garhmukteshwar Garulia Ghazipur Gopeshwar Gayespur Halisahar Kancharapara Hardwar Rishikesh Hazipur Jangipur `Jiaganj Azimganj' Joshimath Kahelgaon Kanpur Karnaparag Katwa Khardaha Konnagar Maheshtala `Mirzapur-Cum-Vindhyachal' Mokameh `Mughal Sarai' Munger Murshidabad Naihati `North Barrackpore' Patna Ranipur Rishra Rudraprayag Sahibganj Saidpur Srinagar Sultanganj `Tolly's Nallah' `Uttar Kashi' Uttarpara `Uttar Kotrung' Varanasi {
	replace action = 1 if year>=1993 & city=="`t'"
	replace gap2 = 1993 if city=="`t'" 
}

/* YAP-1 */
g yap1 = .
foreach u in Delhi Chhachhrauli Faridabad Gharaunda Gohana Gurgaon Indri Karnal Palwal Panipat Radaur Sonipat Yamunanagar Jagadhri Agra Etawah Ghaziabad Mathura Muzaffarnagar Noida Saharanpur Vrindaban {
	replace action = 1 if year>=1993 & city=="`u'"
	replace yap1 = 1993 if city=="`u'"
}

/* DAP */
g dap = .
foreach v in Andal Asansol `Bokaro-Kangali' Chirkunda Dugdha Durgapur Jharia Ramgarh Raniganj Sindri Sudamdih Telmachu {
	replace action = 1 if year>=1993 & city=="`v'"
	replace dap = 1993 if city=="`v'" 
}

/* GOMTIAP-1 */
g gomtiap = .
foreach w in Jaunpur Lucknow Sultanpur {
	replace action = 1 if year>=1993 & city=="`w'"
	replace gomtiap = 1993 if city=="`w'" 
}
	
/* NRCP */
g nrcp = .
foreach x in Chennai Rewa Bhopal Mandideep Vidisha Bhadravathi Chandbali Dharamshala Talcher Puri Bhiwani Erode K.R.Nagar Kollegal Kumarapalayam Nanjangud Pallipalaiyam Karur `Kumba Konam' Mayiladuthurai Tiruchirapalli Srirangapatna Trichy Keshoraipatta Kota Nagda Dimapur Bhadrachalam Mancherial Nanded Nashik Rajahmundri Trimbakeshwar Ramagundam Indore Karad Sangli Ujjain Cuttack Panaji Siliguri Hyderabad Jabalpur Hosangabad Pamba(Sabarimala) Bangalore Gangtok Ranipool Singtom Ahmedabad Jalandhar Ludhiana Phagwara Phillaur Kapurthala `Sultanpur Lodhi' Ghatshila Jamshedpur Ranchi Burhanpur Shimoga Davangere Harihara Tirunelveli Thanjavur Madurai Chapara Keolari Seoni	{
	replace action = 1 if year>=1995 & city=="`x'"
	replace nrcp = 1995 if city=="`x'" 
}

egen year1 = rowmin(gap1 gap2 yap1 dap gomtiap nrcp)
drop gap1 gap2 yap1 dap gomtiap nrcp

*************************
/* Prepare air and water datasets for merging */
preserve
	u "${mypath}Data/Air Data/Final Data/combined.dta", clear
	keep state district city year mean lit_urban pop_urban e_so2_mean e_spm_mean e_no2_mean
	so state city year
	tempfile air
	save `air'

	u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear
	rename pce mean
	keep state district city year mean lit_urban pop_urban bod lnfcoli do
	keep if year < 2005
	drop if bod>=. & lnfcoli>=. & do>=.
	collapse (max) bod lnfcoli do mean lit_urban pop_urban, by(state city year)
	replace city = "Ankaleshwar" if city=="Anklesh"
	tempfile water
	save `water'
restore

/* Make changes to IM city names for merging with air data */
preserve
	replace city = "Behrampur" if city=="Brahmapur"
	replace city = "Chittorgarh" if city=="Chittor"
	replace city = "Gulbarga" if city=="Gularga"
	replace city = "Hissar" if city=="Hisar"
	replace city = "Howrah" if city=="Haora"
	replace city = "Hubli-Dharwad" if city=="Hubli Dharwad"
	replace city = "Khana" if city=="Khanna"
	replace city = "Pune" if city=="Pune Corp"
	replace city = "Shillong" if city=="Shilong"
	replace city = "Singrauli" if city=="Singroli"
	duplicates tag state city year, g(dups)		// 1 pair of duplicates
	*ed if dups==1
	drop if city=="Gulbarga" & year==1995 & c_source=="IM COLLECTED"
	so state city year

	/* Merge IM with air data */
	joinby state city year using `air', unmatched(both)
	rename _merge merge_air
	drop if merge_air==1
	bys state city: egen polltemp = max(merge_air)
	keep if polltemp==3
	drop polltemp
	save "Data/Infant Mortality/IM City/Final Data/im_air.dta", replace
restore

/* Make changes to IM city names for merging with water data */
replace city = "Ferozepur" if city=="Ferozepur City"
replace city = "Bahrampore" if city=="Baharampur" | city=="Behrampur"
replace city = "Bhubaneswar" if city=="Bhubaneshwar"
replace city = "Brajrajnagar" if city=="Brajarajnagar"
replace city = "Buxar" if city=="Buxer"
replace city = "Hassan City" if city=="Hassan"
replace city = "Hoshangabad" if city=="Hosangabad"
replace city = "Hubli-Dharwar" if city=="Hubli Dharwad"
replace city = "Jaggayyapet" if city=="Jaggayyapeta"
replace city = "Kanakapura Town" if city=="Kanakapura"
replace city = "Karaikal Region" if city=="Karaikal"
replace city = "Lunawada" if city=="Lunavada"
replace city = "Mandavi" if city=="Mandvi"
replace city = "Mokama" if city=="Mokameh"
replace city = "Narsinghpur" if city=="Narsimhapur"
replace city = "Pallipalayam" if city=="Pallipalaiyam"
replace city = "Paradeep" if city=="Paradip"
replace city = "Pune" if city=="Pune Corp"
replace city = "Rajahmundry" if city=="Rajahmundri"
replace city = "Rajnandgaon" if city=="Rajnanadgaon"
replace city = "Sonepat" if city=="Sonipat"
replace city = "Tiruchirappalli" if city=="Tiruchirapalli"
replace city = "Velore" if city=="Vellore"
so state city year

/* Merge IM with water data */
joinby state city year using `water', unmatched(both)
rename _merge merge_water
bys state city: egen polltemp = max(merge_water)
ta polltemp
bys state city: egen polltemp2 = min(merge_water)
replace polltemp = 3 if polltemp==2 & polltemp2==1
ta polltemp
keep if polltemp==3		
drop polltemp*

/* City names were changed in IM to match air and water names. But in cases where air and water do not merge, we still have a problem. 
	Now I'm changing water city names to match air city names where there is a conflict */
replace city = "Bhubaneshwar" if city=="Bhubaneswar"
replace city = "Hassan" if city=="Hassan City"
replace city = "Hubli-Dharwad" if city=="Hubli-Dharwar"

save "Data/Infant Mortality/IM City/Final Data/im_water.dta", replace
