***********************************************************************************

* File: merge_ap_policy_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This file merges air pollution data and policy data and adds income controls.

Structure:
1. Load the pollution file. Each obs is a city-year
2. Add the policy data
3. Add an income variable (control)
*/

***********************************************************************************

clear all
set mem 500m
set more off
version 9.0

cd "${mypath}Data/Air Data"
cap log close

********************************************
* 1. Load AP data

u "Intermediate Data/e_airpol_city.dta", clear

********************************************
* 2. Add policy data. State-city-year uniquely identifies an observation.

* Original policy dataset
mer 1:1 state city year using "../Policies/Final Data/policies_cleaned.dta"
ta _mer
drop _mer
sort state city year

******************************************
* 3. Add control data

* Per capita expenditure controls are disaggregated further (into newer, smaller districts) than presently-applied districts. I am changing 
*	a few of them so I can assign more accurate estimates
replace district = "Goa, Daman & Diu" if district == "Daman & Diu" & state == "Daman & Diu"

* Merge per capita expenditure data
so state district year
merge m:1 state district year using "../Controls/Income/Intermediate Data/pov.dta"
drop if year < 1987
ta _mer /* There is no income/poverty data for Goa so there are 80 air pollution/policy obs that didn't merge */
drop if _mer == 2
drop _mer povgap

* Merge airtemp and precip
so state district year
merge m:1 state district year using "Intermediate Data/airtemp_prcp_air.dta"
drop if _merge == 2
drop _merge

******************************************
* Save

sa "Final Data/combined.dta", replace

cd "${mypath}Data/Air Data"
