***********************************************************************************

* File: newspaper_prep_01102014.do
* Date: August 3, 2012
* Contact: Jon Petkun - petkunj@nber.org

/*
Objective: 
 This program's objective is to prepare data representing Times of India keyword
	search results, and to merge those new data with the existing India Pollution datasets.

Structure:
0. Set-up
1. Insheet, reshape, and append together raw Times of India data
2. Basic cleaning and formatting
3. Clean-up

Note: 

*/

***********************************************************************************

***********************************************************************************
* Section 0: Set-up
***********************************************************************************
cap log close 

clear all
set more off
set mem 500m
version 11.0

* ssc install tablemat
* ssc install mat2txt

log using "${mypath}Log/newspaper_prep_01102014.txt", replace t

***********************************************************************************
* Section 1: Insheet, reshape, and append together raw Times of India data
***********************************************************************************
gen temp = .
save "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", replace

* Section 1A: Air references *
local keyword "air"

* Insheet raw data
insheet using "${mypath}Data/Controls/Times of India/Raw Data/ToI_Air.csv", clear names

* Rename variables
local startyear = 1970
foreach var of varlist v* {
	rename `var' `keyword'_references`startyear'
	local startyear = `startyear' + 1
}

* Reshape into long format
reshape long `keyword'_references, i(state) j(year)
* Rajasthan is sometimes mispelled - we have to fix it before merging datasets together
replace state = "Rajasthan" if state == "Rajastan"

* Append and save
append using "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta"
save "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", replace

* Section 1B: Water references *
local keyword "water"

* Insheet raw data
insheet using "${mypath}Data/Controls/Times of India/Raw Data/ToI_Water.csv", clear names

* Rename variables
local startyear = 1970
foreach var of varlist v* {
	rename `var' `keyword'_references`startyear'
	local startyear = `startyear' + 1
}

* Reshape into long format
reshape long `keyword'_references, i(state) j(year)
replace state = "Rajasthan" if state == "Rajastan"

* Merge and save
merge 1:1 state year using "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", gen(merge_water)
save "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", replace

* Section 1C: Corruption references *
local keyword "corruption"

* Insheet raw data
insheet using "${mypath}Data/Controls/Times of India/Raw Data/ToI_Corruption.csv", clear names

* Rename variables
local startyear = 1970
foreach var of varlist v* {
	rename `var' `keyword'_references`startyear'
	local startyear = `startyear' + 1
}

* Reshape into long format
reshape long `keyword'_references, i(state) j(year)
replace state = "Rajasthan" if state == "Rajastan"

* Merge and save
merge 1:1 state year using "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", gen(merge_corruption)
save "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", replace

* Section 1D: SPCB references *
local keyword "spcb"

* Insheet raw data
insheet using "${mypath}Data/Controls/Times of India/Raw Data/ToI_SPCB.csv", clear names

* Rename variables
local startyear = 1970
foreach var of varlist v* {
	rename `var' `keyword'_references`startyear'
	local startyear = `startyear' + 1
}

* Reshape into long format
reshape long `keyword'_references, i(state) j(year)
replace state = "Rajasthan" if state == "Rajastan"

* Merge
merge 1:1 state year using "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", gen(merge_spcb)
drop merge* temp

***********************************************************************************
* Section 2: Basic cleaning and formatting
***********************************************************************************
* Fix state names to match existing pollution/mortality data	
replace state = "Andhra Pradesh" if state == "Andra Pradesh"
replace state = "Jammu & Kashmir" if state == "Jammu and Kashmir"

* Generate new variables
gen pollution_references = air_references + water_references

* Save the full Times of India dataset -- just in case we want to use it later
save "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear_full.dta", replace

* Drop state-years that aren't represented in the existing pollution/mortality data
drop if year < 1986 | year > 2007
drop if state == "Arunachal Pradesh" | state == "Chhattisgarh" | state == "Jharkhand" | ///
	state == "Other" | state == "Sikkim" | state == "Uttarakhand"
	
save "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", replace

***********************************************************************************
* Section 3: Clean-up
***********************************************************************************
log close 
