***********************************************************************************

* File: temp_prcp_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: 
 This file prepares the air temperature and precipitation data for merging with main 
 	water and air datasets. The air and temperature data were provided by Olivier Deschenes.

Structure:
1. Merge district codes file with main airtemp/precip dataset
2. Reconcile district names b/w airtemp/precip file and main water file
3. Saving separate and air water datafiles
*/

***********************************************************************************

clear all
set mem 500m
set more off

cd "${mypath}Data/Water Data"

*************************************
* 1. Merge district codes file with main airtemp/precip dataset

/* Insheet and save district names */
insheet using "Raw Data/DistrictCodes.csv"
drop v4
drop if dist61_id >= .
rename name district
rename state_ut state
so dist61_id
save "Intermediate Data/airtemp_dcodes.dta", replace

/* Merge district names into airtemp/precip datafile */
*u "Intermediate Data/temp_prcp.dta", clear
u "Raw Data/temp_prcp.dta", clear
so dist61_id year
merge m:1 dist61_id using "Intermediate Data/airtemp_dcodes.dta"
ta _merge
drop _merge
rename temp airtemp
replace totprcp = . if totprcp <= 0
save "Intermediate Data/tempA.dta", replace

**************************************
* 2. Reconcile district names b/w airtemp/precip file and main water file

/* clean_districts.do is an existing file for reconciliation of district names with the dataset. clean_districts_1961.do is a file I just made specifically to fill out the gaps in the former do-file and fix any errors created by it. The rest of the code (between the preserve and restore commands) is there to facilitate my creation of the clean_districts_1961.do file and practice-merge to see my progress. The end product is the file airtemp_prcp.dta, and I delete the temporary files. */
do "${mypath}Do Files/Data Cleaning/clean_districts_01102014.do"
do "${mypath}Do Files/Data Cleaning/clean_districts_1961_01102014.do"
collapse (mean) airtemp totprcp, by(state district year month)
so state district year month
save "Intermediate Data/tempB.dta", replace

/*
preserve
	u "Final Data/india_waters.dta", clear
	so state district year month
	merge state district year month using tempB.dta, uniqusing

	drop if year > 2000
	collapse (mean) airtemp totprcp, by(state district _merge)
	drop if district == ""
	so state district _merge
restore

preserve
	collapse (mean) airtemp totprcp, by(state district year)
	save "tempC.dta", replace
	u "../Air Data/Final Data/combined.dta", clear
	so state district year
	merge state district year using tempC.dta, uniqusing

	drop if year > 2000
	collapse (mean) airtemp totprcp, by(state district _merge)
	drop if district == ""
	so state district _merge
restore
*/

* 3. Saving separate and air water datafiles
save "Intermediate Data/airtemp_prcp_water.dta", replace

collapse (mean) airtemp totprcp, by(state district year)
save "${mypath}Data/Air Data/Intermediate Data/airtemp_prcp_air.dta", replace

erase "Intermediate Data/tempA.dta"
erase "Intermediate Data/tempB.dta"
*erase "tempC.dta"
