***********************************************************************************

* File: waterpol_2005_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: 
 This file insheets raw data from the CPCB (by river basin) and cleans it in preparation 
	for merging with the main water dataset.

Structure:
1. Insheet files
2. Clean location names
3. Merge with ID info

Notes:
1. There are 421 observations from the CPCB website. This program assigns ID info (state, city, river) to 360 of them. With no ID information the other observations cannot be used in analysis; they have no corresponding observations from different years. These un-ID'd observations are dropped.
*/

***********************************************************************************

clear all
set more off
set mem 500m

cd "${mypath}Data/Water Data/Raw Data/2005"

***********************************
* 1. Insheet raw data

foreach y in Brahmani Brahmaputra Cauvery Ganga Godavari Indus Krishna Mahanadi Mahi Narmada Subarnarekha Sabarmati Tapi {
	insheet using "`y'-2005.csv", clear nonames
	rename v1 location
	rename v2 temp_min
	rename v3 temp_max
	rename v4 temp
	rename v5 do_min
	rename v6 do_max
	rename v7 do
	rename v8 ph_min
	rename v9 ph_max
	rename v10 ph
	rename v11 cond_min
	rename v12 cond_max
	rename v13 cond
	rename v14 cod_min
	rename v15 cod_max
	rename v16 cod
	rename v17 bod_min
	rename v18 bod_max
	rename v19 bod
	rename v20 nitrate_min
	rename v21 nitrate_max
	rename v22 nitrate
	rename v23 nitrite_min
	rename v24 nitrite_max
	rename v25 nitrite
	rename v26 ammonitro_min
	rename v27 ammonitro_max
	rename v28 ammonitro
	rename v29 fcoli_min
	rename v30 fcoli_max
	rename v31 fcoli
	rename v32 totcoli_min
	rename v33 totcoli_max
	rename v34 totcoli
	rename v35 calc_min
	rename v36 calc_max
	rename v37 calc
	rename v38 magne_min
	rename v39 magne_max
	rename v40 magne
	rename v41 sodium_min
	rename v42 sodium_max
	rename v43 sodium
	rename v44 potassium_min
	rename v45 potassium_max
	rename v46 potassium
	rename v47 chlor_min
	rename v48 chlor_max
	rename v49 chlor
	rename v50 sulph_min
	rename v51 sulph_max
	rename v52 sulph
	rename v53 alk_pheno_min
	rename v54 alk_pheno_max
	rename v55 alk_pheno
	rename v56 alkal_min
	rename v57 alkal_max
	rename v58 alkal
	rename v59 hardness_min
	rename v60 hardness_max
	rename v61 hardness
	rename v62 phosphate_min
	rename v63 phosphate_max
	rename v64 phosphate
	rename v65 turb_min
	rename v66 turb_max
	rename v67 turb
	rename v68 kjeldahl_min
	rename v69 kjeldahl_max
	rename v70 kjeldahl
	rename v71 tds_min
	rename v72 tds_max
	rename v73 tds
	rename v74 tfds_min
	rename v75 tfds_max
	rename v76 tfds
	rename v77 tss_min
	rename v78 tss_max
	rename v79 tss
	rename v80 boron_min
	rename v81 boron_max
	rename v82 boron
	rename v83 fluoride_min
	rename v84 fluoride_max
	rename v85 fluoride
	rename v86 na_perc_min
	rename v87 na_perc_max
	rename v88 na_perc
	rename v89 sar_min
	rename v90 sar_max
	rename v91 sar
	rename v92 saprob_min
	rename v93 saprob_max
	rename v94 saprob
	rename v95 divers_min
	rename v96 divers_max
	rename v97 divers
	rename v98 prr_min
	rename v99 prr_max
	rename v100 prr
	drop if _n < 3
	g basin = "`y'"
	save `y'.dta, replace
}
use brahmani.dta, clear
foreach y in Brahmaputra Cauvery Ganga Godavari Indus Krishna Mahanadi Mahi Narmada Subarnarekha Sabarmati Tapi {
	append using "`y'.dta", force
}

***************************************
* 2. Cleaning

drop if location == ""
foreach x of varlist temp_min-prr {
	replace `x' = "" if `x' == "M" | `x' == "-" | `x' == "##" | `x' == "###"
	destring `x', replace
}
	
drop prr* /* No values; totally empty */

g stncode = .
g city = ""
g state = ""
g year = 2005
g river = ""
order stncode state city river year

* From merging and comparing location names. This is faster because I have to add city, river, and state data for each observation.

* Brahmaputra
replace location = "*MORA BHARALI  AT TEZPUR, ASSAM" if location == "*MORA BHARALI AT TEZPUR, ASSAM"
replace location = "BRAHAMPUTRA AT DIBRUGARH, ASSAM" if location == "DIBRUGARH, ASSAM"
replace location = "BRAHAMPUTRA AT KHERGHAT (AFTER CONFL. WITH DIBANG & DIHANG),ASSAM" if location == "KHERGHAT (A/C WITH DIBANG & DIHANG), ASSAM"
replace location = "BRAHAMPUTRA AT NIMATIGHAT, ASSAM" if location == "NIMATIGHAT, ASSAM"
replace location = "BRAHAMPUTRA AT PANDU, ASSAM" if location == "PANDU, ASSAM"
replace location = "BRAHMPUTRA RIVER AT DHENUKHAPAHAR, ASSAM" if location == "DHENUKHAPAHAR, ASSAM"
replace location = "DIGBOI RIVER AT LAKHIPATHE, RESERVE FOREST, DIGBOI, ASSAM " if location == "DIGBOI RIVER AT LAKHIPATHE, RESERVE FOREST, DIGBOI, ASSAM"
replace location = "FULL NAGARJAN, NAGALAND" if location == "DHANSIRI AT FULL NAGARJAN, NAGALAND"
replace location = "NEAR CHECK GATE (DIMAPUR KHUTKHUTI ROAD), NAGALAND" if location == "DHANSIRI AT NEAR CHECK GATE (DIMAPUR KHUTKHUTI ROAD), NAGALAND"
replace location = "NUTON BASTI, NAGALAND" if location == "DHANSIRI AT NUTON BASTI, NAGALAND"
replace location = "RANICHU BEFORE CONFLUENCE WITH RIVER TEESTA AT SINGTAM, SIKKIM" if location == "RANICHU B/C WITH RIVER TEESTA AT SINGTAM, SIKKIM"
replace location = "RIVER DIKCHU BEFORE CONFIUENCE WITH RIVER TEESTA NEAR NHPC HYDROELECTRIC POWER PROJECT, SIKKIM" if location == "DIKCHU B/C WITH RIVER TEESTA NEAR NHPC HYDROELECTRIC POWER PROJECT, SIKKIM"
replace location = "RIVER MANEY KHOLA AT BURTUK NEAR ARMY BASE CAMP, 4 KM        U/S OF GANGTOK, SIKKIM" if location == "MANEY KHOLA AT BURTUK NEAR ARMY BASE CAMP, 4 KM U/S OF GANGTOK, SIKKIM"
replace location = "RIVER TEESTA AFTER CONFIUENCE OF RIVERS LACHENCHU AND LACHUNGCHU AT CHUNGTHAANG, SIKKIM" if location == "TEESTA A/C OF RIVERS LACHENCHU AND LACHUNGCHU AT CHUNGTHAANG, SIKKIM"
replace location = "RIVER TEESTA AFTER CONFLUENCE WITH RIVER RANICHU AT SINGTAM" if location == "TEESTA A/C WITH RIVER RANICHU AT SINGTAM"
replace location = "RIVER TEESTA AT MELLI DOWNSTREAM, SIKKIM" if location == "TEESTA AT MELLI DOWNSTREAM, SIKKIM"
replace location = "TOWN BOUNDARY BRIDGE (DIPHU ROAD), NAGALAND" if location == "DHANSIRI AT TOWN BOUNDARY BRIDGE (DIPHU ROAD), NAGALAND"
replace location = "BRAHAMPUTRA AT JOGIJHOGA NEAR BRIDGE, ASSAM" if location == "JOGIJHOGA NEAR BRIDGE, ASSAM"
replace location = "SUBANSIRI AT GEREKAMUKH,ASSAM,(BEFORE CONFL. WITH BRAH.),ASSAM" if location == "GEREKAMUKH, ASSAM,(B/C WITH BRAH.),ASSAM"

* Cauvery
replace location = "AMRAVATI AT 1KM D/S FROM EFF.DIS. PT. AT MADHUTHUKKULAM,TAMILNADU" if location == "AMRAVATI AT 1KM D/S FROM EFF.DIS. PT. AT MADHUTHUKKULAM, TAMILNADU"
replace location = "BHAVANI AT SIRUMUGAI,TAMILNADU" if location == "BHAVANI AT SIRUMUGAI, TAMILNADU"
replace location = "CAUVERY AT COLEROON, TAMILNADU" if location == "COLEROON, TAMILNADU"
replace location = "CAUVERY AT D/S OF KAREKUARA VILLAGE, KARNATAKA" if location == "D/S OF KAREKUARA VILLAGE, KARNATAKA"
replace location = "CAUVERY AT ERODE NEAR CHIRAPALAYAM, TAMILNADU" if location == "ERODE NEAR CHIRAPALAYAM, TAMILNADU"
replace location = "CAUVERY AT KRS DAM,BALAMURIKSHETRA,KARNATAKA" if location == "KRS DAM, BALAMURIKSHETRA, KARNATAKA"
replace location = "CAUVERY AT KUSHAL NAGAR U/S (NEAR BAICHANAHALLI), KARNATAKA" if location == "KUSHAL NAGAR U/S (NEAR BAICHANAHALLI), KARNATAKA"
replace location = "CAUVERY AT METTUR, TAMIL NADU" if location == "METTUR, TAMIL NADU"
replace location = "CAUVERY AT MOHANUR NEAR PATTAIPALAYAM, TAMILNADU" if location == "MOHANUR NEAR PATTAIPALAYAM, TAMILNADU"
replace location = "CAUVERY AT MUSIRI, TAMIL NADU" if location == "MUSIRI, TAMIL NADU"
replace location = "CAUVERY AT NAPOKULU BDG (D/S), KARNATAKA" if location == "NAPOKULU BDG (D/S), KARNATAKA"
replace location = "CAUVERY AT PALLIPPALAYAM, TAMIL NADU" if location == "PALLIPPALAYAM, TAMIL NADU"
replace location = "CAUVERY AT PITCHAVARAM, TAMILNADU" if location == "PITCHAVARAM, TAMILNADU"
replace location = "CAUVERY AT SATHYAGALAM BRIDGE, KARNATAKA" if location == "SATHYAGALAM BRIDGE, KARNATAKA"
replace location = "CAUVERY AT SRI RANGAPATTANNA,D/S OF ROAD BDG.,KARNATAKA" if location == "SRI RANGAPATTANNA, D/S OF ROAD BDG., KARNATAKA"
replace location = "CAUVERY AT THANJAVUR, TAMILNADU" if location == "THANJAVUR, TAMILNADU"
replace location = "CAUVERY AT THIRUMUKKUDAL-CONFL. PT.OF R. AMRAVATI,TAMILNADU" if location == "THIRUMUKKUDAL CONFL. PT.OF R. AMRAVATI, TAMILNADU"
replace location = "CAUVERY AT TIRUCHIRAPPALLI D/S, TAMILNADU" if location == "TIRUCHIRAPPALLI D/S, TAMILNADU"
replace location = "CAUVERY AT TIRUCHIRAPPALLI U/S, TAMILNADU" if location == "TIRUCHIRAPPALLI U/S, TAMILNADU"
replace location = "CAUVERY AT TRICHY,GRAND ANAICUT, TAMILNADU" if location == "TRICHY,GRAND ANAICUT, TAMILNADU"
replace location = "CAUVERY AT VELORE NEAR KATTIPALAYAM, TAMILNADU" if location == "VELORE NEAR KATTIPALAYAM, TAMILNADU"
replace location = "KABBANI AT CAUSE WAY  SATTUR, KARNATAKA" if location == "KABBANI AT CAUSEWAY SATTUR, KARNATAKA"
replace location = "KABBANI AT WATER INTAKE OF KIADB AT NANJANGUD,KARNATAKA" if location == "KABBANI AT WATER INTAKE OF KIADB AT NANJANGUD, KARNATAKA"
replace location = "LAKSHMANTIRTHA  AT D/S OF HUNSUR TOWN, KARNATAKA" if location == "LAKSHMANTIRTHA AT D/S OF HUNSUR TOWN, KARNATAKA"

* Baitarni-Brahmani
replace location = "BAITARNI AT ANANDPUR, ORISSA" if location == "ANANDPUR, ORISSA"
replace location = "BAITARNI AT CHANDBALI, ORISSA" if location == "CHANDBALI, ORISSA"
replace location = "BAITARNI AT DHAMRA, ORISSA" if location == "DHAMRA, ORISSA"
replace location = "BAITARNI AT JAJPUR, ORISSA" if location == "JAJPUR, ORISSA"
replace location = "BAITARNI AT JODA, ORISSA" if location == "JODA, ORISSA"

* Ganga
replace location = "AGRA U/S" if location == "AGRA U/S, U.P."
replace location = "BATESHWAR" if location == "BATESWAR, U.P"
replace location = "DAMODAR AT DISHERGARH VILL.(NR.BIHAR-WEST BENGAL BORDER),WEST BENGAL" if location == "DAMODAR AT DISHERGARH VILL.(NR.BIHAR-WEST BENGAL BORDER) WEST BENGAL"
replace location = "ETAWAH" if location == "ETAWAH, U.P."
replace location = "Farmar at Jogbani" if location == "FARMAR AT JOGBANI"
replace location = "GANGA AT ALLAHABAD D/S (SANGAM), U.P." if location == "ALLAHABAD D/S (SANGAM), U.P."
replace location = "GANGA AT ALLAHABAD (RASOOLABAD), U.P." if location == "ALLAHABAD (RASOOLABAD), U.P."
replace location = "GANGA AT BAHARAMPORE, WEST BENGAL" if location == "BAHARAMPORE WEST BENGAL"
replace location = "GANGA AT BITHOOR (KANPUR), U.P." if location == "BITHOOR (KANPUR), U.P."
replace location = "GANGA AT BUXAR,BIHAR" if location == "BUXAR,BIHAR"
replace location = "GANGA AT DAKSHINESHWAR, WEST BENGAL" if location == "DAKSHINESHWAR WEST BENGAL"
replace location = "GANGA AT DALMAU (RAI BAREILLY), U.P." if location == "DALMAU (RAI BAREILLY), U.P."
replace location = "GANGA AT DIAMOND HARBOUR, WEST BENGAL" if location == "DIAMOND HARBOUR WEST BENGAL"
replace location = "GANGA AT GARDEN REACH, WEST BENGAL" if location == "GARDEN REACH WEST BENGAL"
replace location = "GANGA AT GARHMUKTESHWAR, U.P" if location == "GARHMUKTESHWAR, U.P"
replace location = "GANGA AT HOWRAH-SHIVPUR, WEST BENGAL" if location == "HOWRAH-SHIVPUR WEST BENGAL"
replace location = "GANGA AT KANNAUJ D/S, U.P" if location == "KANNAUJ D/S, U.P"
replace location = "GANGA AT KANNAUJ U/S (RAJGHAT), U.P" if location == "KANNAUJ U/S (RAJGHAT), U.P"
replace location = "GANGA AT KANPUR D/S (JAJMAU PUMPING STATION), U.P" if location == "KANPUR D/S (JAJMAU PUMPING STATION), U.P"
replace location = "GANGA AT KANPUR U/S (RANIGHAT), U.P" if location == "KANPUR U/S (RANIGHAT), U.P"
replace location = "GANGA AT KHURJI, PATNA U/S, BIHAR" if location == "KHURJI, PATNA U/S, BIHAR"
replace location = "GANGA AT MOKAMA (U/S)" if location == "MOKAMA (U/S)"
replace location = "GANGA AT NARORA (BULANDSAHAR), U.P." if location == "NARORA (BULANDSAHAR), U.P."
replace location = "GANGA AT PALTA, WEST BENGAL" if location == "PALTA WEST BENGAL"
replace location = "GANGA AT PATNA D/S (GANGA BRIDGE),BIHAR" if location == "PATNA D/S (GANGA BRIDGE),BIHAR"
replace location = "GANGA AT RAJMAHAL, BIHAR" if location == ""
replace location = "GANGA AT SERAMPORE, WEST BENGAL" if location == "SERAMPORE WEST BENGAL"
replace location = "GANGA AT TRIGHAT (GHAZIPUR), U.P" if location == "TRIGHAT (GHAZIPUR), U.P"
replace location = "GANGA AT ULUBERIA, WEST BENGAL" if location == "ULUBERIA WEST BENGAL"
replace location = "GANGA AT VARANASI D/S (MALVIYA BRIDGE), U.P" if location == "VARANASI D/S (MALVIYA BRIDGE), U.P"
replace location = "GANGA AT VARANASI U/S (ASSIGHAT), U.P" if location == "VARANASI U/S (ASSIGHAT), U.P"
replace location = "GOVIND  SAGAR, U.P" if location == "GOVIND SAGAR, U.P"
replace location = "Ganga at Mokama (d/s)" if location == "MOKAMA (D/S)"
replace location = "Ganga at Kahalgaon" if location == "KAHALGAON"
replace location = "HATHNIKUND" if location == "HATHNIKUND HARYANA"
replace location = "JUHIKHA (AFTER CONFL. WITH CHAMBAL)" if location == "JUHIKA B/C WITH CHANBAL, ETAWAH, U.P"
replace location = "KALANAUR" if location == "KALANAUR, YAMUNA NAGAR, HARYANA"
replace location = "MATHURA D/S" if location == "MATHURA D/S , U.P."
replace location = "MATHURA U/S" if location == "MATHURA U/S , U.P."
replace location = "MAZAWALI" if location == "MAZAWALI, U.P"
replace location = "NIZAMUDDIN" if location == "NIZAMUDDIN, DELHI"
replace location = "RIVER YAMUNA , D/S PAONTA SAHIB, H.P" if location == "D/S PAONTA SAHIB, H.P"
replace location = "RIVER YAMUNA , U/S PAONTA SAHIB, H.P" if location == "U/S PAONTA SAHIB, H.P"
replace location = "RIVER YAMUNA AT OKHLA AFTER MEETING OF SHAHDARA DRAIN, DELHI" if location == "OKHLA AFTER MEETING OF SHAHDARA DRAIN, DELHI"
replace location = "SONEPAT" if location == "SONEPAT, HARYANA"
replace location = "YAMUNA AT AGRA U/S, U.P." if location == "AGRA U/S, U.P."
replace location = "YAMUNA AT ALLAHABAD D/S (BALUA GHAT), U.P" if location == "ALLAHABAD D/S (BALUA GHAT), U.P"
replace location = "YAMUNA AT ALLAHABAD. U.P." if location == "ALLAHABAD. U.P."
replace location = "YAMUNA AT OKHLA BRIDGE (INLET OF AGRA CANAL), DELHI" if location == "OKHLA BRIDGE (INLET OF AGRA CANAL), DELHI"
replace location = "YAMUNA AT U/S OF LAKHWAR DAM, U.P." if location == "U/S OF LAKHWAR DAM, U.P"

* Godavari
replace location = "GODAVARI AT DHALEGAON, MAHARASHTRA" if location == "12 DHALEGAON, MAHARASHTRA"
replace location = "GODAVARI AT JAYAKWADI DAM, AURNAGABAD,MAHARASHTRA" if location == "1312 JAYAKWADI DAM, AURNAGABAD, MAHARASHTRA"
replace location = "GODAVARI AT MANCHERIAL, A.P." if location == "13 MANCHERIAL, A.P."
replace location = "GODAVARI AT NANDED, MAHARASHTRA" if location == "1210 NANDED, MAHARASHTRA"
replace location = "GODAVARI AT NASIK D/S, MAHARASHTRA" if location == "1211 NASIK D/S, MAHARASHTRA"
replace location = "GODAVARI AT PANCHAVATI AT RAMKUND,MAHARASHTRA" if location == "1096 PANCHAVATI AT RAMKUND, MAHARASHTRA"
replace location = "GODAVARI AT POLAVARAM, A.P." if location == "14 POLAVARAM, A.P."
replace location = "GODAVARI AT RAHER, MAHARASHTRA" if location == "1209 RAHER, MAHARASHTRA"
replace location = "GODAVARI AT RAJAHMUNDRY D/S, A.P." if location == "1219 RAJAHMUNDRY D/S, A.P."
replace location = "GODAVARI AT RAJAHMUNDRY U/S, A.P." if location == "1218 RAJAHMUNDRY U/S, A.P."
replace location = "GODAVARI AT RAJURA BRIDGE D/S CHANDRAPUR, MAHARASHTRA,REALLO. TO GODAVARI" if location == ""
replace location = "GODAVARI AT U/S OF GANGAPUR DAM,NASIK,MAHARASHTRA" if location == "1095 U/S OF GANGAPUR DAM, NASIK, MAHARASHTRA"
replace location = "Chandrabhaga D/s of Pandharpur town" if location == "1912 CHANDRABHAGA D/S OF PANDHARPUR TOWN"
replace location = "Chandrabhaga U/s of Pandharpur town" if location == "1911 CHANDRABHAGA U/S OF PANDHARPUR TOWN"
replace location = "Kolar before Confluence to Kanhan at Kamptee" if location == "1908 KOLAR BEFORE CONFLUENCE TO KANHAN AT KAMPTEE"
replace location = "Kanhan D/s of Nagpur" if location == "1909 KANHAN D/S OF NAGPUR"
replace location = "MANJEERA RIVER - NEAR GANAPATHI SUGARS , MEDAK DIST., A.P" if location == "1781 MANJEERA RIVER - NEAR GANAPATHI SUGARS , MEDAK DIST., A.P"
replace location = "MANJERA AT RAIPALLU, A.P." if location == "1157 MANJERA AT RAIPALLU, A.P."
replace location = "NIRA AT PULGAON COTTON MILL, WARDHA, MAHARASHTRA" if location == "1315 NIRA AT PULGAON COTTON MILL, WARDHA, MAHARASHTRA"
replace location = "Purna at Dhupeshwar" if location == "1913 PURNA AT DHUPESHWAR"
replace location = "WAINGANGA  AT ASHTI, MAHARASHTRA" if location == "11 WAINGANGA AT ASHTI, MAHARASHTRA"
replace location = "WAINGANGA AT BALAGHAT, M.P." if location == "1213 WAINGANGA AT BALAGHAT, M.P."
replace location = "WAINGANGA AT CHINDWARA, M.P." if location == "1214 WAINGANGA AT CHINDWARA, M.P."
replace location = "WARDHA AT RAJURA BRIDGE, MAHARASHTRA" if location == "1212 WARDHA AT RAJURA BRIDGE, MAHARASHTRA"
replace location = "MANER AT SOMNAPALLI, A.P." if location == "1158 MANER AT SOMNAPALLI, A. P."
replace location = "MANER AT WARANGAL U/S, A.P." if location == "1215 MANER AT WARANGAL U/S, A.P."

* Indus
replace location = "BEAS AT 100M D/S INDUST. DISCH. GOINDWAL PUNJAB" if location == "100M D/S INDUST. DISCH. GOINDWAL PUNJAB "
replace location = "BEAS AT 1KM.D/S OF EFFL. DISH. POINT AT MUKERIAN ,PUNJAB" if location == "1KM.D/S OF EFFL. DISH. POINT AT MUKERIAN ,PUNJAB "
replace location = "BEAS AT HARIKE, PUNJAB" if location == "HARIKE, PUNJAB "
replace location = "BEAS AT MIRTHAL BRIDGE, GURDASPUR, PUNJAB" if location == "MIRTHAL BRIDGE, GURDASPUR, PUNJAB "
replace location = "BEAS AT TALWARA H/W, PUNJAB" if location == "TALWARA H/W, PUNJAB "
replace location = "BEAS AT U/S MANALI, H.P." if location == "U/S MANALI, H.P. "
replace location = "BEAS AT U/S PANDON DAM, H.P." if location == "U/S PANDON DAM, H.P. "
replace location = "BEAS AT D/S ALAMPUR, H.P." if location == "D/S ALAMPUR, H.P. "
replace location = "BEAS AT D/S AUT, H.P." if location == "D/S AUT, H.P. "
replace location = "BEAS AT D/S DEHRAGOPIPUR, H.P." if location == "D/S DEHRAGOPIPUR, H.P. "
replace location = "BEAS AT D/S KULU, H.P." if location == "D/S KULU, H.P. "
replace location = "BEAS AT D/S MANDI, H.P." if location == "D/S MANDI, H.P. "
replace location = "BEAS AT D/S PONG DAM, H.P." if location == "D/S PONG DAM, H.P. "
replace location = "BEAS AT EXIT OF TUNNEL DEHAL POWER HOUSE, H.P." if location == "EXIT OF TUNNEL DEHAL POWER HOUSE, H.P. "
replace location = "BEAS AT G.T.ROAD UNDER BDG. NEAR KAPURTHALA, PUNJAB" if location == "G.T.ROAD UNDER BDG. NEAR KAPURTHALA, PUNJAB "
replace location = "D/S PATHANKOT,PUNJAB" if location == "D/S PATHANKOT,PUNJAB "
replace location = "D/S HUSSANIWALA-H/W FEROZEPUR, PUNJAB" if location == "D/S HUSSANIWALA-H/W FEROZEPUR, PUNJAB "
replace location = "RIVER       SIRSA , U/S SITOMAJRI NALLAHGARH, H.P" if location == "RIVER       SIRSA , U/S SITOMAJRI NALLAHGARH, H.P "
replace location = "RAVI AT U/S CHAMBA, H.P." if location == "RAVI AT U/S CHAMBA, H.P. "
replace location = "RAVI AT U/S MADHOPUR, H.P." if location == "RAVI AT U/S MADHOPUR, H.P. "
replace location = "RAVI AT U/S OF MADHOPUR HEADWORKS,GURDASPUR,PUNJAB" if location == "RAVI AT U/S OF MADHOPUR HEADWORKS,GURDASPUR,PUNJAB "
replace location = "RIVER SIRSA , D/S NALAGARH BRIDGE, H.P" if location == "RIVER SIRSA , D/S NALAGARH BRIDGE, H.P "
replace location = "SATLUJ AT 1 KM. D/S OF ZENITH, PUNJAB" if location == "1 KM. D/S OF ZENITH, PUNJAB "
replace location = "SATLUJ AT 100M D/S ,NANGAL,PUNJAB" if location == "100M D/S ,NANGAL,PUNJAB "
replace location = "SATLUJ AT 100M D/S BUDHA NALA CONFL.,LUDHIANA,PUNJAB" if location == "100M D/S BUDHA NALA CONFL.,LUDHIANA,PUNJAB "
replace location = "SATLUJ AT BOAT BDG. DHARMKOTNAKODAR ROAD, JALANDHAR, PUNJAB" if location == "BOAT BDG. DHARMKOTNAKODAR ROAD, JALANDHAR, PUNJAB "
replace location = "SATLUJ AT BRIDGE HARIKE, AMRITSAR, PUNJAB" if location == "BRIDGE HARIKE, AMRITSAR, PUNJAB "
replace location = "SATLUJ AT D/S BHAKHRA, H.P." if location == "D/S BHAKHRA, H.P. "
replace location = "SATLUJ AT D/S NFL, PUNJAB" if location == "D/S NFL, PUNJAB "
replace location = "SATLUJ AT D/S OF UNITED PAPER MILLS AT ARSON, PUNJAB" if location == ""
replace location = "SATLUJ AT D/S RAMPUR, H.P." if location == "D/S RAMPUR, H.P. "
replace location = "SATLUJ AT D/S SLAPPER, H.P." if location == "D/S SLAPPER, H.P. "
replace location = "SATLUJ AT NEPTHA ZAKHAI, H.P" if location == "NEPTHA ZAKHAI, H.P "
replace location = "SATLUJ AT U/S HEAD WORKS ROPAR, PUNJAB" if location == "U/S HEAD WORKS ROPAR, PUNJAB "
replace location = "SATLUJ AT U/S RAMPUR, H.P." if location == "U/S RAMPUR, H.P. "
replace location = "SATLUJ AT U/S SLAPPER, H.P." if location == "U/S SLAPPER, H.P. "
replace location = "SATLUJ AT U/S TATAPANI, H.P." if location == "U/S TATAPANI, H.P. "
replace location = "U/S BUDHA NALLAH (UPPER), PUNJAB" if location == "U/S BUDHA NALLAH (UPPER), PUNJAB "
replace location = "U/S GOINDWAL, PUNJAB" if location == "U/S GOINDWAL, PUNJAB "
replace location = "U/S HUSSANIWALA - H/W FEROZEPUR, PUNJAB" if location == "U/S HUSSANIWALA - H/W FEROZEPUR, PUNJAB "
replace location = "U/S MANDI, H.P" if location == "U/S MANDI, H.P "
replace location = "U/S PATHANKOT, PUNJAB" if location == "U/S PATHANKOT, PUNJAB "
replace location = "LARGI AT D/S, H.P." if location == "LARGI AT D/S, H.P. "

* Krishna
replace location = "BHADRA AT D/S OF KIOCL ROAD BRIDGE, NEAR HOLEHUNNUR,KARNATAKA" if location == "BHADRA AT D/S OF KIOCL ROAD BRIDGE, NEAR HOLEHUNNUR, KARNATAKA"
replace location = "BHADRA AT MALLESWARAM,D/S OF KIOCL,KARNATAKA" if location == "BHADRA AT MALLESWARAM D/S OF KIOCL KARNATAKA"
replace location = "BHIMA AFTER CONF. WITH DAUND, MAHARASHTRA" if location == "BHIMA AFTER CONF. WITH DAUNT, MAHARASHTRA"
replace location = "BHIMA AT D/S OF BDG. NEAR YADGIR,KARNATAKA" if location == "BHIMA AT D/S OF BDG. NEAR YADGIR, KARNATAKA"
replace location = "BHIMA AT D/S OF ROAD BRIDGE AT GANGAPUR VILLAGE,KARNATAKA" if location == "BHIMA AT D/S OF ROAD BRIDGE AT GANGAPUR VILLAGE, KARNATAKA"
replace location = "BHIMA AT NARSINGHPUR,(D/S AF.CONFL.WITH R.NIRA),MAHARASHTRA" if location == "BHIMA AT NARSINGHPUR, (D/S AF.CONFL.WITH R. NIRA), MAHARASHTRA"
replace location = "BHIMA AT PARGAON (AFTER CONFL.WITH MULA MIRTHA) MAHARASHTRA." if location == "BHIMA AT PARGAON (AFTER CONFL.WITH MULE MARTHA) MAHARASHTRA."
replace location = "BHIMA AT PUNE, D/S OF BUNDGARDEN,MAHARASHTRA" if location == "BHIMA AT PUNE, D/S OF BUNDGARDEN, MAHARASHTRA"
replace location = "KRISHNA AFTER CONFL. WITH TUNGABHADRA, SANGAMESHWARAM A.P." if location == "A/C WITH TUNGABHADRA, SANGAMESHWARAM A.P."
replace location = "KRISHNA AT D/S OF DEVASAGAR BDG.,KARNATAKA" if location == "D/S OF DEVASAGAR BDG., KARNATAKA"
replace location = "KRISHNA AT D/S OF NARAYANPURA DAM,KARNATAKA" if location == "D/S OF NARAYANPURA DAM, KARNATAKA"
replace location = "KRISHNA AT GADWAL BRIDGE, A.P." if location == "GADWAL BRIDGE, A. P."
replace location = "KRISHNA AT KRISHNA BRIDGE, KARAD, MAHARASHTRA" if location == "KARAD, MAHARASHTRA"
replace location = "KRISHNA AT KURUNDWAD IN KOLHAPUR,MAHARASHTRA" if location == "KURUNDWAD IN KOLHAPUR, MAHARASHTRA"
replace location = "KRISHNA AT MAHABALESHWAR DHOM DAM NEAR KOINA DAM,MAHARASHTRA" if location == "MAHABALESHWAR DHOM DAM NEAR KOINA DAM, MAHARASHTRA"
replace location = "KRISHNA AT RAJAPUR WEIR, MAHARASHTRA" if location == "RAJAPUR WEIR, MAHARASHTRA"
replace location = "KRISHNA AT SANGLI, MAHARASHTRA" if location == "SANGLI, MAHARASHTRA"
replace location = "KRISHNA AT TINTINI BRIDGE, KARNATAKA" if location == "TINTINI BRIDGE, KARNATAKA"
replace location = "KRISHNA AT U/S OF UGARKHURD BARRAGE,KARNATAKA" if location == "U/S OF UGARKHURD BARRAGE, KARNATAKA"
replace location = "KRISHNA AT VIJAYWADA, A.P." if location == "VIJAYWADA, A.P."
replace location = "KRISHNA AT WADAPALLY AFTER CONFL. WITH R. MUSI, A.P.(SHIFTED FROM 1220)" if location == "WADAPALLY A/C WITH R. MUSI, A.P. (SHIFTED FROM 1220)"
replace location = "Krishna D/s of Islampur" if location == "D/S OF ISLAMPUR"
replace location = "MALPRABHA AT D/S OF KHANAPUR VILLAGE,KARNATAKA" if location == "MALPRABHA AT D/S OF KHANAPUR VILLAGE, KARNATAKA"
replace location = "MALPRABHA AT WATER ABSTR. PT. TO HUBLI,DHARWAR,KARNATAKA" if location == "MALPRABHA AT WATER ABSTR. PT. TO HUBLI, DHARWAR, KARNATAKA"
replace location = "Panchaganga D/s of Kolhapur Town" if location == "PANCHAGANGA D/S OF KOLHAPUR TOWN"
replace location = "GHATPRABHA AT W.A. POINT TO GOKAK TOWN,KARNATAKA" if location == "GHATPRABHA AT W. A. POINT TO GOKAK TOWN, KARNATAKA"
replace location = "NIRA AT SAROLE BDG.ON PUNE-BANGLORE HIGHWAY, MAHARASHTRA" if location == "NIRA AT SAROLE BDG.ON PUNEBANGLORE HIGHWAY, MAHARASHTRA"

* Mahanadi
replace location = "MAHANADI AFTER CONFL. WITH R.TEL (SONEPUR D/S),ORISSA" if location == "A/C WITH R.TEL (SONEPUR D/S), ORISSA"
replace location = "MAHANADI AFTER CONFL. WITH RIVER MAND,CHHATISSGARH" if location == "A/C WITH RIVER MAND, CHHATISSGARH"
replace location = "MAHANADI AT ARRANG, RAIPUR" if location == "ARRANG, RAIPUR"
replace location = "MAHANADI AT BRAJ RAJ NAGAR U/S, ORISSA" if location == "IB AT RAJ NAGAR U/S, ORISSA"
replace location = "MAHANADI AT CUTTACK D/S, ORISSA" if location == "CUTTACK D/S, ORISSA"
replace location = "MAHANADI AT CUTTACK U/S, ORISSA" if location == "CUTTACK U/S, ORISSA"
replace location = "MAHANADI AT HIRAKUD RESERVOIR, ORISSA" if location == "HIRAKUD RESERVOIR, ORISSA"
replace location = "MAHANADI AT INTERSTATE BOUNDRY, M.P." if location == "INTERSTATE BOUNDRY CHHATISSGARH."
replace location = "MAHANADI AT KHARAD, CHHATISSGARH." if location == "KHARAD CHHATISSGARH."
replace location = "MAHANADI AT NARSINGHPUR, ORISSA" if location == "NARSINGHPUR, ORISSA"
replace location = "MAHANADI AT PARADEEPD/S, ORISSA" if location == "PARADEEP D/S, ORISSA"
replace location = "MAHANADI AT RUDRI U/S AT DHAMTORI RESERVOIR,CHHATISSGARH" if location == "RUDRI U/S AT DHAMTORI RESERVOIR, CHHATISSGARH"
replace location = "MAHANADI AT SAMBALPUR D/S, ORISSA" if location == "SAMBALPUR D/S, ORISSA"
replace location = "MAHANADI AT SAMBALPUR U/S, ORISSA" if location == "SAMBALPUR U/S, ORISSA"
replace location = "MAHANADI AT SHEORINARAYAN VILLAGE, M.P." if location == "SHEORINARAYAN VILLAGE, CHHATISSGARH."
replace location = "MAHANADI AT SIHAWA." if location == "SIHAWA"
replace location = "MAHANADI AT TIKARPADA, ORISSA" if location == "TIKARPADA, ORISSA"
replace location = "MAHANADI AT U/S OF RAJIM, M.P." if location == "U/S OF RAJIM, CHHATISSGARH."
replace location = "MAHANADI D/S (AFTER CONFL. WITH R. ONG SONEPUR U/S), ORISSA" if location == "D/S (AFTER CONFL. WITH R. ONG SONEPUR U/S), ORISSA"
replace location = "SEONATH AT SHIMGA AFTER CONFL. WITH R. KHAROON, M.P." if location == "SEONATH AT SHIMGA AFTER CONFL. WITH R. KHAROON, CHHATISSGARH"
replace location = "SEONATH AT U/S RAJNANDGAON, M.P." if location == "SEONATH AT U/S RAJNANDGAON, CHAATISSGARH"
replace location = "HASDEO AT U/S KORBA, M.P." if location == "HASDEO AT U/S KORBA, CHHATISSGARH"
replace location = "HASDEO AT U/S OF CHAMPA, M.P." if location == "HASDEO AT U/S OF CHAMPA, CHHATISSGARH"
replace location = "KHAROON RIVER A/C KHAPRI DRAIN." if location == "KHAROON RIVER A/C KHAPRI DRAIN"

* Mahi
replace location = "MAHI (D/S) CONF WITH R. CHAP (UNDER SAGWARA-SARHI RD. BDG.),RAJASTHAN" if location == "(D/S) CONF WITH R. CHAP , RAJASTHAN"
replace location = "MAHI AFTER CONF. WITH ANAS AT PARDI (BANASWADA),GUJARAT." if location == "A/C ANAS AT PARDI (BANASWADA), GUJARAT."
replace location = "MAHI AT BADNAWAR, M.P." if location == "BADNAWAR, M.P."
replace location = "MAHI AT MUJPUR" if location == "MUJPUR"
replace location = "MAHI AT SEVALIA, GUJARAT" if location == "SEVALIA, GUJARAT"
replace location = "MAHI AT UMETA BRIDGE" if location == "UMETA BRIDGE"
replace location = "MAHI AT VASAD, GUJARAT" if location == "VASAD, GUJARAT"
replace location = "MAHI AT VIRPUR, GUJARAT" if location == "VIRPUR, GUJARAT"
replace location = "MAHI NEAR RAJASTHAN BORDER AT KADANA DAM,GUJARAT" if location == "NEAR RAJASTHAN BORDER AT KADANA DAM, GUJARAT"

* Narmada
replace location = "NARMADA AT BADWANI, M.P." if location == "BADWANI, M.P."
replace location = "NARMADA AT BHARUCH,ZADESHVAR,GUJARAT" if location == "BHARUCH, ZADESHVAR, GUJARAT"
replace location = "NARMADA AT CHANDOD, GUJARAT" if location == "CHANDOD, GUJARAT"
replace location = "NARMADA AT D/S OF OMKARESHWAR, M.P." if location == "DS OF OMKARESHWAR M.P."
replace location = "NARMADA AT GARUDESHWAR, GUJARAT" if location == "GARUDESHWAR, GUJARAT"
replace location = "NARMADA AT HOSHANGABAD D/S, M.P." if location == "HOSHANGABAD D S M.P."
replace location = "NARMADA AT HOSHANGABAD U/S, M.P." if location == "HOSHANGABAD U S M.P."
replace location = "NARMADA AT MAHESHWAR, M. P." if location == "MAHESHWAR, M.P."
replace location = "NARMADA AT MANDLA NEAR ROAD BDG.,M.P." if location == "MANDLA NEAR ROAD BDG. M.P."
replace location = "NARMADA AT MANDLESHWAR, M.P." if location == "MANDLESHWAR M.P."
replace location = "NARMADA AT NARSINGHPUR, M.P." if location == "NARSINGHPUR M.P."
replace location = "NARMADA AT PANETHA, GUJARAT" if location == "PANETHA, GUJARAT"
replace location = "NARMADA AT SETHANIGHAT, M.P." if location == "SETHANIGHAT M.P."
replace location = "NARMADA NEAR SOURCE AT AMARKANTAK, M.P." if location == "AMARKANTAK M.P."
replace location = "CHOTA TAWA BEFORE CONFL. WITH RIVER NARMADA,M.P." if location == "CHOTA TAWA B/C WITH RIVER NARMADA, M.P."

* Sabarmati
replace location = "SABARMATI AFTER CONF. WITH MESHWA AT VAUTHA (NEAR DHOKLA),GUJARAT" if location == "A/C WITH MESHWA AT VAUTHA (NEAR DHOKLA), GUJARAT"
replace location = "SABARMATI AT AHMEDABAD AT V.N. BRIDGE,GUJARAT" if location == "AHMEDABAD AT V.N. BRIDGE, GUJARAT"
replace location = "SABARMATI AT DHAROI DAM, GUJARAT" if location == "DHAROI DAM, GUJARAT"
replace location = "SABARMATI AT GANDHI NAGAR CHILODA BRIDGE,LEKAWADA,GUJARAT" if location == "GANDHI NAGAR CHILODA BRIDGE, LEKAWADA, GUJARAT"
replace location = "SABARMATI AT KHEROJ BRIDGE, GUJARAT" if location == "KHEROJ BRIDGE, GUJARAT"
replace location = "SABARMATI AT MAHUDI JAIN TEMPLE, 150 KM. FORM ORIGIN" if location == "MAHUDI JAIN TEMPLE, GUJARAT"
replace location = "SABARMATI AT RAILWAY BRIDGE AHMEDABAD, GUJARAT" if location == "RAILWAY BRIDGE AHMEDABAD, GUJARAT"
replace location = "SABARMATI AT VILL. MIROLI TALUKA DASCROI,AHMEDABAD,GUJARAT" if location == "VILL. MIROLI TALUKA DASCROI, AHMEDABAD, GUJARAT"

* Tapi
replace location = "TAPI AT AJNAND VILLAGE, MAHARASHTRA" if location == "AJNAND VILLAGE, MAHARASHTRA"
replace location = "TAPI AT BHUSAWAL U/S, MAHARASHTRA" if location == "BHUSAWAL US MAHARASHTRA"
replace location = "TAPI AT BURHANPUR, M.P." if location == "BURHANPUR M.P."
replace location = "TAPI AT HATHNUR, M.P." if location == "HATHNUR M.P."
replace location = "TAPI AT KATHORE, (NH-8 BRIDGE), GUJARAT" if location == "KATHORE, (NH-8 BRIDGE), GUJARAT"
replace location = "TAPI AT MANDAVI, GUJARAT" if location == "MANDAVI, GUJARAT"
replace location = "TAPI AT NEPANAGAR, M.P." if location == "NEPANAGAR M.P."
replace location = "TAPI AT SURAT U/S KATHORE, GUJARAT" if location == "SURAT U/S KATHORE, GUJARAT"
replace location = "TAPI AT UKAI, SHERULA BRIDGE, GUJARAT" if location == "UKAI, SHERULA BRIDGE, GUJARAT"
replace location = "TAPI AT UPHAD VILLAGE, MAHARASHTRA" if location == "UPHAD VILLAGE, MAHARASHTRA"
replace location = "GIRNA AT MALEGAON (MANMAD), MAHARASHTRA" if location == "GIRNA AT JALGAON, MAHARASHTRA"

save "${mypath}/Data/Water Data/Intermediate Data/temp2005.dta", replace

***********************************
* 3. Merging

use "${mypath}Data/Water Data/Intermediate Data/05_matching.dta", clear
keep stncode river location state city
order stncode state city river location

egen group = group(location)
bys group: keep if _n == 1
merge 1:1 location using "${mypath}Data/Water Data/Intermediate Data/temp2005.dta"
ta _merge
drop if _merge == 1 /* keeps all 2005 observations even if they are unmatched with city names */
drop group

save "${mypath}Data/Water Data/Intermediate Data/waterpol2005.dta", replace
erase "${mypath}Data/Water Data/Intermediate Data/temp2005.dta"

cd "${mypath}Data/Water Data"
