***********************************************************************************

* File: AppFigure1_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Appendix Figure 1 in the paper. 
	Appendix Figure 1 gives kernel density graphs of ambient air quality, surface water
	quality, and infant morality.

Structure:
1. Figure 3A. Kernel Densities of Ambient Air Quality
2. Figure 3B. Kernel Density Graphs of Surface Water Quality
3. Figure 3C. Kernel Density Graph of Infant Mortality
*/

***********************************************************************************

clear all
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/AppFigure11_01102014.txt", replace t

**************************************
* Figure 3A. Kernel Densities of Ambient Air Quality

*** Air ***
cd "${mypath}Output/AF1"
use "${mypath}Data/Air Data/Intermediate Data/e_airpol_city.dta", clear

kdensity e_spm_mean if year < 1991, title("") note("") ///
	addplot(kdensity e_spm_mean if year > 2003, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean PM", margin(medsmall)) legend(rows(1) label(1 "1987-1990") label(2 "2004-2007")) ///
	scheme(s1mono) saving(kdens_spm.gph, replace)

kdensity e_so2_mean if year < 1991, title("") note("") lwidth(medthick) ///
	addplot(kdensity e_so2_mean if year > 2003, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean SO2", margin(medsmall)) legend(rows(1) label(1 "1987-1990") label(2 "2004-2007")) ///
	scheme(s1mono) saving(kdens_so2.gph, replace)

kdensity e_no2_mean if year < 1991, title("") note("") lwidth(medthick) ///
	addplot(kdensity e_no2_mean if year > 2003, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean NO2", margin(medsmall)) legend(rows(1) label(1 "1987-1990") label(2 "2004-2007")) ///
	scheme(s1mono) saving(kdens_no2.gph, replace)

graph combine kdens_spm.gph kdens_so2.gph kdens_no2.gph, cols(1) scheme(s1mono) ysize(5) xsize(2)
	graph export "kdens_air.eps", replace  	

erase kdens_spm.gph
erase kdens_so2.gph
erase kdens_no2.gph
	
***************************************
* Figure 3B. Kernel Density Graphs of Surface Water Quality
	
*** Water ***
use "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear
	
kdensity bod if year < 1990 & bod < 20, title("") note("") lwidth(medthick) ///
	addplot(kdensity bod if year > 2001 & bod < 20, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean BOD", margin(small)) legend(rows(1) label(1 "1986-1989") label(2 "2002-2005")) ///
	scheme(s1mono) saving(kdens_bod.gph, replace)

kdensity lnfcoli if year < 1990, title("") note("") lwidth(medthick) ///
	addplot(kdensity lnfcoli if year > 2001, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean Ln(FColi)", margin(small)) legend(rows(1) label(1 "1986-1989") label(2 "2002-2005")) ///
	scheme(s1mono) saving(kdens_lnfcoli.gph, replace)

kdensity do if year < 1990, title("") note("") lwidth(medthick) xlab(0 4 8 12) ///
	addplot(kdensity do if year > 2001, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean DO", margin(small)) legend(rows(1) label(1 "1986-1989") label(2 "2002-2005")) ///
	scheme(s1mono) saving(kdens_do.gph, replace)

graph combine kdens_bod.gph kdens_lnfcoli.gph kdens_do.gph, cols(1) scheme(s1mono) ysize(5) xsize(3)	
	graph export "kdens_water.eps", replace  		

erase kdens_bod.gph
erase kdens_lnfcoli.gph
erase kdens_do.gph
********************************************
* Figure 3C. Kernel Density Graph of Infant Mortality

*** Infant Mortality ***
u "${mypath}Data/Infant Mortality/IM City/Final Data/im_air.dta", clear
joinby state city year using "${mypath}Data/Infant Mortality/IM City/Final Data/im_water.dta", unmatched(both)

keep if c_IM<.

	
kdensity c_IM if year < 1991 & c_IM < 52.8, title("") note("") lwidth(medthick) ///
	addplot(kdensity c_IM if year > 2000 & c_IM < 52.8, lwidth(medthick) lpattern(dash)) ///
	xtit("Mean IM Rate", margin(small)) legend(rows(1) label(1 "1987-1990") label(2 "2001-2004")) ///
	scheme(s1mono) saving(kdens_im.gph, replace)

graph export "kdens_im.eps", replace
erase kdens_im.gph

cd "${mypath}"
log close
