***********************************************************************************
* File: AppTable1_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Appendix Table 1 in the paper. 
	Appendix Table 1 provides summary statistics, by year, of air quality, water quality,
	and infant mortality.

Structure:
1. Appendix Table 1. Summary Statistics, By Year (Air and Water and IM; Entire Sample)
*/

***********************************************************************************

clear all
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/AppTable1_01102014.txt", replace t

***************************
* Appendix Table 1. Summary Statistics By Year

* AIR: Open city-year dataset
use "${mypath}Data/Air Data/Intermediate Data/e_airpol_city.dta", clear
cd "${mypath}Output/AT1"

* Duplicate pollution monitor-year means so I can collapse means into both sample means and sample standard devs
g spm_sd = e_spm_mean
g so2_sd =  e_so2_mean
g no2_sd =  e_no2_mean
g spm_y = (e_spm_mean < .)
g so2_y = (e_so2_mean < .)
g no2_y = (e_no2_mean < .)
rename e_spm_mean spm_mean
rename e_so2_mean so2_mean
rename e_no2_mean no2_mean
collapse (mean) spm_mean so2_mean no2_mean (sd) spm_sd so2_sd no2_sd (sum) spm_y so2_y no2_y, by(year)
order spm* so2* no2*

* Reshape
reshape long spm_ so2_ no2_, i(year) j(stat) string
replace stat = "N" if stat == "y"
drop if stat=="sd"

foreach var of varlist spm_ so2_ no2_ {
	replace `var' = round(`var', .01)
	replace `var' = round(`var', .01)
	replace `var' = round(`var', .01)
} 
* Export
outsheet using airstat.txt, replace
	* From here, I re-format in Excel

* WATER: Open city-year dataset
use "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear

* Vars for collapse into summary stats
foreach x in "bod" "do" "lnfcoli" {
	g `x'_sd = `x'
	rename `x' `x'_mean
}
g bod_y = (bod_mean < .)
g do_y = (do_mean < .)
g lnfcoli_y = (lnfcoli_mean < .)

collapse (mean) *mean (sd) *sd (sum) bod_y do_y lnfcoli_y, by(year)
order bod* lnfcoli* do*

* Reshape
reshape long bod_ lnfcoli_ do_, i(year) j(stat) string
replace stat = "N" if stat == "y"
order year stat bod_ lnfcoli_ do_
drop if stat=="sd"

foreach var of varlist bod_ do_ lnfcoli_ {
	replace `var' = round(`var', .01)
}
* Export
outsheet using waterstat.txt, replace
	* From here, I re-format in Excel

* INFANT MORTALITY
*****
***** Note. The below commands result in Stata keeping ALL data from cities which appear even just once in the air or water data.
*****
u "${mypath}Data/Infant Mortality/IM City/Final Data/im_air.dta", clear
joinby state city year using "${mypath}Data/Infant Mortality/IM City/Final Data/im_water.dta", unmatched(both)

keep if c_IM<.

* Vars for collapse into summary stats
rename c_IM im_mean
g im_y = 1

collapse (mean) im_mean (sum) im_y, by(year)

* Reshape
reshape long im_, i(year) j(stat) string
replace stat = "N" if stat == "y"
order year stat im_

replace im_ = round(im_, .01)

* Export
outsheet using IMstat.txt, replace
	* From here, I re-format in Excel
