***********************************************************************************
* File: AppTable2_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Author: Samuel Stolper
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Appendix Table 2 in the paper. 
	Appendix Table 2 provides the distribution of air and water pollution policies
	across all Indian cities, by year.

Structure:
1. Appendix Table 2. Pollution Policy Coverage in India, By Year
*/

clear
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/AppTable2_01102014.txt", replace t

***************************
* Appendix Table 2. Distribution of Policies

/* Air */
cd "${mypath}Output/AT2"
u "${mypath}Data/Air Data/Final Data/Combined.dta", clear

/* Keep only obs with some electronic air pollution info */
keep if e_spm_mean < . | e_spm_max < . | e_spm_min < . | e_so2_mean < . | e_so2_max < . | e_so2_min < . | e_no2_mean < . | e_no2_max < . | e_no2_min < . 

/* Create variables to facilitate total city count by year */
* Generate variable for total cities IN OUR SAMPLE
g totalcities = 1

/* Collapse policies into yearly counts */
collapse (sum) totalcities, by(year)

* Total number of cities covered by SCAP (disregarding our sample)
g actionplan_tot = 0
replace actionplan_tot = 1 if year > 1997 & year < 2003
replace actionplan_tot = 12 if year == 2003
replace actionplan_tot = 17 if year > 2003

* Total number of cities covered by CatConverters (disregarding our sample)
g catconverter_tot = 0
replace catconverter_tot = 4 if year >= 1996 & year < 1999
replace catconverter_tot = 49 if year >= 1999 

order totalcities actionplan_tot catconverter_tot

outsheet year actionplan_tot catconverter_tot using airpolicies.csv, comma replace

/* Water */
u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear

/* Create variables to facilitate total city count by year */
g totalcities = 1

/* Collapse policies into yearly counts */
collapse (sum) totalcities, by(year)

g action_tot = 0
replace action_tot = 25 if year >= 1986
replace action_tot = 97 if year > 1993
replace action_tot = 160 if year >= 1995
replace action_tot = . if year > 2005

order totalcities action_tot

outsheet year action_tot using waterpolicies.csv, comma replace
/* From here, I re-format in Excel */
