***********************************************************************************

* File: Figure4_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by: Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Figure 4 for the paper. Figure 4
	plots trends in Air Quality, Water Quality, and Infant Mortality in India during over the
	course of the sampler period.
*/

***********************************************************************************

clear all
set mem 500m
set more off

* Establish log
cap log close
log using "${mypath}Log/Figure4_01102014.txt", replace t

cd "${mypath}Output/F4"

*** AIR ***

* Use full sample AP dataset
u "${mypath}Data/Air Data/Final Data/combined.dta", clear

* To create three separate graphs in one panel
* Collapse three variables to be used
collapse (mean) e_spm_mean e_no2_mean e_so2_mean, by(year)

* Rename to clarify reshape
rename e_spm_mean meantsp
rename e_no2_mean meanno2
rename e_so2_mean meanso2

* Reshape
reshape long mean, i(year) j(pollutant) string

* Clean names for graph display
replace pollutant = "3" if pollutant == "no2"
replace pollutant = "2" if pollutant == "so2"
replace pollutant = "1" if pollutant == "tsp"
destring pollutant, replace

* Label define for displaying graphs in proper order
la de poll 1 "PM" 2 "SO2" 3 "NO2"
la val pollutant poll

* Create a local for a superscript '3'
local cube = char(179)

* Graph
tw connected mean year, by(pollutant, rows(1) rescale) lwidth(thick) msize(medium) ///
	xtit("Year", size(medium) margin(small)) ytit("Mean Pollution" "({&mu}g/m`cube')", size(medium) margin(small)) /// /*"*/ 
	xlab(1987 1992 1997 2002 2007) aspectratio(.8) xsize(7) scheme(s1mono) /*"*/
graph export ap_trends.eps, replace

*** WATER ***

* Use full sample city-year water data
use "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear

* To create three separate graphs in one panel
collapse (mean) bod do fcoli, by(year)

* Scale down Fcoli
replace fcoli = fcoli/1000

* Rename vars and reshape
rename bod meanbod
rename do meando
rename fcoli meanfcoli
reshape long mean, i(year) j(pollutant) string

* Clean names for graph display
replace pollutant = "3" if pollutant == "do"
replace pollutant = "2" if pollutant == "fcoli"
replace pollutant = "1" if pollutant == "bod"
destring pollutant, replace

* Label define for displaying graphs in proper order
la de poll 1 "BOD (mg/l)" 2 "FColi (1000's/100 ml)" 3 "DO (mg/l)"
la val pollutant poll

* Graph
tw connected mean year, by(pollutant, rows(1) rescale) lwidth(thick) msize(medium) ///
	xtit("Year", size(medium) margin(small)) ytit("Mean Pollution", size(medium) margin(small)) /// /*"*/ 
	xlab(1986 1991 1996 2001 2005) aspectratio(.8) xsize(7) scheme(s1mono) /*"*/
graph export wp_trends.eps, replace

*** INFANT MORTALITY ***

u "${mypath}Data/Infant Mortality/IM City/Final Data/im_air.dta", clear
joinby state city year using "${mypath}Data/Infant Mortality/IM City/Final Data/im_water.dta", unmatched(both)

keep if c_IM<.

collapse (mean) c_IM, by(year)
g outcome = "Infant Mortality"

tw connected c_IM year, by(outcome) lwidth(thick) msize(medium) ///
	xtit("Year", size(medium) margin(small)) ytit("Mean IM Rate" "(Deaths/1000 Births)", size(medium) margin(small)) /// /*"*/ 
	xlab(1987 1991 1995 1999 2004) aspectratio(.8) xsize(7) scheme(s1mono) /*"*/
	
graph export im_trends.eps, replace
