***********************************************************************************

* File: Figure6_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Figure 6 in the paper. Figure 6
	plots the water policy event-study estimates developed in the first stage of the two-stage
	regression analysis. 

	
Structure:
1. NRCP and BOD
2. NRCP and LNFCOLI
3. NRCP and DO
4. Combine graphs, erase old graphs
*/

***********************************************************************************

clear all
set more off
set mem 500m
set matsize 800

* Establish log
cap log close
log using "${mypath}Log/Figure6_01102014.txt", replace t

*******************************
* NRCP and BOD.

cd "${mypath}Output/F6"
u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear

cap egen cityriver = group(city river)
foreach var of varlist month_* {
	replace `var' = 0 if year == 2005
}
cap drop temp*
egen yap1city = max(yap1), by(cityriver)
egen gap1city = max(gap1), by(cityriver)
egen gap2city = max(gap2), by(cityriver)
egen nrcpcity = max(nrcp), by(cityriver)
egen dapcity = max(dap), by(cityriver)
egen gomtiap1city = max(gomtiap1), by(cityriver)
g temp2 = 1995 if nrcpcity==1
replace temp2 = 1993 if yap1city==1 | gap2city==1 | dapcity==1 | gomtiap1city==1
replace temp2 = 1985 if gap1city==1
egen temp3 = min(year), by(cityriver) 
g tau = year - temp2 if temp2 > temp3 & bod<.
g neveradopt = temp2 >= .
g tempx = 1 if (yap1==1 | gap1==1 | gap2==1 | nrcp==1 | dap==1 | gomtiap1==1) & bod<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(cityriver)
ta tempy if temp2<., missing		// no cities fitting this description.

g temp4 = tau >= 3 & tau < .
g temp5 = tau <= -3 & tau < .
egen Mtemp4 = max(temp4), by(cityriver) 
egen Mtemp5 = max(temp5), by(cityriver)
bys state city: egen count = count(bod)
g use = (Mtemp4 == 1 & Mtemp5 == 1) | (neveradopt == 1 & count>1)
cap g one = 1
keep if use == 1
drop if bod >= .
ta tau
forv tau = 7(-1)1 {
	g taum`tau' = tau == -`tau'
	la var taum`tau' "This obs is `tau' years before problem area began"
}
forv tau = 0/10 {
	g tau`tau' = tau == `tau'
	la var tau`tau' "This obs is `tau' years after problem area began"
}
g tauL = tau<-7
g tauR = tau>10 & tau<.

xi: reg bod taum7-taum2 tau0-tau10 tauL tauR lit_urban pce i.cityriver i.year [aw = pop_urban]
mat M = e(b)'
svmat M
replace M1 = . if _n >= 18
g n = _n - 8 in 1/18
tsset one n 
g temp6 = L.M1
replace M1 = temp6 if _n >= 8
replace M1 = 0 if _n == 7

tw connected M1 n if _n <= 18, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on BOD") ///
	xline(0, lpattern(dash)) ///
	xtit("Years since added to NRCP", margin(medsmall)) ///
	scheme(s1color) ///
	xlab(-7 -6 -3 0 3 6 9 10) ///
	saving(taus_bod, replace)

*******************************
* NRCP and LNFCOLI.

u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear

cap egen cityriver = group(city river)
foreach var of varlist month_* {
	replace `var' = 0 if year == 2005
}

cap drop temp*
egen yap1city = max(yap1), by(cityriver)
egen gap1city = max(gap1), by(cityriver)
egen gap2city = max(gap2), by(cityriver)
egen nrcpcity = max(nrcp), by(cityriver)
egen dapcity = max(dap), by(cityriver)
egen gomtiap1city = max(gomtiap1), by(cityriver)
g temp2 = 1995 if nrcpcity==1
replace temp2 = 1993 if yap1city==1 | gap2city==1 | dapcity==1 | gomtiap1city==1
replace temp2 = 1985 if gap1city==1
egen temp3 = min(year), by(cityriver) 
g tau = year - temp2 if temp2 > temp3 & lnfcoli<.
g neveradopt = temp2 >= .
g tempx = 1 if (yap1==1 | gap1==1 | gap2==1 | nrcp==1 | dap==1 | gomtiap1==1) & lnfcoli<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(cityriver)
ta tempy if temp2<., missing		// 2 cities, but there is no pre-data, so leave them to be dropped.

g temp4 = tau >= 3 & tau < .
g temp5 = tau <= -3 & tau < .
egen Mtemp4 = max(temp4), by(cityriver) 
egen Mtemp5 = max(temp5), by(cityriver)
bys state city: egen count = count(lnfcoli)
g use = (Mtemp4 == 1 & Mtemp5 == 1) | (neveradopt == 1 & count>1)
cap g one = 1
keep if use == 1
drop if lnfcoli >= .
ta tau
forv tau = 7(-1)1 {
	g taum`tau' = tau == -`tau'
	la var taum`tau' "This obs is `tau' years before problem area began"
}
forv tau = 0/10 {
	g tau`tau' = tau == `tau'
	la var tau`tau' "This obs is `tau' years after problem area began"
}
g tauL = tau<-7
g tauR = tau>10 & tau<.

xi: reg lnfcoli taum7-taum2 tau0-tau10 tauL tauR lit_urban pce i.cityriver i.year [aw = pop_urban]
mat M = e(b)'
svmat M
replace M1 = . if _n >= 18
g n = _n - 8 in 1/18
tsset one n 
g temp6 = L.M1
replace M1 = temp6 if _n >= 8
replace M1 = 0 if _n == 7
tw connected M1 n if _n <= 18, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on Ln(FColi)") ///
	xline(0, lpattern(dash)) ///
	xtit("Years since added to NRCP", margin(medsmall)) ///
	scheme(s1color) ///
	xlab(-7 -6 -3 0 3 6 9 10) ///
	saving(taus_lnfcoli, replace)

*******************************
* NRCP and DO.

u "${mypath}Data/Water Data/Final Data/india_waters_cityyear.dta", clear

cap egen cityriver = group(city river)
foreach var of varlist month_* {
	replace `var' = 0 if year == 2005
}

cap drop temp*
egen yap1city = max(yap1), by(cityriver)
egen gap1city = max(gap1), by(cityriver)
egen gap2city = max(gap2), by(cityriver)
egen nrcpcity = max(nrcp), by(cityriver)
egen dapcity = max(dap), by(cityriver)
egen gomtiap1city = max(gomtiap1), by(cityriver)
g temp2 = 1995 if nrcpcity==1
replace temp2 = 1993 if yap1city==1 | gap2city==1 | dapcity==1 | gomtiap1city==1
replace temp2 = 1985 if gap1city==1
egen temp3 = min(year), by(cityriver) 
g tau = year - temp2 if temp2 > temp3 & do<.
g neveradopt = temp2 >= .
g tempx = 1 if (yap1==1 | gap1==1 | gap2==1 | nrcp==1 | dap==1 | gomtiap1==1) & do<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if temp2<., by(cityriver)
ta tempy if temp2<., missing		// no cities fitting this description.

g temp4 = tau >= 3 & tau < .
g temp5 = tau <= -3 & tau < .
egen Mtemp4 = max(temp4), by(cityriver) 
egen Mtemp5 = max(temp5), by(cityriver)
bys state city: egen count = count(do)
g use = (Mtemp4 == 1 & Mtemp5 == 1) | (neveradopt == 1 & count>1)
cap g one = 1
keep if use == 1
drop if do >= .
ta tau
forv tau = 7(-1)1 {
	g taum`tau' = tau == -`tau'
	la var taum`tau' "This obs is `tau' years before problem area began"
}
forv tau = 0/10 {
	g tau`tau' = tau == `tau'
	la var tau`tau' "This obs is `tau' years after problem area began"
}
g tauL = tau<-7
g tauR = tau>10 & tau<.

xi: reg do taum7-taum2 tau0-tau10 tauL tauR lit_urban pce i.cityriver i.year [aw = pop_urban]
mat M = e(b)'
svmat M
replace M1 = . if _n >= 18
g n = _n - 8 in 1/18
tsset one n 
g temp6 = L.M1
replace M1 = temp6 if _n >= 8
replace M1 = 0 if _n == 7

tw connected M1 n if _n <= 18, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on DO") ///
	xline(0, lpattern(dash)) ///
	xtit("Years since added to NRCP", margin(medsmall)) ///
	scheme(s1color) ///
	xlab(-7 -6 -3 0 3 6 9 10) ///
	saving(taus_do, replace)

* Combine graphs, erase old graphs
graph combine taus_bod.gph taus_lnfcoli.gph taus_do.gph, rows(1) scheme(s1color) ysize(2.5) xsize(9) iscale(*1.2)
graph export F6.eps, replace	
erase taus_bod.gph
erase taus_lnfcoli.gph
erase taus_do.gph	
