***********************************************************************************

* File: Figure8_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Figure 8 in the paper. Figure 8
	plots an event study of the effect of catalytic converters on infant mortality. The
	event year estimates are derived from the first stage of the two-stage regression
	approach.

*/

***********************************************************************************

clear all
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/Figure8_01102014.txt", replace t

***************************
* Infant Mortality
u "${mypath}Data/Infant Mortality/IM City/Final Data/im_air.dta", clear
cd "${mypath}Output/F8"

egen IMtemp = max(c_IM), by(state city)
drop if IMtemp >= .
drop IMtemp
egen city_id = group(city)
bys state city: egen count = count(c_IM)

egen temp3 = min(year), by(city_id)
egen temp35 = max(year), by(city_id) 
g tauCAT = year - catyear if catyear > temp3 & c_IM<.
g neveradoptCAT = (catyear >= . | temp35 < catyear)
g tempx = 1 if year>=catyear & catyear<. & c_IM<.		// the following 3 lines of code determine whether there are any cities which enacted the policy but are missing pollution data for ALL post-policy years
egen tempy = min(tempx) if catyear<., by(city_id)
ta tempy if catyear<., missing		// many cities fit this description. they should be included as (effectively) 'neveradopt' cities.
replace neveradoptCAT = 1 if tempy>=. & catyear<.		
replace tauCAT = . if tempy>=. & catyear<.

g temp4 = tauCAT >= 3 & tauCAT < .
g temp5 = tauCAT <= -3 & tauCAT < .
egen Mtemp4 = max(temp4), by(city_id) 
egen Mtemp5 = max(temp5), by(city_id)
g useCAT = (Mtemp4 == 1 & Mtemp5 == 1 & count > 1) | (neveradoptCAT == 1 & count > 1)

drop if useCAT==0
drop if c_IM >= .
ta tauCAT
g one = 1

forv tau = 10(-1)1 {
	g tauCATm`tau' = tauCAT == -`tau'
	la var tauCATm`tau' "This obs is `tau' years before catalytic converters made mandatory"
}
forv tau = 0/5 {
	g tauCAT`tau' = tauCAT == `tau'
	la var tauCAT`tau' "This obs is `tau' years after catalytic converters made mandatory"
}
g tauCATL = tauCAT<-10
g tauCATR = tauCAT>5 & tauCAT<.

xi: reg c_IM tauCATm10-tauCATm2 tauCAT0-tauCAT5 tauCATL tauCATR lit_urban mean i.city i.year [aw = c_birth]	
mat N = e(b)'
svmat N
replace N1 = . if _n >= 16
g n = _n - 11 in 1/16
tsset one n 
g temp6 = L.N1
replace N1 = temp6 if _n >= 11
replace N1 = 0 if _n == 10

tw connected N1 n if _n <= 16, lwidth(medthick) ///
	sort yline(0, lpattern(dash)) ///
	ytit("Effect on IM Rate", margin(medsmall)) ///
	xline(0, lpattern(dash)) ///
	xtit("Years since Catalytic Converters Mandated", margin(medsmall) size(small)) ///
	scheme(s1color) ///
	subtit("Policy:  Catalytic Converters") ///
	xlab(-10 -5 0 5) ///
	saving(taus_catconIM, replace)			

graph export F8.eps, replace
graph export F8.png, replace
erase taus_catconIM.gph
