***********************************************************************************

* File: Figure9_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
* Modified by Jon Petkun (jbpetkun@mit.edu)

/*
Objective: The objective of this program is to generate Figure 9 in the paper. Figure 9
	graphs total nationwide references to air and water pollution in the Times of India
	newspaper over the course of the sample period.

*/

***********************************************************************************

***********************************************************************************
* Section 0: Set-up
***********************************************************************************

clear all
set more off
set mem 500m

* Establish log
cap log close
log using "${mypath}Log/Figure9_01102014.txt", replace t

***********************************************************************************
* Section 1: Generate summary graphs of Times of India data
***********************************************************************************

#delimit ;
use "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", clear;

* Collapse into nationwide time series ;
collapse (sum) *_references, by(year);

* Plot annual nation-wide references to air and water pollution
* Nationwide air and water references in bar graph ;
graph bar (sum) air_references water_references, legend(label(1 "Air Pollution")) legend(label(2 "Water Pollution")) 
	ytitle("Number of References") blabel(total) ysc(r(0 400)) ylabel(0(100)400) bar(1, color(gs2)) bar(2, color(gs13))
	saving("${mypath}Output/F9/AirWaterBar.gph", replace);
graph export "${mypath}Output/F9/F9_AirWaterBar.eps", replace;

* Nationwide air and water in line chart ;
graph twoway (connected air_references year, msymbol(O) mcolor(gs2) lcolor(gs2))
	(connected water_references year, msymbol(T) mcolor(gs6) lcolor(gs13)),
	xsc(r(1986 2007)) xlabel(1986(3)2007) 
	ysc(r(0 60)) ylabel(0(10)60) 
	xtitle("Year") ytitle("Number of References") 
	legend(label(1 "Air Pollution")) legend(label(2 "Water Pollution"))
	saving("${mypath}Output/F9/AirWaterLine.gph", replace);
graph export "${mypath}Output/F9/F9_AirWaterLine.eps", replace;

/*
* Nationwide air and water in bar graph, excluding Delhi ; 
use "${mypath}Data/Controls/Times of India/Intermediate Data/news_references_stateyear.dta", clear;
drop if state == "Delhi" ;
collapse (sum) *_references, by(year) ;
graph bar (sum) air_references water_references, legend(label(1 "Air Pollution")) legend(label(2 "Water Pollution")) 
	ytitle("Number of References") blabel(total) ysc(r(0 400)) ylabel(0(100)400) bar(1, color(gs2)) bar(2, color(gs13))
	saving("${mypath}Output/F9/AirWaterBar_wo_Delhi.gph", replace);
graph export "${mypath}Output/F9/AirWaterBar_wo_Delhi.eps", replace;

* Nationwide air and water in line chart, excluding Delhi ;
graph twoway (connected air_references year, msymbol(O) mcolor(gs2) lcolor(gs2))
	(connected water_references year, msymbol(T) mcolor(gs6) lcolor(gs13)),
	xsc(r(1986 2007)) xlabel(1986(3)2007) 
	ysc(r(0 60)) ylabel(0(10)60) 
	xtitle("Year") ytitle("Number of References") 
	legend(label(1 "Air Pollution")) legend(label(2 "Water Pollution"))
	saving("${mypath}Output/F9/AirWaterLine_wo_Delhi.gph", replace);
graph export "${mypath}Output/F9/AirWaterLine_wo_Delhi.eps", replace;
*/
#delimit cr

***********************************************************************************
* Section 2: Clean-up
***********************************************************************************
erase "${mypath}Output/F9/AirWaterBar.gph"
erase "${mypath}Output/F9/AirWaterLine.gph"
* erase "${mypath}Output/F9/AirWaterBar_wo_Delhi.gph"
* erase "${mypath}Output/F9/AirWaterLine_wo_Delhi.gph"
log close
