***********************************************************************************

* File: Table5_Figure7_01102014.do
* Author: Jon Petkun (jbpetkun@mit.edu), utilizing user-generate commands written by Tom Zimmerman (tzimmerm@fas.harvard.edu)
* Date: August 19, 2013
* Paper: Greenstone & Hanna 2013, Environmental Regulations & Pollution in India
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This program performs QLR Breakpoint tests on the air and water pollution policies. This file
	generates both Table 5 and Figure 7 for the academic paper.

Structure:
0. Stata Setup
1. Run Breakpoint Tests
	a. CC taus
	b. NRCP taus
2. Clean-up

IMPORTANT NOTE: This program uses two .ado files: qlrmean.ado and qlrtrend.ado.
	These files can be found in the "Save to Ado Folder" subfolder. These need
	to be copied to the Ado directory referenced by your installation of Stata.
*/

***********************************************************************************
* 0. Setup
***********************************************************************************

* Reset memory options
clear all
version 12.0
set more off
set mem 500m
set matsize 10000

* Establish log
cap log close
log using "${mypath}Log/Table5_Figure7_01102014.txt", replace t

***********************************************************************************
* 1. Run Breakpoint Tests
***********************************************************************************

foreach pollutant in spm so2 no2 {
	use "${mypath}Data/Air Data/Final Data/sigmas_`pollutant'.dta", clear
	rename tauCAT tau
	qlrtrend taub, trim(4) filename("${mypath}Output/T5/T5_qlrtrend_`pollutant'.txt")
	graph export "${mypath}Output/F7/F7_Trend_`pollutant'.png", replace width(4000)
	graph export "${mypath}Output/F7/F7_Trend_`pollutant'.eps", replace 
}

foreach pollutant in bod lnfcoli do {
	use "${mypath}Data/Water Data/Final Data/sigmas_`pollutant'.dta", clear
	qlrtrend taub, trim(4) filename("${mypath}Output/T5/T5_qlrtrend_`pollutant'.txt")
	* graph export "${mypath}Output/F7/F7_Trend_`pollutant'.png", replace width(4000)
}

***********************************************************************************
* 2. Clean-up
***********************************************************************************

log close
