***********************************************************************************
*
* File: india_pollution_master_01102014.do
* Author: Jon Petkun, jbpetkun@mit.edu
* Date: 10 January 2014
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu
*
/*
Objective: This file calls all other do-files for the India pollution project.

Structure:
1. Set-up 
2. Run data processing/cleaning do-files
3. Run analysis do-files (construct tables & figures)
4. Clean-up
*/

***********************************************************************************
* Section 1: Set-up
***********************************************************************************
display "Section 1: Set-up"

clear all
set more off
set mem 500m
version 9.0

*   A global macro ("mypath") establishes the working directory.
*	Replace with appropriate file directory before using. See ReadMe document
*	for additional information. 
*global mypath "/Users/jbpetkun/Dropbox/India Pollution/Greenstone and Hanna (2014) Replication Files - 01102014/"
global mypath "C:\Users\sberkou\Dropbox\EPoD\NRHM_KARNATAKA\Greenstone and Hanna (2014) Replication Files - 01102014\Greenstone and Hanna (2014) Replication Files (non-zipped folder)\"

* Establish log file
capt log close
log using "${mypath}Log/india_pollution_master_01102014.log", replace t

***********************************************************************************
* Section 2: Run data processing/cleaning do-files
***********************************************************************************
display "Section 2: Run data processing/cleaning do-files"

* Insheet, clean, and append together the air pollution data.
qui do "${mypath}Do Files/Data Cleaning/airpol04_in_01102014.do"
display "airpol04_in_01102014.do done"

qui do "${mypath}Do Files/Data Cleaning/airpol0507_in_01102014.do"
display "airpol0507_in_01102014.do done"

qui do "${mypath}Do Files/Data Cleaning/ap_clean_01102014.do"
display "ap_clean_01102014.do done"
* "ap_clean_01102014.do" calls two other programs: "clean_names_01102014.do" and "census_in_01102014.do"
* The purpose of "census_in_01102014.do" is to construct the population/literacy control dataset.
* "census_in_01102014.do" calls one other program: "clean_districts_01102014.do"

* Construct the dataset of Problem Area Action Plans for air and water.
qui do "${mypath}Do Files/Data Cleaning/probareas_01102014.do" 
display "probareas_01102014.do done"

* Construct and clean the air policy dataset.
qui do "${mypath}Do Files/Data Cleaning/policy_clean_01102014.do"
display "policy_clean_01102014.do done"
* "policy_clean_01102014.do" calls two other programs: "clean_names_01102014.do" and "clean_districts_01102014.do"

* Construct the per capita expenditure controls dataset and prepare it for merging.
qui do "${mypath}Do Files/Data Cleaning/pov_merge_01102014.do"
display "pov_merge_01102014.do done"
* "pov_merge_01102014.do" calls one other program: "clean_districts_01102014.do"

* Construct the air temperature and precipitation controls datasets and prepare them for merging.
qui do "${mypath}Do Files/Data Cleaning/temp_prcp_01102014.do"
display "temp_prcp_01102014.do done"
* "temp_prcp_01102014.do" calls two other programs: "clean_districts_01102014.do" and "clean_districts_1961_01102014.do"

* Merge together the air pollution data and air policy data, and add controls.
qui do "${mypath}Do Files/Data Cleaning/merge_ap_policy_01102014.do"
display "merge_ap_policy_01102014.do done"

* Insheet, clean, and append together the water pollution data.
qui do "${mypath}Do Files/Data Cleaning/waterclean-apr09_01102014.do"
display "waterclean-apr09_01102014.do done"
* "waterclean-apr09_01102014.do" calls three other programs: "waterpol_2005_01102014.do", "waterpolicy_sam_01102014.do"
*	and "clean_waternames_01102014.do"

* Construct the city-by-month infant mortality dataset.
qui do "${mypath}Do Files/Data Cleaning/im_city_data_01102014.do"
display "im_city_data_01102014.do done"

* Merge the infant mortality data with air/water pollution and policy data.
qui do "${mypath}Do Files/Data Cleaning/im_addpolicy_01102014.do"
display "im_addpolicy_01102014.do done"

* Additional controls: Times of India newspaper citations, industry compliance, and corruption
* Prepare Times of India pollution references data
qui do "${mypath}Do Files/Data Cleaning/newspaper_prep_01102014.do"
display "newspaper_prep_01102014.do done"

* Prepare industry compliance data 
qui do "${mypath}Do Files/Data Cleaning/industry_compliance_prep_01102014.do"
display "industry_compliance_prep_01102014.do done"

* Prepare corruption data
qui do "${mypath}Do Files/Data Cleaning/corruption_prep_01102014.do"
display "corruption_prep_01102014.do done"

* Merge additional controls with existing air and water datasets
qui do "${mypath}Do Files/Data Cleaning/controls_merge_01102014.do"

***********************************************************************************
* Section 3: Run analysis do-files
***********************************************************************************
* Generate Table 1: Prevalence of Air and Water Policies
do "${mypath}Do Files/Tables and Figures/Table1_01102014.do"
display "Table1_01102014.do done"

* Generate Table 2: Summary Stats
qui do "${mypath}Do Files/Tables and Figures/Table2_01102014.do"
display "Table2_01102014.do done"

* Generate Table 3: Air policy mean shift & trend-break analysis
qui do "${mypath}Do Files/Tables and Figures/Table3_01102014.do"
display "Table3_01102014.do done"

* Generate Table 4: Water policy mean shift & trend-break analysis
qui do "${mypath}Do Files/Tables and Figures/Table4_01102014.do"
display "Table4_01102014.do done"

* Generate Table 5 and Figure 7: Structural break analysis using QLR test
do "${mypath}Do Files/Tables and Figures/Table5_Figure7_01102014.do"
display "Table5_Figure7_01102014.do done"

* Generate Table 6: Structural break analysis using QLR test
qui do "${mypath}Do Files/Tables and Figures/Table6_01102014.do"
display "Table6_01102014.do done"

* Generate Table 7: Difference in Catalytic Converter 5-year Treatment Effect 
*	Between Cities Above and Below the Median in Proxies for Demand for Clean Air
qui do "${mypath}Do Files/Tables and Figures/Table7_01102014.do"
display "Table7_01102014.do done"

* Generate Figure 1: Comparison of pollution levels in India, China, and U.S.
qui do "${mypath}Do Files/Tables and Figures/Figure1_01102014.do"
display "Figure1_01102014.do done"

* Generate Figure 4: Trends in Air Quality, Water Quality, and Infant Mortality
qui do "${mypath}Do Files/Tables and Figures/Figure4_01102014.do"
display "Figure4_01102014.do done"

* Generate Figure 5: Event Study of Air Pollution Policies
qui do "${mypath}Do Files/Tables and Figures/Figure5_01102014.do"
display "Figure5_01102014.do done" 

* Generate Figure 6: Event Study of Water Pollution Policy
qui do "${mypath}Do Files/Tables and Figures/Figure6_01102014.do"
display "Figure6_01102014.do done" 

* Generate Figure 8: Event Study of Catalytic Converters and Infant Morality
qui do "${mypath}Do Files/Tables and Figures/Figure8_01102014.do"
display "Figure8_01102014.do done" 

* Generate Figure 9: Total Nationwide References to Air and Water Pollution in Times of India
qui do "${mypath}Do Files/Tables and Figures/Figure9_01102014.do"
display "Figure9_01102014.do done" 

* Generate Appendix Table 1: Summary Statistics, by Year
qui do "${mypath}Do Files/Tables and Figures/AppTable1_01102014.do"
display "AppTable1_01102014.do done"

* Generate Appendix Table 2: Pollution Policy Coverage in India, by Year
qui do "${mypath}Do Files/Tables and Figures/AppTable2_01102014.do"
display "AppTable2_01102014.do done"

* Generate Appendix Table 3: Distribution of Air and Water Policies, by Relative Year
qui do "${mypath}Do Files/Tables and Figures/AppTable3_01102014.do"
display "AppTable3_01102014.do done"

* Generate Appendix Table 4: Robustness Checks with Varying Taus
qui do "${mypath}Do Files/Tables and Figures/AppTable4_01102014.do"
display "AppTable4_01102014.do done"

* Generate Appendix Figure 1: Kernel Density Graphs of Air Quality, Water Quality, and Infanty Morality
qui do "${mypath}Do Files/Tables and Figures/AppTable4_01102014.do"
display "AppTable4_01102014.do done"


***********************************************************************************
* end
***********************************************************************************
