***********************************************************************************

* File:  clean_names_01102014.do
* Contact: Rema Hanna - rema_hanna@hks.harvard.edu or Michael Greenstone - mgreenst@mit.edu

/*
Objective: This file cleans location names: states, districts, cities, location descriptions.
*/

***********************************************************************************

* Do this so the code will run in a dataset which doesn't have identifiers for certain geographic levels.
cap g district = ""
cap g distcode = ""
cap g city = ""
cap drop statecode /* define them all anew */
cap g statecode = .
cap g location = ""
cap ren state_full state

**********************************************************
* Now clean state names. This is originally from City Data.do and from Clean District Data.do and from Air_Pollution_code.do
* 	Jharkhand was formed on 15 November 2000 by carving out the districts of Chota Nagpur and Santhal Parganas divisions of Bihar
* 	Note: there are two distinct union territories: one is "Daman & Diu" and the other is "Dadra & Nagar Haveli". I'm combining them 
*	into one since they are geographically close and since the air pollution location data don't distinguish between them (several 
*	monitors list city as "Daman Diu & Nagar Haveli" and state as union territory, and their location codes usually don't distinguish 
*	Daman/Diu from Dadra/Nagar Haveli" Uttaranchal formed in 2000 from Uttar Pradesh.  
*	Use capture for commands that involve cities (since some datasets don't have city IDs)

replace state = "A & N Islands" if state == "A. & N. Islands" | state == "A & N. Island" | state == "ANDAMAN & NICOBAR ISLANDS" | state == "Andaman & Nicobar Islands"
replace state = "Andhra Pradesh" if state == "ANDHRA PRADESH" | state == "Andhra Pradhesh" | state == "AndhraPradesh"
replace state = "Arunachal Pradesh" if state == "ARUNACHAL PRADESH"
replace state = "Assam" if state == "ASSAM"
replace state = "Bihar" if state == "BIHAR" | state == "Bihir" | state == "Jharkhand"
replace state = "Chandigarh" if (state == "Union Territory" & city == "Chandigarh") | state == "CHANDIGARH"
replace state = "Daman & Diu + Dadra & Nagar Haveli" if state == "DADRA & NAGAR HAVELI" | state == "DAMAN  & DIU" | state == "DAMAN & DIU" | (state == "Union Territory" & (city == "Daman Diu & Nagar Haveli" | city == "Daman, Diu, and Nagar Haveli" | city == "Daman, Diu, and Nagat Haveli")) | state == "Dadra & Nagar Haveli +" | state == "Dadra / Nagar Haveli" | state == "Daman and Diu" | state == "Daman & Diu" | state == "Dadra & Nagar Haveli" | state == "Daman Diu & Nagar Haveli" | state == "Daman & Diu and Dadar & Nagar Haveli"
replace state = "Delhi" if state == "DELHI" | (state == "Union Territory" & city == "Delhi")
replace state = "Goa" if state == "GOA"
replace state = "Gujarat" if state == "GUJARAT" | state == "Gujaarat"
replace state = "Haryana" if state == "HARYANA" | state == "D. Hayana"
replace state = "Himachal Pradesh" if state == "HIMACHAL PRADESH" | state == "Himachal Pradhesh" | state == "Himahal Pradesh"
replace state = "Jammu & Kashmir" if state == "JAMMU & KASHMIR" | state == "Jammu and Kashmir"
replace state = "Karnataka" if state == "KARNATAKA"
replace state = "Kerala" if state == "KERALA"
replace state = "Lakshadweep" if state == "LAKSHADWEEP" | state == "Lakshadweep +"
replace state = "Madhya Pradesh" if state == "MADHYA PRADESH" | state == "Madhya Pradhesh" | state == "Chhattisgarh" | state == "Chhatisgarh#" | state == "Chattisgarh"
replace state = "Maharashtra" if state == "MAHARASHTRA" | state == "Maharastra"
replace state = "Manipur" if state == "MANIPUR"
replace state = "Meghalaya" if state == "MEGHALAYA" | state == "Meghalya"
replace state = "Mizoram" if state == "MIZORAM"
replace state = "Nagaland" if state == "NAGALAND"
replace state = "Orissa" if state == "ORISSA"
replace state = "Pondicherry" if state == "PONDICHERRY" | (state == "Union Territory" & (city == "Pondicherry" | city == "Pondichery" | city == "Metropolyam")) | state == "Pondichery"
replace state = "Punjab" if state == "PUNJAB"
replace state = "Rajasthan" if state == "RAJASTHAN"
replace state = "Sikkim" if state == "SIKKIM"
replace state = "Tamil Nadu" if state == "TAMIL NADU"
replace state = "Tripura" if state == "TRIPURA"
replace state = "Uttar Pradesh" if state == "UTTAR PRADESH" | state == "Uttar Pradhesh" | state == "Utter Pradesh" | state == "Uttaranchal"
replace state = "West Bengal" if state == "WEST BENGAL" | (state == "Union Territory" & city == "Howrah")

*********************************************
* Define state codes. This comes from mergedata.csv, which is used in Air_Pollution_code (and previously was used in the "Merge IM and Pollution Data" file).

capt pr drop statecodefix
pr de statecodefix
	replace statecode = `2' if state == "`1'"
end

* Note: the city of Patna in Bihar had a state code of 10, but I'll call all of Bihar as 20.
* Note: Daman Diu & Nagar Haveli was 25 or 26, I'm calling it 25 (Silvassa had state code of 26)
* Note: Chhattisgarh was being coded as 22, but make it as 23 (which is Madhya Pradesh)"

statecodefix "A & N Islands"						35
statecodefix "Andhra Pradesh"						28
statecodefix "Assam"							18
statecodefix "Bihar"							20
statecodefix "Chandigarh"						4
statecodefix "Daman & Diu + Dadra & Nagar Haveli"		25
statecodefix "Delhi"							7
statecodefix "Goa"								30
statecodefix "Gujarat"							24
statecodefix "Haryana"							6
statecodefix "Himachal Pradesh"					2
statecodefix "Jammu & Kashmir"					1
statecodefix "Karnataka"							29
statecodefix "Kerala"							32
statecodefix "Madhya Pradesh"						23
statecodefix "Maharashtra"						27
statecodefix "Meghalaya"							17
statecodefix "Manipur"							14
statecodefix "Mizoram"							15
statecodefix "Nagaland"							13
statecodefix "Orissa"							21
statecodefix "Pondicherry"						34
statecodefix "Punjab"							3
statecodefix "Rajasthan"							8
statecodefix "Tamil Nadu"						33
statecodefix "Tripura"							16
statecodefix "Uttar Pradesh"						9
statecodefix "West Bengal"						19

**********************************************************
* Now clean districts

* The following is from district_fix.csv. It basically replaces district = District_Name_2001 if state == State_Name_2001. I erased lines where district_name_2001 is missing.
capt pr drop distnamefix
pr de distnamefix
	replace district = "`3'" if district == "`1'" & state == "`2'"
end
	
distnamefix "Andaman"	"A & N Islands"	"Andamans"
distnamefix "Andamans"	"A & N Islands"	"Andamans"
distnamefix "Nicobar"	"A & N Islands"	"Nicobars"
distnamefix "Nicobar +"	"A & N Islands"	"Nicobars"
distnamefix "Nicobar:"	"A & N Islands"	"Nicobars"
distnamefix "Nicobars"	"A & N Islands"	"Nicobars"
distnamefix "Nicobars+"	"A & N Islands"	"Nicobars"
distnamefix "Adilabad"	"Andhra Pradesh"	"Adilabad"
distnamefix "Anantapur"	"Andhra Pradesh"	"Anantapur"
distnamefix "Chittoor"	"Andhra Pradesh"	"Chittoor"
distnamefix "Cuddapab"	"Andhra Pradesh"	"Cuddapah"
distnamefix "Cuddapah"	"Andhra Pradesh"	"Cuddapah"
distnamefix "East Godavari"	"Andhra Pradesh"	"East Godavari"
distnamefix "Guntur"	"Andhra Pradesh"	"Guntur"
distnamefix "Hyderabad"	"Andhra Pradesh"	"Hyderabad and Rangareddi"
distnamefix "Hyderabad @"	"Andhra Pradesh"	"Hyderabad and Rangareddi"
distnamefix "Hyderabad!"	"Andhra Pradesh"	"Hyderabad and Rangareddi"
distnamefix "Karimnagar"	"Andhra Pradesh"	"Karimnagar"
distnamefix "Khamam"	"Andhra Pradesh"	"Khammam"
distnamefix "Khammam"	"Andhra Pradesh"	"Khammam"
distnamefix "Krishna"	"Andhra Pradesh"	"Krishna"
distnamefix "Kurnool"	"Andhra Pradesh"	"Kurnool"
distnamefix "Mahbubnagar"	"Andhra Pradesh"	"Mahbubnagar"
distnamefix "Medak"	"Andhra Pradesh"	"Medak"
distnamefix "Mehbubnagar"	"Andhra Pradesh"	"Mahbubnagar"
distnamefix "Nalgonda"	"Andhra Pradesh"	"Nalgonda"
distnamefix "Nellore"	"Andhra Pradesh"	"Nellore"
distnamefix "Nizamabad"	"Andhra Pradesh"	"Nizamabad"
distnamefix "Ongole (Prakasam)"	"Andhra Pradesh"	"Prakasam"
distnamefix "Prakasam"	"Andhra Pradesh"	"Prakasam"
distnamefix "Ranagareddi"	"Andhra Pradesh"	"Rangareddi"
distnamefix "Rangareddi"	"Andhra Pradesh"	"Rangareddi"
distnamefix "Srikakulam"	"Andhra Pradesh"	"Srikakulam"
distnamefix "Visakhapatnam"	"Andhra Pradesh"	"Visakhapatnam"
distnamefix "Vishakhapatnam"	"Andhra Pradesh"	"Visakhapatnam"
distnamefix "Vizianagaram"	"Andhra Pradesh"	"Vizianagaram"
distnamefix "Warangal"	"Andhra Pradesh"	"Warangal"
distnamefix "Warrangal"	"Andhra Pradesh"	"Warangal"
distnamefix "West Godavari"	"Andhra Pradesh"	"West Godavari"
distnamefix "Changlang"	"Arunachal Pradesh"	"Changlang"
distnamefix "Changlang+"	"Arunachal Pradesh"	"Changlang"
distnamefix "Dibang Valley"	"Arunachal Pradesh"	"Dibang Valley"
distnamefix "Dibang Vally"	"Arunachal Pradesh"	"Dibang Valley"
distnamefix "East Kamang"	"Arunachal Pradesh"	"East Kameng"
distnamefix "East Kameng"	"Arunachal Pradesh"	"East Kameng"
distnamefix "East Siang"	"Arunachal Pradesh"	"East Siang"
distnamefix "Est Siang"	"Arunachal Pradesh"	"East Siang"
distnamefix "Lohit"	"Arunachal Pradesh"	"Lohit"
distnamefix "Lower Subansiri"	"Arunachal Pradesh"	"Lower Subansiri"
distnamefix "Papum Pare"	"Arunachal Pradesh"	"Papum Pare *"
distnamefix "Papun Pare"	"Arunachal Pradesh"	"Papum Pare *"
distnamefix "Tawang"	"Arunachal Pradesh"	"Tawang"
distnamefix "Tirap"	"Arunachal Pradesh"	"Tirap"
distnamefix "Upper Siang*"	"Arunachal Pradesh"	"Upper Siang *"
distnamefix "Upper Subansiri"	"Arunachal Pradesh"	"Upper Subansiri"
distnamefix "West Kamang"	"Arunachal Pradesh"	"West Kameng"
distnamefix "West Kameng"	"Arunachal Pradesh"	"West Kameng"
distnamefix "West Siang"	"Arunachal Pradesh"	"West Siang"
distnamefix "Barpeta"	"Assam"	"Barpeta"
distnamefix "Bongaigaon"	"Assam"	"Bongaigaon"
distnamefix "Cachar"	"Assam"	"Cachar"
distnamefix "Darrang"	"Assam"	"Darrang"
distnamefix "Dhemaji"	"Assam"	"Dhemaji"
distnamefix "Dhubri"	"Assam"	"Dhubri"
distnamefix "Dibrugarh"	"Assam"	"Dibrugarh"
distnamefix "Goal Para"	"Assam"	"Goalpara"
distnamefix "Goalpara"	"Assam"	"Goalpara"
distnamefix "Golaghat"	"Assam"	"Golaghat"
distnamefix "Hailakandi"	"Assam"	"Hailakandi"
distnamefix "Jorhat"	"Assam"	"Jorhat"
distnamefix "Kakrajhar"	"Assam"	"Kokrajhar"
distnamefix "Kamrup"	"Assam"	"Kamrup"
distnamefix "Karbi Anglong"	"Assam"	"Karbi Anglong"
distnamefix "Karimganj"	"Assam"	"Karimganj"
distnamefix "Kokrajhar"	"Assam"	"Kokrajhar"
distnamefix "Korbi Anglong"	"Assam"	"Karbi Anglong"
distnamefix "Lakhimpur"	"Assam"	"Lakhimpur"
distnamefix "Marigaon"	"Assam"	"Marigaon"
distnamefix "N.C.Hills"	"Assam"	"North Cachar Hills"
distnamefix "Nagaon"	"Assam"	"Nagaon"
distnamefix "Nalbari"	"Assam"	"Nalbari"
distnamefix "North Cachar Hills"	"Assam"	"North Cachar Hills"
distnamefix "Sibsagar"	"Assam"	"Sibsagar"
distnamefix "Sonitpur"	"Assam"	"Sonitpur"
distnamefix "Tinsukia"	"Assam"	"Tinsukia"
distnamefix "Arana"	"Bihar"	"Araria"
distnamefix "Araria"	"Bihar"	"Araria"
distnamefix "Araria*"	"Bihar"	"Araria"
distnamefix "Aurangabad"	"Bihar"	"Aurangabad"
distnamefix "Banka"	"Bihar"	"Banka *"
distnamefix "Begusarai"	"Bihar"	"Begusarai"
distnamefix "Bhabhua"	"Bihar"	"Kaimur (Bhabua) *"
distnamefix "Bhabua"	"Bihar"	"Kaimur (Bhabua) *"
distnamefix "Bhagalpur"	"Bihar"	"Bhagalpur"
distnamefix "Bhojpur"	"Bihar"	"Bhojpur"
distnamefix "Bokaro"	"Bihar"	"Bokaro *"
distnamefix "Buxar"	"Bihar"	"Buxar *"
distnamefix "Chatra"	"Bihar"	"Chatra *"
distnamefix "Darbhanga"	"Bihar"	"Darbhanga"
distnamefix "Deogarh"	"Bihar"	"Deoghar"
distnamefix "Deoghar"	"Bihar"	"Deoghar"
distnamefix "Dhanbad"	"Bihar"	"Dhanbad"
distnamefix "Dumka"	"Bihar"	"Dumka"
distnamefix "Garhwa"	"Bihar"	"Garhwa *"
distnamefix "Gaya"	"Bihar"	"Gaya"
distnamefix "Giridih"	"Bihar"	"Giridih"
distnamefix "Giridjh"	"Bihar"	"Giridih"
distnamefix "Godda"	"Bihar"	"Godda"
distnamefix "Gopal Ganj"	"Bihar"	"Gopalganj"
distnamefix "Gopalganj"	"Bihar"	"Gopalganj"
distnamefix "Gumla"	"Bihar"	"Gumla"
distnamefix "Hazaribag"	"Bihar"	"Hazaribag"
distnamefix "Jahanabad"	"Bihar"	"Jehanabad "
distnamefix "Jamui"	"Bihar"	"Jamui *"
distnamefix "Jehanabad"	"Bihar"	"Jehanabad "
distnamefix "Kaimur (Bhabua)"	"Bihar"	"Kaimur (Bhabua) *"
distnamefix "Katihal"	"Bihar"	"Katihar"
distnamefix "Katihar"	"Bihar"	"Katihar"
distnamefix "Khagana"	"Bihar"	"Khagaria"
distnamefix "Khagaria"	"Bihar"	"Khagaria"
distnamefix "Kishanganj"	"Bihar"	"Kishanganj"
distnamefix "Kodarma"	"Bihar"	"Kodarma *"
distnamefix "Lakhisarai"	"Bihar"	"Lakhisarai *"
distnamefix "Lakshisarai"	"Bihar"	"Lakhisarai *"
distnamefix "Lohardaga"	"Bihar"	"Lohardaga"
distnamefix "Lohardagga"	"Bihar"	"Lohardaga"
distnamefix "Madhebura"	"Bihar"	"Madhepura"
distnamefix "Madhepura"	"Bihar"	"Madhepura"
distnamefix "Madhubani"	"Bihar"	"Madhubani"
distnamefix "Mashubani"	"Bihar"	"Madhubani"
distnamefix "Munge"	"Bihar"	"Munger"
distnamefix "Munger"	"Bihar"	"Munger"
distnamefix "Muzaffarpur"	"Bihar"	"Muzaffarpur"
distnamefix "Nalanda"	"Bihar"	"Nalanda"
distnamefix "Nawada"	"Bihar"	"Nawada"
distnamefix "Pakir"	"Bihar"	"Pakaur *"
distnamefix "Pakur"	"Bihar"	"Pakaur *"
distnamefix "Palamu"	"Bihar"	"Palamu"
distnamefix "Paschim Champaran"	"Bihar"	"Pashchim Champaran"
distnamefix "Paschim Singhbhum"	"Bihar"	"Pashchimi Singhbhum"
distnamefix "Pashchim Champaran"	"Bihar"	"Pashchim Champaran"
distnamefix "Pashchimi Singhbhum"	"Bihar"	"Pashchimi Singhbhum"
distnamefix "Patna"	"Bihar"	"Patna"
distnamefix "Purab Champaran"	"Bihar"	"Purba Champaran"
distnamefix "Purba Champaran"	"Bihar"	"Purba Champaran"
distnamefix "Purba Chaparan"	"Bihar"	"Purba Champaran"
distnamefix "Purbi Singhbhum"	"Bihar"	"Purbi Singhbhum"
distnamefix "Purnia"	"Bihar"	"Purnia"
distnamefix "Ranchi"	"Bihar"	"Ranchi"
distnamefix "Rohtas"	"Bihar"	"Rohtas"
distnamefix "Saharsa"	"Bihar"	"Saharsa"
distnamefix "Sahibganj"	"Bihar"	"Sahibganj"
distnamefix "Samastipur"	"Bihar"	"Samastipur"
distnamefix "Saran"	"Bihar"	"Saran"
distnamefix "Sheikhpura"	"Bihar"	"Sheikhpura *"
distnamefix "Shekhpura"	"Bihar"	"Sheikhpura *"
distnamefix "Sheohar"	"Bihar"	"Sheohar *"
distnamefix "Singbhum"	"Bihar"	"Pashchimi Singhbhum"
distnamefix "Singhbhum (Paschim)"	"Bihar"	"Pashchimi Singhbhum"
distnamefix "Singhbhum (Purab)"	"Bihar"	"Purbi Singhbhum"
distnamefix "Singhbum"	"Bihar"	"Pashchimi Singhbhum"
distnamefix "Sitamarhi"	"Bihar"	"Sitamarhi"
distnamefix "Siwan"	"Bihar"	"Siwan"
distnamefix "Supaul"	"Bihar"	"Supaul *"
distnamefix "Vaisali"	"Bihar"	"Vaishali"
distnamefix "Vaishali"	"Bihar"	"Vaishali"
distnamefix "CHANDIGARH"	"Chandigarh"	"Chandigarh"
distnamefix "Chandigarh"	"Chandirgarh"	"Chandigarh"
distnamefix "'Dadra & Nagar haveli"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "DADRA & NAGAR HAVELI"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "Dadra & Nagar Haveli"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "Dadra & Nagar Haveli +"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "Dadra & Nagar haveli"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "Dadra / Nagar Haveli"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "Dadra and Nagar Haveli"	"Daman & Diu + Dadra & Nagar Haveli"	"Dadra & Nagar Haveli"
distnamefix "Daman"	"Daman & Diu + Dadra & Nagar Haveli"	"Daman & Diu"
distnamefix "Diu"	"Daman & Diu + Dadra & Nagar Haveli"	"Daman & Diu"
distnamefix "DELHI"	"Delhi"	"Delhi"
distnamefix "Delhi"	"Delhi"	"Delhi"
distnamefix "AHMEDABAD"	"Gujarat"	"Ahmadabad"
distnamefix "AMRELI"	"Gujarat"	"Amreli"
distnamefix "ANAND"	"Gujarat"	"Anand  *"
distnamefix "Ahmadabad"	"Gujarat"	"Ahmadabad"
distnamefix "Ahmedabad"	"Gujarat"	"Ahmadabad"
distnamefix "Amreli"	"Gujarat"	"Amreli"
distnamefix "Anand*"	"Gujarat"	"Anand  *"
distnamefix "BANASKANTHA"	"Gujarat"	"Banas Kantha"
distnamefix "BHARUCH"	"Gujarat"	"Bharuch"
distnamefix "BHAVNAGAR"	"Gujarat"	"Bhavnagar"
distnamefix "Banas Kantha"	"Gujarat"	"Banas Kantha"
distnamefix "Banaskantha"	"Gujarat"	"Banas Kantha"
distnamefix "Bharuch"	"Gujarat"	"Bharuch"
distnamefix "Bhavnagar"	"Gujarat"	"Bhavnagar"
distnamefix "DAHOD"	"Gujarat"	"Dohad  *"
distnamefix "DANGS"	"Gujarat"	"The Dangs"
distnamefix "Dohad*"	"Gujarat"	"Dohad  *"
distnamefix "GANDHINAGAR"	"Gujarat"	"Gandhinagar"
distnamefix "Gandhi Nagar"	"Gujarat"	"Gandhinagar"
distnamefix "Gandhinagar"	"Gujarat"	"Gandhinagar"
distnamefix "JAMNAGAR"	"Gujarat"	"Jamnagar"
distnamefix "JUNAGADH"	"Gujarat"	"Junagadh"
distnamefix "Jamnagar"	"Gujarat"	"Jamnagar"
distnamefix "Junagadh"	"Gujarat"	"Junagadh"
distnamefix "KHEDA"	"Gujarat"	"Kheda"
distnamefix "KUTCH"	"Gujarat"	"Kachchh"
distnamefix "Kachchh"	"Gujarat"	"Kachchh"
distnamefix "Kheda"	"Gujarat"	"Kheda"
distnamefix "MAHESANA"	"Gujarat"	"Mahesana"
distnamefix "Mahesana"	"Gujarat"	"Mahesana"
distnamefix "Mehsana"	"Gujarat"	"Mahesana"
distnamefix "NARMADA"	"Gujarat"	"Narmada  *"
distnamefix "NAVSARI"	"Gujarat"	"Navsari  *"
distnamefix "Narmada*"	"Gujarat"	"Narmada  *"
distnamefix "Navsari*"	"Gujarat"	"Navsari  *"
distnamefix "North Goa"	"Goa"	"North Goa"
distnamefix "PANCHAMAHAL"	"Gujarat"	"Panch Mahals"
distnamefix "PATAN"	"Gujarat"	"Patan  *"
distnamefix "PORBANDAR"	"Gujarat"	"Porbandar  *"
distnamefix "Panch Mahal"	"Gujarat"	"Panch Mahals"
distnamefix "Panch Mahals"	"Gujarat"	"Panch Mahals"
distnamefix "Patan*"	"Gujarat"	"Patan  *"
distnamefix "Porbandar*"	"Gujarat"	"Porbandar  *"
distnamefix "RAJKOT"	"Gujarat"	"Rajkot"
distnamefix "Rajkot"	"Gujarat"	"Rajkot"
distnamefix "SABARKANTHA"	"Gujarat"	"Sabar Kantha"
distnamefix "SURAT"	"Gujarat"	"Surat"
distnamefix "SURENDRANAGAR"	"Gujarat"	"Surendranagar"
distnamefix "SURENDRANAGR"	"Gujarat"	"Surendranagar"
distnamefix "Sabar Kantha"	"Gujarat"	"Sabar Kantha"
distnamefix "Sabarkantha"	"Gujarat"	"Sabar Kantha"
distnamefix "South Goa"	"Goa"	"South Goa"
distnamefix "Surat"	"Gujarat"	"Surat"
distnamefix "Surendranagar"	"Gujarat"	"Surendranagar"
distnamefix "The Dangs"	"Gujarat"	"The Dangs"
distnamefix "The Dangs+"	"Gujarat"	"The Dangs"
distnamefix "VADODARA"	"Gujarat"	"Vadodara"
distnamefix "VALSAD"	"Gujarat"	"Valsad"
distnamefix "Vadodara"	"Gujarat"	"Vadodara"
distnamefix "Valsad"	"Gujarat"	"Valsad"
distnamefix "Ambala"	"Haryana"	"Ambala"
distnamefix "Bhiwani"	"Haryana"	"Bhiwani"
distnamefix "Faridabad"	"Haryana"	"Faridabad"
distnamefix "Fatehabad*"	"Haryana"	"Fatehabad *"
distnamefix "Gurgaon"	"Haryana"	"Gurgaon"
distnamefix "Hisar"	"Haryana"	"Hisar"
distnamefix "Jhajjar*"	"Haryana"	"Jhajjar *"
distnamefix "Jind"	"Haryana"	"Jind"
distnamefix "Kaithal"	"Haryana"	"Kaithal"
distnamefix "Karnal"	"Haryana"	"Karnal"
distnamefix "Kurukshetra"	"Haryana"	"Kurukshetra"
distnamefix "Mahendragarh"	"Haryana"	"Mahendragarh"
distnamefix "Panchkula"	"Haryana"	"Panchkula *"
distnamefix "Panipat"	"Haryana"	"Panipat"
distnamefix "Rewari"	"Haryana"	"Rewari"
distnamefix "Rohtak"	"Haryana"	"Rohtak"
distnamefix "Sirsa"	"Haryana"	"Sirsa"
distnamefix "Sonipat"	"Haryana"	"Sonipat"
distnamefix "Sonipet"	"Haryana"	"Sonipat"
distnamefix "Yamunanagar"	"Haryana"	"Yamunanagar"
distnamefix "Bilaspur"	"Himachal Pradesh"	"Bilaspur"
distnamefix "Chamba"	"Himachal Pradesh"	"Chamba"
distnamefix "Hamirpur"	"Himachal Pradesh"	"Hamirpur"
distnamefix "Kangra"	"Himachal Pradesh"	"Kangra"
distnamefix "Kinaur"	"Himachal Pradesh"	"Kinnaur"
distnamefix "Kinnaur"	"Himachal Pradesh"	"Kinnaur"
distnamefix "Kinnaur+"	"Himachal Pradesh"	"Kinnaur"
distnamefix "Kullu"	"Himachal Pradesh"	"Kullu"
distnamefix "Lahul & Spiti"	"Himachal Pradesh"	"Lahul & Spiti"
distnamefix "Lahul & Spiti+"	"Himachal Pradesh"	"Lahul & Spiti"
distnamefix "Lahul & Spitti"	"Himachal Pradesh"	"Lahul & Spiti"
distnamefix "Lahul and Spiti"	"Himachal Pradesh"	"Lahul & Spiti"
distnamefix "Mandi"	"Himachal Pradesh"	"Mandi"
distnamefix "Selan"	"Himachal Pradesh"	"Solan"
distnamefix "Shimla"	"Himachal Pradesh"	"Shimla"
distnamefix "Sirmaur"	"Himachal Pradesh"	"Sirmaur"
distnamefix "Solan"	"Himachal Pradesh"	"Solan"
distnamefix "Una"	"Himachal Pradesh"	"Una"
distnamefix "Anantanag"	"Jammu & Kashmir"	"Anantnag"
distnamefix "Anantnag"	"Jammu & Kashmir"	"Anantnag"
distnamefix "Badgam"	"Jammu & Kashmir"	"Badgam"
distnamefix "Baramula"	"Jammu & Kashmir"	"Baramula"
distnamefix "Doda"	"Jammu & Kashmir"	"Doda"
distnamefix "Jammu"	"Jammu & Kashmir"	"Jammu"
distnamefix "Kargil"	"Jammu & Kashmir"	"Kargil"
distnamefix "Kargil+"	"Jammu & Kashmir"	"Kargil"
distnamefix "Kathua"	"Jammu & Kashmir"	"Kathua"
distnamefix "Kathula"	"Jammu & Kashmir"	"Kathua"
distnamefix "Kupwara"	"Jammu & Kashmir"	"Kupwara"
distnamefix "Leh"	"Jammu & Kashmir"	"Leh (Ladakh)"
distnamefix "Leh (Ladakh)"	"Jammu & Kashmir"	"Leh (Ladakh)"
distnamefix "Pulwama"	"Jammu & Kashmir"	"Pulwama"
distnamefix "Punch"	"Jammu & Kashmir"	"Punch"
distnamefix "Rajauri"	"Jammu & Kashmir"	"Rajauri"
distnamefix "Srinagar"	"Jammu & Kashmir"	"Srinagar"
distnamefix "Udhampur"	"Jammu & Kashmir"	"Udhampur"
distnamefix "Bagalkot"	"Karnataka"	"Bagalkot *"
distnamefix "Bagalkot*"	"Karnataka"	"Bagalkot *"
distnamefix "Bangalore"	"Karnataka"	"Bangalore"
distnamefix "Bangalore (Rural)"	"Karnataka"	"Bangalore Rural"
distnamefix "Bangalore (Urban)"	"Karnataka" "Bangalore"
distnamefix "Bangalore Rural"	"Karnataka"	"Bangalore Rural"
distnamefix "Belgaum"	"Karnataka"	"Belgaum"
distnamefix "Bellary"	"Karnataka"	"Bellary"
distnamefix "Bidar"	"Karnataka"	"Bidar"
distnamefix "Bijapur"	"Karnataka"	"Bijapur"
distnamefix "Chamarajanagar*"	"Karnataka"	"Chamrajnagar*"
distnamefix "Chamarajanagara"	"Karnataka"	"Chamrajnagar*"
distnamefix "Chickmagalur"	"Karnataka"	"Chikmagalur"
distnamefix "Chickmangalur"	"Karnataka"	"Chikmagalur"
distnamefix "Chikmagalur"	"Karnataka"	"Chikmagalur"
distnamefix "Chitradurga"	"Karnataka"	"Chitradurga"
distnamefix "Dakashin Kannad"	"Karnataka"	"Dakshina Kannada"
distnamefix "Dakashin Kannada"	"Karnataka"	"Dakshina Kannada"
distnamefix "Dakshin Kannad"	"Karnataka"	"Dakshina Kannada"
distnamefix "Dakshina Kannada"	"Karnataka"	"Dakshina Kannada"
distnamefix "Davanagere"	"Karnataka"	"Davangere*"
distnamefix "Davanagere*"	"Karnataka"	"Davangere*"
distnamefix "Dharwad"	"Karnataka"	"Dharwad"
distnamefix "Dharwar"	"Karnataka"	"Dharwad"
distnamefix "Gadag"	"Karnataka"	"Gadag *"
distnamefix "Gadag*"	"Karnataka"	"Gadag *"
distnamefix "Gulbarga"	"Karnataka"	"Gulbarga"
distnamefix "Hassan"	"Karnataka"	"Hassan"
distnamefix "Haveri"	"Karnataka"	"Haveri *"
distnamefix "Haveri*"	"Karnataka"	"Haveri *"
distnamefix "Kodagu"	"Karnataka"	"Kodagu"
distnamefix "Kolar"	"Karnataka"	"Kolar"
distnamefix "Koppal*"	"Karnataka"	"Koppal *"
distnamefix "Koppala"	"Karnataka"	"Koppal *"
distnamefix "Mandya"	"Karnataka"	"Mandya"
distnamefix "Mysore"	"Karnataka"	"Mysore"
distnamefix "Raichur"	"Karnataka"	"Raichur"
distnamefix "Shimoga"	"Karnataka"	"Shimoga"
distnamefix "Tumkur"	"Karnataka"	"Tumkur"
distnamefix "Udupi"	"Karnataka"	"Udupi *"
distnamefix "Udupi*"	"Karnataka"	"Udupi *"
distnamefix "Uttar Kannad"	"Karnataka"	"Uttara Kannada"
distnamefix "Uttar kannada"	"Karnataka"	"Uttara Kannada"
distnamefix "Uttara Kannada"	"Karnataka"	"Uttara Kannada"
distnamefix "Alappuzha"	"Kerala"	"Alappuzha"
distnamefix "Alleppey"	"Kerala"	"Alappuzha"
distnamefix "Cannanore"	"Kerala"	"Kannur"
distnamefix "Eranakulam"	"Kerala"	"Ernakulam"
distnamefix "Ernakulam"	"Kerala"	"Ernakulam"
distnamefix "Iduki"	"Kerala"	"Idukki"
distnamefix "Idukki"	"Kerala"	"Idukki"
distnamefix "Kannur"	"Kerala"	"Kannur"
distnamefix "Kasaragod"	"Kerala"	"Kasaragod"
distnamefix "Kasaragode"	"Kerala"	"Kasaragod"
distnamefix "Kollam"	"Kerala"	"Kollam"
distnamefix "Kottayam"	"Kerala"	"Kottayam"
distnamefix "Kozhikode"	"Kerala"	"Kozhikode"
distnamefix "Malappuram"	"Kerala"	"Malappuram"
distnamefix "Palakkad"	"Kerala"	"Palakkad"
distnamefix "Palghat"	"Kerala"	"Palakkad"
distnamefix "Pathanamthitta"	"Kerala"	"Pathanamthitta"
distnamefix "Qailon"	"Kerala"	"Kollam"
distnamefix "Quilon"	"Kerala"	"Kollam"
distnamefix "Thiruvananthapuram"	"Kerala"	"Thiruvananthapuram"
distnamefix "Thiruvananthapuram (Trivandrum)"	"Kerala"	"Thiruvananthapuram"
distnamefix "Thrissur"	"Kerala"	"Thrissur"
distnamefix "Trichur"	"Kerala"	"Thrissur"
distnamefix "Trivandrum"	"Kerala"	"Thiruvananthapuram"
distnamefix "Wayanad"	"Kerala"	"Wayanad"
distnamefix "Waynad"	"Kerala"	"Wayanad"
distnamefix "LAKSHADWEEP"	"Lakshadweep"	"Lakshadweep"
distnamefix "Lakshadweep"	"Lakshadweep"	"Lakshadweep"
distnamefix "Lakshadweep +"	"Lakshadweep"	"Lakshadweep"
distnamefix "Balaghat"	"Madhya Pradesh"	"Balaghat"
distnamefix "Barwani"	"Madhya Pradesh"	"Barwani *"
distnamefix "Barwani*"	"Madhya Pradesh"	"Barwani *"
distnamefix "Bastar"	"Madhya Pradesh"	"Baster"
distnamefix "Baster"	"Madhya Pradesh"	"Baster"
distnamefix "Betul"	"Madhya Pradesh"	"Betul"
distnamefix "Bhind"	"Madhya Pradesh"	"Bhind"
distnamefix "Bhopal"	"Madhya Pradesh"	"Bhopal"
distnamefix "Bilaspur"	"Madhya Pradesh"	"Bilaspur"
distnamefix "Chhatarpur"	"Madhya Pradesh"	"Chhatarpur"
distnamefix "Chhindwara"	"Madhya Pradesh"	"Chhindwara"
distnamefix "Damoh"	"Madhya Pradesh"	"Damoh"
distnamefix "Dantewada*"	"Madhya Pradesh"	"Dantewada*"
distnamefix "Datia"	"Madhya Pradesh"	"Datia"
distnamefix "Dewas"	"Madhya Pradesh"	"Dewas"
distnamefix "Dhamtari*"	"Madhya Pradesh"	"Dhamtari *"
distnamefix "Dhar"	"Madhya Pradesh"	"Dhar"
distnamefix "Dindori"	"Madhya Pradesh"	"Dindori *"
distnamefix "Dindori*"	"Madhya Pradesh"	"Dindori *"
distnamefix "Dishi"	"Madhya Pradesh"	"Sidhi"
distnamefix "Durg"	"Madhya Pradesh"	"Durg"
distnamefix "Eash Nimar (Khandwa)"	"Madhya Pradesh"	"East Nimar"
distnamefix "East Nimar (Khandwa)"	"Madhya Pradesh"	"East Nimar"
distnamefix "Guna"	"Madhya Pradesh"	"Guna"
distnamefix "Gwalior"	"Madhya Pradesh"	"Gwalior"
distnamefix "Harda"	"Madhya Pradesh"	"Harda *"
distnamefix "Harda*"	"Madhya Pradesh"	"Harda *"
distnamefix "Hoshangabad"	"Madhya Pradesh"	"Hoshangabad"
distnamefix "Hoshangabak"	"Madhya Pradesh"	"Hoshangabad"
distnamefix "Indore"	"Madhya Pradesh"	"Indore"
distnamefix "Jabalpur"	"Madhya Pradesh"	"Jabalpur"
distnamefix "Janjgir-Champa*"	"Madhya Pradesh"	"Janjgir - Champa*"
distnamefix "Jashpur*"	"Madhya Pradesh"	"Jashpur *"
distnamefix "Jhabhu"	"Madhya Pradesh"	"Jhabua"
distnamefix "Jhabua"	"Madhya Pradesh"	"Jhabua"
distnamefix "Kanker*"	"Madhya Pradesh"	"Kanker *"
distnamefix "Katni"	"Madhya Pradesh"	"Katni *"
distnamefix "Katni*"	"Madhya Pradesh"	"Katni *"
distnamefix "Kawardha*"	"Madhya Pradesh"	"Kawardha *"
distnamefix "Khandwa"	"Madhya Pradesh"	"East Nimar"
distnamefix "Khandwa (East Nimar)"	"Madhya Pradesh"	"East Nimar"
distnamefix "Khargone"	"Madhya Pradesh"	"West Nimar"
distnamefix "Khargone (West Nimar)"	"Madhya Pradesh"	"West Nimar"
distnamefix "Korba*"	"Madhya Pradesh"	"Korba"
distnamefix "Koriya*"	"Madhya Pradesh"	"Koriya *"
distnamefix "Mahasamund*"	"Madhya Pradesh"	"Mahasamund *"
distnamefix "Mandla"	"Madhya Pradesh"	"Mandla"
distnamefix "Mandsaur"	"Madhya Pradesh"	"Mandsaur"
distnamefix "Mndsaur"	"Madhya Pradesh"	"Mandsaur"
distnamefix "Morena"	"Madhya Pradesh"	"Morena"
distnamefix "Narshimhapur"	"Madhya Pradesh"	"Narsimhapur"
distnamefix "Narsimhapur"	"Madhya Pradesh"	"Narsimhapur"
distnamefix "Neemuch"	"Madhya Pradesh"	"Neemuch *"
distnamefix "Neemuch*"	"Madhya Pradesh"	"Neemuch *"
distnamefix "Panna"	"Madhya Pradesh"	"Panna"
distnamefix "Raigarh"	"Madhya Pradesh"	"Raigarh"
distnamefix "Raipur"	"Madhya Pradesh"	"Raipur"
distnamefix "Raisen"	"Madhya Pradesh"	"Raisen"
distnamefix "Rajgarh"	"Madhya Pradesh"	"Rajgarh"
distnamefix "Rajnandgaon"	"Madhya Pradesh"	"Rajnandgaon"
distnamefix "Ratlam"	"Madhya Pradesh"	"Ratlam"
distnamefix "Rewa"	"Madhya Pradesh"	"Rewa"
distnamefix "Sagar"	"Madhya Pradesh"	"Sagar"
distnamefix "Satna"	"Madhya Pradesh"	"Satna"
distnamefix "Sconi"	"Madhya Pradesh"	"Seoni"
distnamefix "Sehore"	"Madhya Pradesh"	"Sehore"
distnamefix "Seoni"	"Madhya Pradesh"	"Seoni"
distnamefix "Shahdol"	"Madhya Pradesh"	"Shahdol"
distnamefix "Shajapur"	"Madhya Pradesh"	"Shajapur"
distnamefix "Sheopur"	"Madhya Pradesh"	"Sheopur *"
distnamefix "Sheopur*"	"Madhya Pradesh"	"Sheopur *"
distnamefix "Shivpuri"	"Madhya Pradesh"	"Shivpuri"
distnamefix "Sidhi"	"Madhya Pradesh"	"Sidhi"
distnamefix "Surguja"	"Madhya Pradesh"	"Surguja"
distnamefix "Tikamgarh"	"Madhya Pradesh"	"Tikamgarh"
distnamefix "Uijain"	"Madhya Pradesh"	"Ujjain"
distnamefix "Ujjain"	"Madhya Pradesh"	"Ujjain"
distnamefix "Umaria*"	"Madhya Pradesh"	"Umaria *"
distnamefix "Umariya"	"Madhya Pradesh"	"Umaria *"
distnamefix "Vidisha"	"Madhya Pradesh"	"Vidisha"
distnamefix "West Nimar (Khargone)"	"Madhya Pradesh"	"West Nimar"
distnamefix "Ahmadnagar"	"Maharashtra"	"Ahmadnagar"
distnamefix "Akola"	"Maharashtra"	"Akola"
distnamefix "Amaravati"	"Maharashtra"	"Amravati"
distnamefix "Amravati"	"Maharashtra"	"Amravati"
distnamefix "Aurangabad"	"Maharashtra"	"Aurangabad"
distnamefix "Aurngabad"	"Maharashtra"	"Aurangabad"
distnamefix "Bandara"	"Maharashtra"	"Bhandara"
distnamefix "Beed"	"Maharashtra"	"Bid"
distnamefix "Bhandara"	"Maharashtra"	"Bhandara"
distnamefix "Bid"	"Maharashtra"	"Bid"
distnamefix "Buldana"	"Maharashtra"	"Buldana"
distnamefix "Buldhana"	"Maharashtra"	"Buldana"
distnamefix "Chandrapur"	"Maharashtra"	"Chandrapur"
distnamefix "Dhule"	"Maharashtra"	"Dhule"
distnamefix "Gadchiroli"	"Maharashtra"	"Gadchiroli"
distnamefix "Gadghiroli"	"Maharashtra"	"Gadchiroli"
distnamefix "God Chirole"	"Maharashtra"	"Gadchiroli"
distnamefix "God Chiroli"	"Maharashtra"	"Gadchiroli"
distnamefix "Gondiya"	"Maharashtra"	"Gondiya *"
distnamefix "Gondiya*"	"Maharashtra"	"Gondiya *"
distnamefix "Greater Bomaby @"	"Maharashtra"	"Mumbai (Suburban) and Mumbai"
distnamefix "Greater Bombay"	"Maharashtra"	"Mumbai (Suburban) and Mumbai"
distnamefix "Hingoli"	"Maharashtra"	"Hingoli *"
distnamefix "Hingoli*"	"Maharashtra"	"Hingoli *"
distnamefix "Jaland"	"Maharashtra"	"Jalna"
distnamefix "Jaland (Jalna)"	"Maharashtra"	"Jalna"
distnamefix "Jalgaon"	"Maharashtra"	"Jalgaon"
distnamefix "Jalna"	"Maharashtra"	"Jalna"
distnamefix "Kolhapur"	"Maharashtra"	"Kolhapur"
distnamefix "Latur"	"Maharashtra"	"Latur"
distnamefix "Mumbai"	"Maharashtra"	"Mumbai"
distnamefix "Mumbai !"	"Maharashtra"	"Mumbai"
distnamefix "Mumbai (Sub)"	"Maharashtra"	"Mumbai (Suburban) and Mumbai"
distnamefix "Mumbai (Suburban)*"	"Maharashtra"	"Mumbai (Suburban) and Mumbai"
distnamefix "Nagpur"	"Maharashtra"	"Nagpur"
distnamefix "Nanded"	"Maharashtra"	"Nanded"
distnamefix "Nandurbar"	"Maharashtra"	"Nandurbar *"
distnamefix "Nandurbar*"	"Maharashtra"	"Nandurbar *"
distnamefix "Nashik"	"Maharashtra"	"Nashik"
distnamefix "Osmanabad"	"Maharashtra"	"Osmanabad"
distnamefix "Parbhani"	"Maharashtra"	"Parbhani"
distnamefix "Pune"	"Maharashtra"	"Pune"
distnamefix "Raigad"	"Maharashtra"	"Raigarh"
distnamefix "Raigarh"	"Maharashtra"	"Raigarh"
distnamefix "Raigarh (Kolaba)"	"Maharashtra"	"Raigarh"
distnamefix "Ranagiri"	"Maharashtra"	"Ratnagiri"
distnamefix "Ratnagiri"	"Maharashtra"	"Ratnagiri"
distnamefix "Sangli"	"Maharashtra"	"Sangli"
distnamefix "Satara"	"Maharashtra"	"Satara"
distnamefix "Sindhudurg"	"Maharashtra"	"Sindhudurg"
distnamefix "Solapur"	"Maharashtra"	"Solapur"
distnamefix "Thane"	"Maharashtra"	"Thane"
distnamefix "Wardha"	"Maharashtra"	"Wardha"
distnamefix "Washim"	"Maharashtra"	"Washim *"
distnamefix "Washim*"	"Maharashtra"	"Washim *"
distnamefix "Yavatmal"	"Maharashtra"	"Yavatmal"
distnamefix "Bishenpur"	"Manipur"	"Bishnupur"
distnamefix "Bishnupur"	"Manipur"	"Bishnupur"
distnamefix "Chandel"	"Manipur"	"Chandel"
distnamefix "Chandel #"	"Manipur"	"Chandel"
distnamefix "Churachandpur"	"Manipur"	"Churachandpur"
distnamefix "Senapati"	"Manipur"	"Senapati"
distnamefix "Senapati #"	"Manipur"	"Senapati"
distnamefix "Senapati+"	"Manipur"	"Senapati"
distnamefix "Senaspati"	"Manipur"	"Senapati"
distnamefix "Tamenglong"	"Manipur"	"Tamenglong"
distnamefix "Tamenglong #"	"Manipur"	"Tamenglong"
distnamefix "Tamenglong+"	"Manipur"	"Tamenglong"
distnamefix "Thoubal"	"Manipur"	"Thoubal"
distnamefix "Ukhrul"	"Manipur"	"Ukhrul"
distnamefix "Ukhrul #"	"Manipur"	"Ukhrul"
distnamefix "Ukhrul+"	"Manipur"	"Ukhrul"
distnamefix "East Garo Hills"	"Meghalaya"	"East Garo Hills"
distnamefix "East Khasi Hills"	"Meghalaya"	"East Khasi Hills"
distnamefix "Jaintia Hills"	"Meghalaya"	"Jaintia Hills"
distnamefix "Ribhoi"	"Meghalaya"	"Ri Bhoi  *"
distnamefix "Ri Bhoi"	"Meghalaya"	"Ri Bhoi  *"
distnamefix "Ribhoi	Meghalaya"	"Ri Bhoi  *"
distnamefix "South Garo Hills"	"Meghalaya"	"South Garo Hills *"
distnamefix "South Garo Hills*"	"Meghalaya"	"South Garo Hills *"
distnamefix "West Garo Hills"	"Meghalaya"	"West Garo Hills"
distnamefix "West Khasi Hills"	"Meghalaya"	"West Khasi Hills"
distnamefix "Aizawl"	"Mizoram"	"Aizawl"
distnamefix "Champhai*"	"Mizoram"	"Champhai *"
distnamefix "Kolasib*"	"Mizoram"	"Kolasib *"
distnamefix "Lawngtlai*"	"Mizoram"	"Lawngtlai"
distnamefix "Lunglei"	"Mizoram"	"Lunglei"
distnamefix "Mamit*"	"Mizoram"	"Mamit *"
distnamefix "Serchhip*"	"Mizoram"	"Serchhip *"
distnamefix "Dimapur*"	"Nagaland"	"Dimapur *"
distnamefix "Kohima"	"Nagaland"	"Kohima"
distnamefix "Mokokchung"	"Nagaland"	"Mokokchung"
distnamefix "Mokokehung"	"Nagaland"	"Mokokchung"
distnamefix "Mon"	"Nagaland"	"Mon"
distnamefix "Mukokchung"	"Nagaland"	"Mokokchung"
distnamefix "Phek"	"Nagaland"	"Phek"
distnamefix "Phek +"	"Nagaland"	"Phek"
distnamefix "Teunsang"	"Nagaland"	"Tuensang"
distnamefix "Tuensang"	"Nagaland"	"Tuensang"
distnamefix "Wokha"	"Nagaland"	"Wokha"
distnamefix "Zuneboto"	"Nagaland"	"Zunheboto"
distnamefix "Zunheboto"	"Nagaland"	"Zunheboto"
distnamefix "Angul"	"Orissa"	"Anugul  *"
distnamefix "Balangir"	"Orissa"	"Balangir"
distnamefix "Baleshwar"	"Orissa"	"Baleshwar"
distnamefix "Bargarh"	"Orissa"	"Bargarh  *"
distnamefix "Barhgarh"	"Orissa"	"Bargarh  *"
distnamefix "Baudh"	"Orissa"	"Baudh  *"
distnamefix "Bhadrak"	"Orissa"	"Bhadrak  *"
distnamefix "Boudh"	"Orissa"	"Baudh  *"
distnamefix "Cuttack"	"Orissa"	"Cuttack"
distnamefix "Deogarh"	"Orissa"	"Debagarh  *"
distnamefix "Dhenkanal"	"Orissa"	"Dhenkanal"
distnamefix "Gajapati"	"Orissa"	"Gajapati  *"
distnamefix "Ganjam"	"Orissa"	"Ganjam"
distnamefix "Jagatsinghpur"	"Orissa"	"Jagatsinghapur  *"
distnamefix "Jajapur"	"Orissa"	"Jajapur  *"
distnamefix "Jajpur"	"Orissa"	"Jajapur  *"
distnamefix "Jharsuguda"	"Orissa"	"Jharsuguda  *"
distnamefix "Kalahandi"	"Orissa"	"Kalahandi"
distnamefix "Kandhamal (Phulbani)"	"Orissa"	"Kandhamal"
distnamefix "Kandhamal*"	"Orissa"	"Kandhamal"
distnamefix "Kandujhar"	"Orissa"	"Kendujhar"
distnamefix "Kendrapara"	"Orissa"	Kendrapara "*"
distnamefix "Kendujhar"	"Orissa"	"Kendujhar"
distnamefix "Khordha"	"Orissa"	"Khordha  *"
distnamefix "Khurda"	"Orissa"	"Khordha  *"
distnamefix "Koraput"	"Orissa"	"Koraput"
distnamefix "Malkangiri"	"Orissa"	"Malkangiri  *"
distnamefix "Malkargiri"	"Orissa"	"Malkangiri  *"
distnamefix "Mayrbhanj"	"Orissa"	"Mayurbhanj"
distnamefix "Mayurbhanj"	"Orissa"	"Mayurbhanj"
distnamefix "Nabarangapur"	"Orissa"	"Nabarangapur  *"
distnamefix "Nabarangpur"	"Orissa"	"Nabarangapur  *"
distnamefix "Nawapara"	"Orissa"	"Nuapada  *"
distnamefix "Nayagarh"	"Orissa"	"Nayagarh  *"
distnamefix "Nuapada"	"Orissa"	"Nuapada  *"
distnamefix "Nuapara"	"Orissa"	"Nuapada  *"
distnamefix "Phulabani"	"Orissa"	"Kandhamal"
distnamefix "Phulbani"	"Orissa"	"Kandhamal"
distnamefix "Phulbani (Kandhamal)"	"Orissa"	"Kandhamal"
distnamefix "Puri"	"Orissa"	"Puri"
distnamefix "Rayagada"	"Orissa"	"Rayagada  *"
distnamefix "Sambalpur"	"Orissa"	"Sambalpur"
distnamefix "Sonapur(Subarnapur)"	"Orissa"	"Sonapur  *"
distnamefix "Sonepur"	"Orissa"	"Sonapur  *"
distnamefix "Subernapur"	"Orissa"	"Sonapur  *"
distnamefix "Sundargarh"	"Orissa"	"Sundargarh"
distnamefix "Karaikal"	"Pondicherry"	"Karaikal"
distnamefix "Mahe"	"Pondicherry"	"Mahe"
distnamefix "Mahe!"	"Pondicherry"	"Mahe"
distnamefix "Pondicherry"	"Pondicherry"	"Pondicherry"
distnamefix "Pondichery"	"Pondicherry"	"Pondicherry"
distnamefix "Yanam"	"Pondicherry"	"Yanam"
distnamefix "Yanam !"	"Pondicherry"	"Yanam"
distnamefix "Yanam @"	"Pondicherry"	"Yanam"
distnamefix "Amristar"	"Punjab"	"Amritsar"
distnamefix "Amritsar"	"Punjab"	"Amritsar"
distnamefix "Bathinda"	"Punjab"	"Bathinda"
distnamefix "Bhatinda"	"Punjab"	"Bathinda"
distnamefix "Bhatindan"	"Punjab"	"Bathinda"
distnamefix "Faridkot"	"Punjab"	"Faridkot"
distnamefix "Fatehgarh Sahib"	"Punjab"	"Fatehgarh Sahib"
distnamefix "Firojpur"	"Punjab"	"Firozpur"
distnamefix "Firozpur"	"Punjab"	"Firozpur"
distnamefix "Gurdaspur"	"Punjab"	"Gurdaspur"
distnamefix "Gurudaspur"	"Punjab"	"Gurdaspur"
distnamefix "Hoshiarpur"	"Punjab"	"Hoshiarpur"
distnamefix "Jalandhar"	"Punjab"	"Jalandhar"
distnamefix "Kapurthala"	"Punjab"	"Kapurthala"
distnamefix "Ludhiana"	"Punjab"	"Ludhiana"
distnamefix "Mansa"	"Punjab"	"Mansa *"
distnamefix "Moga"	"Punjab"	"Moga *"
distnamefix "Muktsar"	"Punjab"	"Muktsar *"
distnamefix "Nawanshahr"	"Punjab"	"Nawanshahr *"
distnamefix "Patiala"	"Punjab"	"Patiala"
distnamefix "Patiale"	"Punjab"	"Patiala"
distnamefix "Ropar (Rup Nagar)"	"Punjab"	"Rupnagar"
distnamefix "Rupnagar"	"Punjab"	"Rupnagar"
distnamefix "Rupnagar (Ropar)"	"Punjab"	"Rupnagar"
distnamefix "Rupnagar(Ropar)"	"Punjab"	"Rupnagar"
distnamefix "Sangrur"	"Punjab"	"Sangrur"
distnamefix "Ajmer"	"Rajasthan"	"Ajmer"
distnamefix "Alwar"	"Rajasthan"	"Alwar"
distnamefix "Banswara"	"Rajasthan"	"Banswara"
distnamefix "Baran"	"Rajasthan"	"Baran *"
distnamefix "Barmer"	"Rajasthan"	"Barmer"
distnamefix "Baruan"	"Rajasthan"	"Baran *"
distnamefix "Bharatpur"	"Rajasthan"	"Bharatpur"
distnamefix "Bhilwara"	"Rajasthan"	"Bhilwara"
distnamefix "Bikaner"	"Rajasthan"	"Bikaner"
distnamefix "Bilwara"	"Rajasthan"	"Bhilwara"
distnamefix "Bundi"	"Rajasthan"	"Bundi"
distnamefix "Chitiaurgarh"	"Rajasthan"	"Chittaurgarh"
distnamefix "Chittaurgarh"	"Rajasthan"	"Chittaurgarh"
distnamefix "Churu"	"Rajasthan"	"Churu"
distnamefix "Dausa"	"Rajasthan"	"Dausa *"
distnamefix "Dhaulpur"	"Rajasthan"	"Dhaulpur"
distnamefix "Dholpur"	"Rajasthan"	"Dhaulpur"
distnamefix "Dungarpur"	"Rajasthan"	"Dungarpur"
distnamefix "Durgapur"	"Rajasthan"	"Dungarpur"
distnamefix "Ganganagar"	"Rajasthan"	"Ganganagar"
distnamefix "Hanumangarh"	"Rajasthan"	"Hanumangarh *"
distnamefix "Jaipur"	"Rajasthan"	"Jaipur"
distnamefix "Jaisalmer"	"Rajasthan"	"Jaisalmer"
distnamefix "Jalor"	"Rajasthan"	"Jalor"
distnamefix "Jhalawar"	"Rajasthan"	"Jhalawar"
distnamefix "Jhunjhunun"	"Rajasthan"	"Jhunjhunun"
distnamefix "Jodhpur"	"Rajasthan"	"Jodhpur"
distnamefix "Karauli*"	"Rajasthan"	"Karauli *"
distnamefix "Kota"	"Rajasthan"	"Kota"
distnamefix "Nagaur"	"Rajasthan"	"Nagaur"
distnamefix "Pali"	"Rajasthan"	"Pali"
distnamefix "Rajsamand"	"Rajasthan"	"Rajsamand *"
distnamefix "Sawai Madhopur"	"Rajasthan"	"Sawai Madhopur"
distnamefix "Sawal Madhopur"	"Rajasthan"	"Sawai Madhopur"
distnamefix "Sikar"	"Rajasthan"	"Sikar"
distnamefix "Sirohi"	"Rajasthan"	"Sirohi"
distnamefix "Tonk"	"Rajasthan"	"Tonk"
distnamefix "Udaipur"	"Rajasthan"	"Udaipur"
distnamefix "East"	"Sikkim"	"East"
distnamefix "East District"	"Sikkim"	"East"
distnamefix "North"	"Sikkim"	"North"
distnamefix "North District"	"Sikkim"	"North"
distnamefix "South"	"Sikkim"	"South"
distnamefix "South District"	"Sikkim"	"South"
distnamefix "West"	"Sikkim"	"West"
distnamefix "West District"	"Sikkim"	"West"
distnamefix "Anna"	"Tamil Nadu"	"Dindigul"
distnamefix "Anna (Dindigul Quaid-e-Milleth)"	"Tamil Nadu"	"Dindigul"
distnamefix "Anna(Dindigulguide Milleth)"	"Tamil Nadu"	"Dindigul"
distnamefix "Ariyalur*"	"Tamil Nadu"	"Ariyalur  *"
distnamefix "Chennai (Madras) !"	"Tamil Nadu"	"Chennai"
distnamefix "Chidambaranar:"	"Tamil Nadu"	"Thoothukkudi"
distnamefix "Coimbatore"	"Tamil Nadu"	"Coimbatore"
distnamefix "Cuddaiore Vallalar (South Arcot)"	"Tamil Nadu"	"Cuddalore"
distnamefix "Cuddalore"	"Tamil Nadu"	"Cuddalore"
distnamefix "Cuddalore Vallalar (South Arcot)"	"Tamil Nadu"	"Cuddalore"
distnamefix "Dharmapuri"	"Tamil Nadu"	"Dharmapuri"
distnamefix "Dindigul"	"Tamil Nadu"	"Dindigul"
distnamefix "Dindigul Anna"	"Tamil Nadu"	"Dindigul"
distnamefix "Erode"	"Tamil Nadu"	"Erode"
distnamefix "Kamarajar"	"Tamil Nadu"	"Virudhunagar"
distnamefix "Kancheepuram"	"Tamil Nadu"	"Kancheepuram"
distnamefix "Kanniyakumari"	"Tamil Nadu"	"Kanniyakumari"
distnamefix "Kanyakumari"	"Tamil Nadu"	"Kanniyakumari"
distnamefix "Karur*"	"Tamil Nadu"	"Karur  *"
distnamefix "Madras"	"Tamil Nadu"	"Chennai"
distnamefix "Madras @"	"Tamil Nadu"	"Chennai"
distnamefix "Madras@"	"Tamil Nadu"	"Chennai"
distnamefix "Madurai"	"Tamil Nadu"	"Madurai"
distnamefix "Nagapattinam"	"Tamil Nadu"	"Nagapattinam  *"
distnamefix "Nagapattinam Q. Milletu"	"Tamil Nadu"	"Nagapattinam  *"
distnamefix "Nagapattinam Q.M."	"Tamil Nadu"	"Nagapattinam  *"
distnamefix "Namakkal*"	"Tamil Nadu"	"Namakkal   *"
distnamefix "Nilgiri"	"Tamil Nadu"	"The Nilgiris"
distnamefix "Nilgiris"	"Tamil Nadu"	"The Nilgiris"
distnamefix "North Arcot Ambedkar"	"Tamil Nadu"	"Vellore"
distnamefix "P. M. Ramalingam"	"Tamil Nadu"	"Sivaganga"
distnamefix "P.M. Ramalingam"	"Tamil Nadu"	"Sivaganga"
distnamefix "Pasumpon M. Thevar"	"Tamil Nadu"	"Sivaganga"
distnamefix "Perambalur*"	"Tamil Nadu"	"Perambalur  *"
distnamefix "Periyar"	"Tamil Nadu"	"Erode"
distnamefix "Pudukkottai"	"Tamil Nadu"	"Pudukkottai"
distnamefix "Pudukottai"	"Tamil Nadu"	"Pudukkottai"
distnamefix "Pudukottal"	"Tamil Nadu"	"Pudukkottai"
distnamefix "Ramanathapuram"	"Tamil Nadu"	"Ramanathapuram"
distnamefix "Ramnad (Ramnath Puram)"	"Tamil Nadu"	"Ramanathapuram"
distnamefix "Ramnad (Ramnathapuram)"	"Tamil Nadu"	"Ramanathapuram"
distnamefix "Ramnathapuram"	"Tamil Nadu"	"Ramanathapuram"
distnamefix "Salem"	"Tamil Nadu"	"Salem"
distnamefix "Sivaganga"	"Tamil Nadu"	"Sivaganga"
distnamefix "Sivaganga*"	"Tamil Nadu"	"Sivaganga"
distnamefix "South Arcot"	"Tamil Nadu"	"Cuddalore"
distnamefix "Thanjavur"	"Tamil Nadu"	"Thanjavur"
distnamefix "The Nilgiris"	"Tamil Nadu"	"The Nilgiris"
distnamefix "Theni*"	"Tamil Nadu"	"Theni  *"
distnamefix "Thiruvallur*"	"Tamil Nadu"	"Thiruvallur"
distnamefix "Thiruvarur*"	"Tamil Nadu"	"Thiruvarur"
distnamefix "Tiruchirappalli"	"Tamil Nadu"	"Tiruchirappalli"
distnamefix "Tirunelveli"	"Tamil Nadu"	"Tirunelveli"
distnamefix "Tirunelveli Kattabomman"	"Tamil Nadu"	"Tirunelveli"
distnamefix "Tirunelvelli"	"Tamil Nadu"	"Tirunelveli"
distnamefix "Tiruvanamalai"	"Tamil Nadu"	"Tiruvannamalai"
distnamefix "Tiruvannamalai - Sambuvara"	"Tamil Nadu"	"Tiruvannamalai"
distnamefix "Tiruvannamalai Sambuvara"	"Tamil Nadu"	"Tiruvannamalai"
distnamefix "Tiruvannamalai  Sambuvara"	"Tamil Nadu"	"Tiruvannamalai"
distnamefix "Toothukudi"	"Tamil Nadu"	"Thoothukkudi"
distnamefix "Trichy (Tiruchirappalli)"	"Tamil Nadu"	"Tiruchirappalli"
distnamefix "V.D.C (Chidambaram)"	"Tamil Nadu"	"Thoothukkudi"
distnamefix "V.O.C."	"Tamil Nadu"	"Thoothukkudi"
distnamefix "V.O.C. (Chidambaram)"	"Tamil Nadu"	"Thoothukkudi"
distnamefix "Vellore"	"Tamil Nadu"	"Vellore"
distnamefix "Villupura Ramaswamy Padaya"	"Tamil Nadu"	"Viluppuram"
distnamefix "Viluppuram"	"Tamil Nadu"	"Viluppuram"
distnamefix "Virudhunagar"	"Tamil Nadu"	"Virudhunagar"
distnamefix "Dhalai"	"Tripura"	"Dhalai  *"
distnamefix "Dhalai District"	"Tripura"	"Dhalai  *"
distnamefix "North Tripura"	"Tripura"	"North Tripura"
distnamefix "South Tripura"	"Tripura"	"South Tripura"
distnamefix "West Tripura"	"Tripura"	"West Tripura"
distnamefix "Agra"	"Uttar Pradesh"	"Agra"
distnamefix "Aligarh"	"Uttar Pradesh"	"Aligarh"
distnamefix "Allahabad"	"Uttar Pradesh"	"Allahabad"
distnamefix "Alllahabad"	"Uttar Pradesh"	"Allahabad"
distnamefix "Almora"	"Uttar Pradesh"	"Almora"
distnamefix "Azamgarh"	"Uttar Pradesh"	"Azamgarh"
distnamefix "Babraich"	"Uttar Pradesh"	"Bahraich"
distnamefix "Bahraich"	"Uttar Pradesh"	"Bahraich"
distnamefix "Ballia"	"Uttar Pradesh"	"Ballia"
distnamefix "Banda"	"Uttar Pradesh"	"Banda"
distnamefix "Barabanki"	"Uttar Pradesh"	"Barabanki"
distnamefix "Bareilly"	"Uttar Pradesh"	"Bareilly"
distnamefix "Basta"	"Uttar Pradesh"	"Basti"
distnamefix "Basti"	"Uttar Pradesh"	"Basti"
distnamefix "Bijnoor"	"Uttar Pradesh"	"Bijnor"
distnamefix "Bijnor"	"Uttar Pradesh"	"Bijnor"
distnamefix "Bijnore"	"Uttar Pradesh"	"Bijnor"
distnamefix "Budaun"	"Uttar Pradesh"	"Budaun"
distnamefix "Bulandshahar"	"Uttar Pradesh"	"Bulandshahr"
distnamefix "Bulandshahr"	"Uttar Pradesh"	"Bulandshahr"
distnamefix "Chamoli"	"Uttar Pradesh"	"Chamoli"
distnamefix "Dehra" Dun	"Uttar Pradesh"	"Dehradun"
distnamefix "Dehradun"	"Uttar Pradesh"	"Dehradun"
distnamefix "Deoria"	"Uttar Pradesh"	"Deoria"
distnamefix "Etah"	"Uttar Pradesh"	"Etah"
distnamefix "Etawah"	"Uttar Pradesh"	"Etawah"
distnamefix "Faizabad"	"Uttar Pradesh"	"Faizabad"
distnamefix "Farrukhabad"	"Uttar Pradesh"	"Farrukhabad"
distnamefix "Farukhabad"	"Uttar Pradesh"	"Farrukhabad"
distnamefix "Fatehpur"	"Uttar Pradesh"	"Fatehpur"
distnamefix "Firozabad"	"Uttar Pradesh"	"Firozabad"
distnamefix "Garhwal"	"Uttar Pradesh"	"Garhwal"
distnamefix "Garhwal (Pauri)"	"Uttar Pradesh"	"Garhwal"
distnamefix "Garhwal (Pouri)"	"Uttar Pradesh"	"Garhwal"
distnamefix "Gaziabad"	"Uttar Pradesh"	"Ghaziabad"
distnamefix "Ghaziabad"	"Uttar Pradesh"	"Ghaziabad"
distnamefix "Ghazipur"	"Uttar Pradesh"	"Ghazipur"
distnamefix "Gonda"	"Uttar Pradesh"	"Gonda"
distnamefix "Gorakhpur"	"Uttar Pradesh"	"Gorakhpur"
distnamefix "Gorakpur"	"Uttar Pradesh"	"Gorakhpur"
distnamefix "Hamirpur"	"Uttar Pradesh"	"Hamirpur"
distnamefix "Hardoi"	"Uttar Pradesh"	"Hardoi"
distnamefix "Hardwar"	"Uttar Pradesh"	"Hardwar"
distnamefix "Jalaun"	"Uttar Pradesh"	"Jalaun"
distnamefix "Jalun"	"Uttar Pradesh"	"Jalaun"
distnamefix "Jaunpur"	"Uttar Pradesh"	"Jaunpur"
distnamefix "Jhansi"	"Uttar Pradesh"	"Jhansi"
distnamefix "Kanpur" "Uttar Pradesh" "(Nagpur + Dehat)"
distnamefix "Kanpur(Dehat)"	"Uttar Pradesh"	"Kanpur Dehat"
distnamefix "Kanpur(Nagar)"	"Uttar Pradesh"	"Kanpur Nagar"
distnamefix "Kheri"	"Uttar Pradesh"	"Kheri"
distnamefix "Kheri (Lakhipur)"	"Uttar Pradesh"	"Kheri"
distnamefix "Lalitpur"	"Uttar Pradesh"	"Lalitpur"
distnamefix "Lucknow"	"Uttar Pradesh"	"Lucknow"
distnamefix "Maharajganj"	"Uttar Pradesh"	"Maharajganj"
distnamefix "Mainpuri"	"Uttar Pradesh"	"Mainpuri"
distnamefix "Manipuri"	"Uttar Pradesh"	"Mainpuri"
distnamefix "Mathura"	"Uttar Pradesh"	"Mathura"
distnamefix "Mau"	"Uttar Pradesh"	"Mau"
distnamefix "Meerut"	"Uttar Pradesh"	"Meerut"
distnamefix "Mirazpur (Sonbhadra)"	"Uttar Pradesh"	"Sonbhadra"
distnamefix "Mirzapur"	"Uttar Pradesh"	"Mirzapur"
distnamefix "Mirzapur (Sonbhadra)"	"Uttar Pradesh"	"Sonbhadra"
distnamefix "Moradabad"	"Uttar Pradesh"	"Moradabad"
distnamefix "Muzaffarnagar"	"Uttar Pradesh"	"Muzaffarnagar"
distnamefix "Nainital"	"Uttar Pradesh"	"Nainital"
distnamefix "Pilibhit"	"Uttar Pradesh"	"Pilibhit"
distnamefix "Pithoragarh"	"Uttar Pradesh"	"Pithoragarh"
distnamefix "Pratapgarh"	"Uttar Pradesh"	"Pratapgarh"
distnamefix "Rae Bareli"	"Uttar Pradesh"	"Rae Bareli"
distnamefix "Rampur"	"Uttar Pradesh"	"Rampur"
distnamefix "Saharanpur"	"Uttar Pradesh"	"Saharanpur"
distnamefix "Shahjahanpur"	"Uttar Pradesh"	"Shahjahanpur"
distnamefix "Siddarthanagar"	"Uttar Pradesh"	"Siddharthnagar"
distnamefix "Siddharthnagar"	"Uttar Pradesh"	"Siddharthnagar"
distnamefix "Sitapur"	"Uttar Pradesh" "Sitapur"
distnamefix "Sonbhadra"	"Uttar Pradesh" "Sonbhadra"
distnamefix "Sultanpur"	"Uttar Pradesh" "Sultanpur"
distnamefix "Tehri Garhwal"	"Uttar Pradesh"	"Tehri Garhwal"
distnamefix "Unnao"	"Uttar Pradesh"	"Unnao"
distnamefix "Uttar Kashi"	"Uttar Pradesh"	"Uttarkashi"
distnamefix "Uttarkashi"	"Uttar Pradesh"	"Uttarkashi"
distnamefix "Varanashi"	"Uttar Pradesh"	"Varanasi"
distnamefix "Varanasi"	"Uttar Pradesh"	"Varanasi"
distnamefix "Bankura"	"West Bengal"	"Bankura"
distnamefix "Barddhaman"	"West Bengal"	"Barddhaman"
distnamefix "Birbhum"	"West Bengal"	"Birbhum"
distnamefix "Calcutta"	"West Bengal"	"Kolkata"
distnamefix "Calcutta@"	"West Bengal"	"Kolkata"
distnamefix "Dakshin Dinajpur"	"West Bengal"	"Dakshin Dinajpur *"
distnamefix "Darjiling"	"West Bengal"	"Darjiling"
distnamefix "Haora"	"West Bengal"	"Haora"
distnamefix "Hugli"	"West Bengal"	"Hugli"
distnamefix "Jalpaiguri"	"West Bengal"	"Jalpaiguri"
distnamefix "Koch Bihar"	"West Bengal"	"Koch Bihar"
distnamefix "Kochbihar"	"West Bengal"	"Koch Bihar"
distnamefix "Kolkata !"	"West Bengal"	"Kolkata"
distnamefix "Maldah"	"West Bengal"	"Maldah"
distnamefix "Medinipur"	"West Bengal"	"Medinipur"
distnamefix "Medinipur (Paschim)"	"West Bengal"	"Medinipur"
distnamefix "Medinipur (Purba)"	"West Bengal"	"Medinipur"
distnamefix "Midnapur"	"West Bengal"	"Medinipur"
distnamefix "Murshidabad"	"West Bengal"	"Murshidabad"
distnamefix "Nadia"	"West Bengal"	"Nadia"
distnamefix "North Twenty Four Parganas"	"West Bengal"	"North Twenty Four Parganas"
distnamefix "North Twenty Parganas"	"West Bengal"	"North Twenty Four Parganas"
distnamefix "PS. Medinipur"	"West Bengal"	"Medinipur"
distnamefix "PU. Medinipur"	"West Bengal"	"Medinipur"
distnamefix "Puruliya"	"West Bengal"	"Puruliya"
distnamefix "South  Twenty Four Parganas"	"West Bengal"	"South  Twenty Four Parganas"
distnamefix "South Twenty Pargana"	"West Bengal"	"South  Twenty Four Parganas"
distnamefix "South Twenty Parganas"	"West Bengal"	"South  Twenty Four Parganas"
distnamefix "Uttar Dinajpur"	"West Bengal"	"Uttar Dinajpur"

* Also from district_fix.csv. Now replace district = old_district_name if state == State_Name_2001 & old_district_name is nonmissing.
capt pr drop distnamefix2
pr de distnamefix2
	replace district = "`3'" if state == "`1'" & district == "`2'"
end

distnamefix2 "Arunachal Pradesh"	"Changlang"	"Tirap"
distnamefix2 "Arunachal Pradesh"	"Changlang"	"Tirap"
distnamefix2 "Arunachal Pradesh"	"East Siang"	"West Siang"
distnamefix2 "Arunachal Pradesh"	"East Siang"	"West Siang"
distnamefix2 "Arunachal Pradesh"	"Lower Subansiri"	"Subansiri"
distnamefix2 "Arunachal Pradesh"	"Papum Pare *"	"Subansiri"
distnamefix2 "Arunachal Pradesh"	"Papum Pare *"	"Subansiri"
distnamefix2 "Arunachal Pradesh"	"Tawang"	"West Kamang"
distnamefix2 "Arunachal Pradesh"	"Upper Siang *"	"West Siang"
distnamefix2 "Arunachal Pradesh"	"Upper Subansiri"	"Subansiri"
distnamefix2 "Assam"	"Cachar"	"Cachar"
distnamefix2 "Assam"	"Dhemaji"	"Lakhimpur"
distnamefix2 "Assam"	"Dibrugarh"	"Dibrugarh"
distnamefix2 "Assam"	"Golaghat"	"Sibsagar"
distnamefix2 "Assam"	"Hailakandi"	"Cachar"
distnamefix2 "Assam"	"Kamrup"	"Kamrup"
distnamefix2 "Assam"	"Marigaon"	"Nagaon"
distnamefix2 "Assam"	"Nalbari"	"Kamrup"
distnamefix2 "Assam"	"Tinsukia"	"Dibrugarh"
distnamefix2 "Bihar"	"Banka *"	"Bhagalpur"
distnamefix2 "Bihar"	"Kaimur (Bhabua) *"	"Rohtas"
distnamefix2 "Bihar"	"Kaimur (Bhabua) *"	"Rohtas"
distnamefix2 "Bihar"	"Bokaro *"	"Giridih"
distnamefix2 "Bihar"	"Buxar *"	"Bhojpur"
distnamefix2 "Bihar"	"Chatra *"	"Hazaribagh"
distnamefix2 "Bihar"	"Deoghar"	"Santhal Pargana"
distnamefix2 "Bihar"	"Deoghar"	"Santhal Pargana"
distnamefix2 "Bihar"	"Dumka"	"Santhal Pargana"
distnamefix2 "Bihar"	"Garhwa *"	"Palamu"
distnamefix2 "Bihar"	"Godda"	"Santhal Pargana"
distnamefix2 "Bihar"	"Gumla"	"Ranchi"
distnamefix2 "Bihar"	"Jehanabad" 	"Gaya"
distnamefix2 "Bihar"	"Jamui *"	"Munger"
distnamefix2 "Bihar"	"Jehanabad" 	"Gaya"
distnamefix2 "Bihar"	"Kaimur (Bhabua) *"	"Rohtas"
distnamefix2 "Bihar"	"Khagaria"	"Munger"
distnamefix2 "Bihar"	"Khagaria"	"Munger"
distnamefix2 "Bihar"	"Kodarma *"	"Hazaribagh"
distnamefix2 "Bihar"	"Lakhisarai *"	"Munger"
distnamefix2 "Bihar"	"Lakhisarai *"	"Munger"
distnamefix2 "Bihar"	"Lohardaga"	"Ranchi"
distnamefix2 "Bihar"	"Lohardaga"	"Ranchi"
distnamefix2 "Bihar"	"Madhepura"	"Saharsa"
distnamefix2 "Bihar"	"Madhepura"	"Saharsa"
distnamefix2 "Bihar"	"Pakaur *"	"Santhal Pargana"
distnamefix2 "Bihar"	"Pakaur *"	"Santhal Pargana"
distnamefix2 "Bihar"	"Pashchimi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Pashchimi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Purbi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Sahibganj"	"Santhal Pargana"
distnamefix2 "Bihar"	"Sheikhpura *"	"Munger"
distnamefix2 "Bihar"	"Sheikhpura *"	"Munger"
distnamefix2 "Bihar"	"Sheohar *"	"Sitamarhi"
distnamefix2 "Bihar"	"Pashchimi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Pashchimi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Purbi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Pashchimi Singhbhum"	"Singhbhum"
distnamefix2 "Bihar"	"Supaul *"	"Saharsa"
distnamefix2 "Gujarat"	"Anand  *"	"Kheda"
distnamefix2 "Gujarat"	"Anand  *"	"Kheda"
distnamefix2 "Gujarat"	"Dohad  *"	"Panch Mahals"
distnamefix2 "Gujarat"	"Dohad  *"	"Panch Mahals"
distnamefix2 "Gujarat"	"Narmada  *"	"Bharuch"
distnamefix2 "Gujarat"	"Navsari  *"	"Valsad"
distnamefix2 "Gujarat"	"Narmada  *"	"Bharuch"
distnamefix2 "Goa"	"North Goa" 	"Goa"
distnamefix2 "Gujarat"	"Porbandar  *"	"Junagadh"
distnamefix2 "Goa"	"South Goa"	"Goa"
distnamefix2 "Haryana"	"Fatehabad *"	"Hisar"
distnamefix2 "Haryana"	"Hisar"	"Hisar"
distnamefix2 "Haryana"	"Jhajjar *"	"Rohtak"
distnamefix2 "Haryana"	"Rewari"	"Mahendragarh"
distnamefix2 "Karnataka"	"Bagalkot *"	"Bijapur"
distnamefix2 "Karnataka"	"Bagalkot *"	"Bijapur"
distnamefix2 "Karnataka"	"Bangalore"	"Bangalore (R+U)"
distnamefix2 "Karnataka"	"Bangalore Rural"	"Bangalore (R+U)"
distnamefix2 "Karnataka"	"Bangalore"	"Bangalore (R+U)"
distnamefix2 "Karnataka"	"Bangalore Rural"	"Bangalore (R+U)"
distnamefix2 "Karnataka"	"Chamrajnagar*"	"Mysore"
distnamefix2 "Karnataka"	"Chamrajnagar*"	"Mysore"
distnamefix2 "Karnataka"	"Koppal *"	"Raichur"
distnamefix2 "Karnataka"	"Koppal *"	"Raichur"
distnamefix2 "Karnataka"	"Udupi *"	"Dakshina Kannada"
distnamefix2 "Karnataka"	"Udupi *"	"Dakshina Kannada"
distnamefix2 "Kerala"	"Kasaragod"	"Kannur"
distnamefix2 "Kerala"	"Kasaragod"	"Kannur"
distnamefix2 "Madhya Pradesh"	"Barwani *"	"West Nimar"
distnamefix2 "Madhya Pradesh"	"Barwani *"	"West Nimar"
distnamefix2 "Madhya Pradesh"	"Dantewada*"	"Baster"
distnamefix2 "Madhya Pradesh"	"Dhamtari *"	"Raipur"
distnamefix2 "Madhya Pradesh"	"Dindori *"	"Mandla"
distnamefix2 "Madhya Pradesh"	"Dindori *"	"Mandla"
distnamefix2 "Madhya Pradesh"	"East Nimar"	"Khandwa (East Nimar)"
distnamefix2 "Madhya Pradesh"	"East Nimar"	"Khandwa (East Nimar)"
distnamefix2 "Madhya Pradesh"	"Harda *"	"Hoshanagabad"
distnamefix2 "Madhya Pradesh"	"Harda *"	"Hoshanagabad"
distnamefix2 "Madhya Pradesh"	"Hoshangabad"	"Hoshanagabad"
distnamefix2 "Madhya Pradesh"	"Hoshangabad"	"Hoshanagabad"
distnamefix2 "Madhya Pradesh"	"Jabalpur"	"Jabalpur"
distnamefix2 "Madhya Pradesh"	"Jashpur *"	"Raigarh"
distnamefix2 "Madhya Pradesh"	"Kanker *"	"Baster"
distnamefix2 "Madhya Pradesh"	"Katni *"	"Jabalpur"
distnamefix2 "Madhya Pradesh"	"Katni *"	"Jabalpur"
distnamefix2 "Madhya Pradesh"	"East Nimar"	"Khandwa (East Nimar)"
distnamefix2 "Madhya Pradesh"	"East Nimar"	"Khandwa (East Nimar)"
distnamefix2 "Madhya Pradesh"	"West Nimar"	"West Nimar"
distnamefix2 "Madhya Pradesh"	"West Nimar"	"West Nimar"
distnamefix2 "Madhya Pradesh"	"Koriya *"	"Surguja"
distnamefix2 "Madhya Pradesh"	"Mahasamund *"	"Raipur"
distnamefix2 "Madhya Pradesh"	"Neemuch *"	"Mandsaur"
distnamefix2 "Madhya Pradesh"	"Neemuch *"	"Mandsaur"
distnamefix2 "Madhya Pradesh"	"Sheopur *"	"Morena"
distnamefix2 "Madhya Pradesh"	"Sheopur *"	"Morena"
distnamefix2 "Madhya Pradesh"	"Umaria *"	"Shahdol"
distnamefix2 "Madhya Pradesh"	"Umaria *"	"Shahdol"
distnamefix2 "Mahrashtra"	"Gadchiroli"	"Chandrapur"
distnamefix2 "Mahrashtra"	"Gadchiroli"	"Chandrapur"
distnamefix2 "Mahrashtra"	"Gadchiroli"	"Chandrapur"
distnamefix2 "Mahrashtra"	"Gadchiroli"	"Chandrapur"
distnamefix2 "Mahrashtra"	"Gondiya *"	"Bhandara"
distnamefix2 "Mahrashtra"	"Gondiya *"	"Bhandara"
distnamefix2 "Mahrashtra"	"Mumbai (Suburban) *"	"Mumbai (Suburban) and Mumbai"
distnamefix2 "Mahrashtra"	"Mumbai (Suburban) *"	"Mumbai (Suburban) and Mumbai"
distnamefix2 "Mahrashtra"	"Hingoli *"	"Parbhani"
distnamefix2 "Mahrashtra"	"Hingoli *"	"Parbhani"
distnamefix2 "Mahrashtra"	"Jalna"	"Aurangabad"
distnamefix2 "Mahrashtra"	"Jalna"	"Aurangabad"
distnamefix2 "Mahrashtra"	"Jalna"	"Aurangabad"
distnamefix2 "Mahrashtra"	"Latur"	"Osmanabad"
distnamefix2 "Mahrashtra"	"Mumbai"	"Mumbai (Suburban) and Mumbai"
distnamefix2 "Mahrashtra"	"Mumbai"	"Mumbai (Suburban) and Mumbai"
distnamefix2 "Mahrashtra"	"Mumbai (Suburban) *"	"Mumbai (Suburban) and Mumbai"
distnamefix2 "Mahrashtra"	"Mumbai (Suburban) *"	"Mumbai (Suburban) and Mumbai"
distnamefix2 "Mahrashtra"	"Nandurbar *"	"Dhule"
distnamefix2 "Mahrashtra"	"Nandurbar *"	"Dhule"
distnamefix2 "Mahrashtra"	"Sindhudurg"	"Ratnagiri"
distnamefix2 "Mahrashtra"	"Washim *"	"Akola"
distnamefix2 "Maharashtra"	"Washim *"	"Akola"
distnamefix2 "Manipur"	"Imphal"	"Imphal"
distnamefix2 "Meghalaya"	"Ri Bhoi  *"	"East Khasi Hills"
distnamefix2 "Meghalaya"	"Ri Bhoi  *"	"East Khasi Hills"
distnamefix2 "Meghalaya"	"South Garo Hills *"	"West Garo Hills"
distnamefix2 "Meghalaya"	"South Garo Hills *"	"West Garo Hills"
distnamefix2 "Mizoram"	"Champhai *"	"Aizawl"
distnamefix2 "Mizoram"	"Chhimtuipui"	"Chhimtuipui"
distnamefix2 "Mizoram"	"Kolasib *"	"Aizawl"
distnamefix2 "Mizoram"	"Lawngtlai"	"Chhimtuipui"
distnamefix2 "Mizoram"	"Mamit *"	"Aizawl"
distnamefix2 "Mizoram"	"Serchhip *"	"Aizawl"
distnamefix2 "Nagaland"	"Dimapur *"	"Kohima"
distnamefix2 "Orissa"	"Anugul  *"	"Dhenkanal"
distnamefix2 "Orissa"	"Bargarh  *"	"Sambalpur"
distnamefix2 "Orissa"	"Bargarh  *"	"Sambalpur"
distnamefix2 "Orissa"	"Baudh  *"	"Phulbani"
distnamefix2 "Orissa"	"Bhadrak  *"	"Baleshwar"
distnamefix2 "Orissa"	"Baudh  *"	"Phulbani"
distnamefix2 "Orissa"	"Debagarh  *"	"Sambalpur"
distnamefix2 "Orissa"	"Gajapati  *"	"Ganjam"
distnamefix2 "Orissa"	"Jagatsinghapur  *"	"Cuttack"
distnamefix2 "Orissa"	"Jajapur  *"	"Cuttack"
distnamefix2 "Orissa"	"Jajapur  *"	"Cuttack"
distnamefix2 "Orissa"	"Jharsuguda  *"	"Sambalpur"
distnamefix2 "Orissa"	"Kandhamal"	"Phulbani"
distnamefix2 "Orissa"	"Kandhamal"	"Phulbani"
distnamefix2 "Orissa"	"Kendrapara *"	"Cuttack"
distnamefix2 "Orissa"	"Khordha  *"	"Puri"
distnamefix2 "Orissa"	"Khordha  *"	"Puri"
distnamefix2 "Orissa"	"Malkangiri  *"	"Koraput"
distnamefix2 "Orissa"	"Malkangiri  *"	"Koraput"
distnamefix2 "Orissa"	"Nabarangapur  *"	"Koraput"
distnamefix2 "Orissa"	"Nabarangapur  *"	"Koraput"
distnamefix2 "Orissa"	"Nayagarh  *"	"Puri"
distnamefix2 "Orissa"	"Nuapada  *"	"Kalahandi"
distnamefix2 "Orissa"	"Nuapada  *"	"Kalahandi"
distnamefix2 "Orissa"	"Kandhamal"	"Phulbani"
distnamefix2 "Orissa"	"Kandhamal"	"Phulbani"
distnamefix2 "Orissa"	"Kandhamal"	"Phulbani"
distnamefix2 "Orissa"	"Rayagada  *"	"Koraput"
distnamefix2 "Orissa"	"Sonapur  *"	"Balangir"
distnamefix2 "Orissa"	"Sonapur  *"	"Balangir"
distnamefix2 "Orissa"	"Sonapur  *"	"Balangir"
distnamefix2 "Punjab"	"Mansa *"	"Bathinda"
distnamefix2 "Punjab"	"Moga *"	"Faridkot"
distnamefix2 "Punjab"	"Muktsar *"	"Faridkot"
distnamefix2 "Punjab"	"Nawanshahr *"	"Hoshiarpur"
distnamefix2 "Rajasthan"	"Baran *"	"Kota"
distnamefix2 "Rajasthan"	"Baran *"	"Kota"
distnamefix2 "Rajasthan"	"Dausa *"	"Jaipur"
distnamefix2 "Rajasthan"	"Dhaulpur"	"Bharatpur"
distnamefix2 "Rajasthan"	"Dhaulpur"	"Bharatpur"
distnamefix2 "Rajasthan"	"Hanumangarh *"	"Garangnagar"
distnamefix2 "Rajasthan"	"Karauli *"	"Sawai Madhopur"
distnamefix2 "Rajasthan"	"Rajsamand *"	"Udaipur"
distnamefix2 "Tamil Nadu"	"Ariyalur  *"	"Tiruchirappalli"
distnamefix2 "Tamil Nadu"	"Chengalpattu"	"Chengalpattu"
distnamefix2 "Tamil Nadu"	"Chengalpattu - M.G.R."	"Chengalpattu"
distnamefix2 "Tamil Nadu"	"Chengalpattu  M.G.R."	"Chengalpattu"
distnamefix2 "Tamil Nadu"	"Chingleput"	"Chengalpattu"
distnamefix2 "Tamil Nadu"	"Cuddalore"	"South Arcot"
distnamefix2 "Tamil Nadu"	"Cuddalore"	"South Arcot"
distnamefix2 "Tamil Nadu"	"Cuddalore"	"South Arcot"
distnamefix2 "Tamil Nadu"	"Kancheepuram"	"Chengalpattu"
distnamefix2 "Tamil Nadu"	"Karur  *"	"Tiruchirappalli"
distnamefix2 "Tamil Nadu"	"Nagapattinam  *"	"Thanjavur"
distnamefix2 "Tamil Nadu"	"Nagapattinam  *"	"Thanjavur"
distnamefix2 "Tamil Nadu"	"Nagapattinam  *"	"Thanjavur"
distnamefix2 "Tamil Nadu"	"Namakkal   *"	"Salem"
distnamefix2 "Tamil Nadu"	"North Arcot"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Vellore"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Perambalur  *"	"Tiruchirappalli"
distnamefix2 "Tamil Nadu"	"Cuddalore"	"South Arcot"
distnamefix2 "Tamil Nadu"	"Theni  *"	"Madurai"
distnamefix2 "Tamil Nadu"	"Thiruvallur"	"Chengalpattu"
distnamefix2 "Tamil Nadu"	"Tiruvannamalai"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Tiruvannamalai"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Tiruvannamalai"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Tiruvannamalai"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Vellore"	"North Arcot"
distnamefix2 "Tamil Nadu"	"Viluppuram"	"South Arcot"
distnamefix2 "Tamil Nadu"	"Viluppuram"	"South Arcot"
distnamefix2 "Uttar Pradesh"	"Ambedkar Nagar *"	"Faizabad"
distnamefix2 "Uttar Pradesh"	"Auraiya *"	"Etawah"
distnamefix2 "Uttar Pradesh"	"Balrampur *"	"Gonda"
distnamefix2 "Uttar Pradesh"	"Chandauli *"	"Varanasi"
distnamefix2 "Uttar Pradesh"	"Chitrakoot *"	"Banda"
distnamefix2 "Uttar Pradesh"	"Jyotiba Phule Nagar *"	"Moradabad"
distnamefix2 "Uttar Pradesh"	"Kannauj *"	"Farrukhabad"
distnamefix2 "Uttar Pradesh"	"Kaushambi *"	"Allahabad"
distnamefix2 "Uttar Pradesh"	"Kushinagar *"	"Deoria"
distnamefix2 "Uttar Pradesh"	"Maharajganj"	"Gorakhpur"
distnamefix2 "Uttar Pradesh"	"Mahoba *"	"Hamirpur"
distnamefix2 "Uttar Pradesh"	"Sant Kabir Nagar *"	"Basti"
distnamefix2 "Uttar Pradesh"	"Sant Ravidas Nagar *"	"Varanasi"
distnamefix2 "Uttar Pradesh"	"Shrawasti *"	"Bahraich"
distnamefix2 "Uttar Pradesh"	"Siddharthnagar"	"Basti"
distnamefix2 "Uttar Pradesh"	"Siddharthnagar"	"Basti"
distnamefix2 "Uttar Pradesh"	"Sonbhadra"	"Mirzapur"
distnamefix2 "West Bengal"	"Dakshin Dinajpur *"	"West Dinajpur"
distnamefix2 "West Bengal"	"North Twenty Four Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"North Twenty Four Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"South  Twenty Four Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"South  Twenty Four Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"South  Twenty Four Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"Twenty Four Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"Twentyfour Pargams"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"Twentyfour Parganas"	"Twentyfour Paraganas"
distnamefix2 "West Bengal"	"Uttar Dinajpur"	"West Dinajpur"
distnamefix2 "West Bengal"	"West Dinajpur"	"West Dinajpur"
distnamefix2 "West Bengal"	"West Dinapur"	"West Dinajpur"

* An additional fix I observe by looking at the cross-tab of district names in the IM district data and comparing death values for this district against those of district == "Mirzapur" | district == "Mirazpur (Sonbhadra)" | district == "Mirzapur (Sonbhadra)" | district == "Sonbhadra"

replace district = "Mirzapur" if district == "just Mirzpur" & state == "Uttar Pradesh"

**********************************************************
* Additional district cleaning
* The district 'DAMAN & DIU' is too vague. The other data is listed as Daman or specifically Diu. I want to drop the district Daman & Diu
drop if district == "DAMAN & DIU" | district == "Daman & Diu"

**********************************************************
* Now clean district codes. Use this in Air_Pollution_code. This is assigning district codes to cities (not to districts).
capt pr drop distcodefix
pr de distcodefix
	replace distcode = "`3'" if state == "`1'" & city == "`2'"
end
	
distcodefix "Andhra Pradesh" "Hyderabad"		"5 & 6"
distcodefix "Andhra Pradesh" "Vishakhapatnam"	"13"
distcodefix "Assam"	"Bongaigaon"	"4"
distcodefix "Assam"	"Guwahati"	"6"
distcodefix "Bihar"	"Dhanbad"	"12"
distcodefix "Bihar"	"Jamshedpur"	"18"
distcodefix "Bihar"	"Jharia"	"12"
distcodefix "Bihar"	"Patna"		"28"
distcodefix "Bihar"	"Sindri"		"12"
distcodefix "Chandigarh" "Chandigarh"		"1"
distcodefix "Daman & Diu + Dadra & Nagar Haveli" "Daman"		"2"
distcodefix "Daman & Diu + Dadra & Nagar Haveli" "Silvassa"		"1"
distcodefix "Delhi"	"Delhi"		"1 to 9"
distcodefix "Goa" "Panaji"		"1"
distcodefix "Goa" "Ponda"		"1"
distcodefix "Goa" "Vasco"		"2"
distcodefix "Gujarat" "Ahmedabad"		"7"
distcodefix "Gujarat" "Ankleshwar"		"21"
distcodefix "Gujarat" "Jamnagar"		"10"
distcodefix "Gujarat" "Rajkot"		"9"
distcodefix "Gujarat" "Surat"		"22"
distcodefix "Gujarat" "Vadodara"		"19"
distcodefix "Gujarat" "Vapi"		"25"
distcodefix "Haryana" "Faridabad"		"19"
distcodefix "Haryana" "Yamuna Nagar"		"3"
distcodefix "Himachal Pradesh"	"Damtal"		"2"
distcodefix "Himachal Pradesh"	"Paonta Sahib"		"10"
distcodefix "Himachal Pradesh"	"Parwanoo"		"9"
distcodefix "Himachal Pradesh"	"Shimla"		"11"
distcodefix "Karnataka"	"Bangalore"		"20"
distcodefix "Karnataka"	"Mysore"		"26"
distcodefix "Kerala"	"Kochi"		"8"
distcodefix "Kerala"	"Kottayam"		"10"
distcodefix "Kerala"	"Kozhikode"		"4"
distcodefix "Kerala"	"Palakkad"		"6"
distcodefix "Kerala"	"Thiruvananthapuram"		"14"
distcodefix "Madhya Pradesh"	"Bhilai"		"10"
distcodefix "Madhya Pradesh"	"Bhopal"		"32"
distcodefix "Madhya Pradesh"	"Indore"		"26"
distcodefix "Madhya Pradesh"	"Jabalpur"		"39"
distcodefix "Madhya Pradesh"	"Korba"		"5"
distcodefix "Madhya Pradesh" "Nagda"		"21"
distcodefix "Madhya Pradesh"	"Raipur"		"11"
distcodefix "Madhya Pradesh"	"Satna"		"13"
distcodefix "Maharashtra"	"Aurangabad"		"19"
distcodefix "Maharashtra"	"Chandrapur"		"13"
distcodefix "Maharashtra"	"Dombivali"		"21"
distcodefix "Maharashtra"	"Mumbai"		"22 & 23"
distcodefix "Maharashtra"	"Nagpur"		"9"
distcodefix "Maharashtra"	"Nashik"		"20"
distcodefix "Maharashtra"	"Pune"		"25"
distcodefix "Maharashtra"	"Solapur"		"30"
distcodefix "Maharashtra"	"Thane"		"21"
distcodefix "Meghalaya"	"Shilong"		"6"
distcodefix "Nagaland"	"Dimapur"		"6"
distcodefix "Orissa"	"Angul"		"15"
distcodefix "Orissa"	"Rayagada"		"27"
distcodefix "Orissa"	"Rourkela"		"5"
distcodefix "Orissa"	"Talcher"		"15"
distcodefix "Pondicherry"	"Pondicherry"		"2"
distcodefix "Punjab"	"Gobindgarh"		"8"
distcodefix "Punjab"	"Jalandhar"		"4"
distcodefix "Punjab"	"Ludhiana"		"9"
distcodefix "Punjab"	"Patiala"		"17"
distcodefix "Rajasthan"	"Alwar"		"6"
distcodefix "Rajasthan"	"Chittor"		"29"
distcodefix "Rajasthan"	"Jaipur"		"12"
distcodefix "Rajasthan"	"Jodhpur"		"15"
distcodefix "Rajasthan"	"Kota"		"30"
distcodefix "Rajasthan"	"Udaipur"		"26"
distcodefix "Tamil Nadu"	"Chennai"		"2"
distcodefix "Tamil Nadu"	"Coimbatore"		"12"
distcodefix "Tamil Nadu"	"Madurai"		"24"
distcodefix "Tamil Nadu"	"Salem"		"8"
distcodefix "Tamil Nadu"	"Tuticorin"		"28"
distcodefix "Uttar Pradesh"	"Agra"		"15"
distcodefix "Uttar Pradesh"	"Anpara"		"70"
distcodefix "Uttar Pradesh"	"Dehradun"		"5"
distcodefix "Uttar Pradesh"	"Gajraula"		"6"
distcodefix "Uttar Pradesh"	"Ghaziabad"		"9"
distcodefix "Uttar Pradesh"	"Kanpur"	"34"
distcodefix "Uttar Pradesh"	"Lucknow"		"27"
distcodefix "Uttar Pradesh"	"Moradabad"		"4"
distcodefix "Uttar Pradesh"	"Noida"		"10"
distcodefix "Uttar Pradesh"	"Varanasi"		"67"
distcodefix "West Bengal"	"Haldia"		"15"
* OJO: what's up with howrah?
distcodefix "West Bengal"	"Howrah"		""
distcodefix "West Bengal"	"Kolkata"		"17"

*****************************************************************
* Now clean cities. 
	
* The following is from the "city fix" file. These are alphabetically organized by *new* (correct) city
capt pr drop cityfix
pr de cityfix
	replace city = "`3'" if city == "`2'" & state == "`1'"
end

* This first group of corrections is from my looking at the result of "bys state: ta city" in the City Data.do. I essentially take cities 
*	which have one observation and are one letter different from a city with many observation in the same state. The fact that there are 
*	so many of these suggests that many of the remaining states which have more than one observation are also typo versions of differently 
*	named cities in the same state.
cityfix "Andhra Pradesh" "Bellampalli" "Bellampalle"
cityfix "Andhra Pradesh" "Chilakuralipet" "Chilakaluripet"
cityfix "Andhra Pradesh" "Kothagudem" "Kothagadem"
cityfix "Andhra Pradesh" "Miryalguda" "Miryalgada"
cityfix "Andhra Pradesh" "Sirsilla" "Sirieilla"
cityfix "Bihar" "Buxar" "Buxer"
cityfix "Bihar" "Giridith" "Giridih"
cityfix "Bihar" "Jamshedpur & Tata Nagar Rly. Col." "Jamshedpur & Tata Nagar Rly. Colony"
cityfix "Bihar" "Jhumri Talaiya" "Jhumri Tilaiya"
cityfix "Bihar" "Mokamch" "Mokameh"
cityfix "Bihar" "Ramgarh Court" "Ramgarh Cantt."
cityfix "Bihar" "Ramgarh Court" "Ramgarh Cantt."
cityfix "Haryana" "Ambala (Cantt. & Sadar)" "Ambala"
cityfix "Haryana" "Faridabad Complex Administration" "Faribadad Complex Admn."
cityfix "Jammu & Kashmir" "Sapore" "Sepore"
cityfix "Karnataka" "Basauakalyan" "Basavakalyana"
cityfix "Karnataka" "Chikballapur" "Chikkaballapura"
cityfix "Karnataka" "Gulburga" "Gulbarga"
cityfix "Karnataka" "Robersonpet" "Roberstsonpeti"
cityfix "Kerala" "Calicutt" "Calicut (Kozhikode)"
cityfix "Kerala" "Kasargod" "Kasargodu"
cityfix "Kerala" "Tellicherry" "Tellicherry (Thalaserry)"
cityfix "Madhya Pradesh" "Bhatapura" "Bhatapara"
cityfix "Madhya Pradesh" "Jaora" "Jaora (Jabra)"
cityfix "Madhya Pradesh" "Narasimhapur" "Narsimhapur"
cityfix "Maharashtra" "Ahmadnagar Cantt" "Ahmadnagar Cantt."
cityfix "Maharashtra" "Bhadara" "Bhandara"
cityfix "Maharashtra" "Dehu Road Cantt" "Dehu Road (Cantt.)"
cityfix "Maharashtra" "Kabnur CT" "Kabnoor"
cityfix "Maharashtra" "Puna Cantt." "Pune Cant"
cityfix "Maharashtra" "Umrad" "Umred"
cityfix "Maharashtra" "Bhubanswar" "Bhubaneswar"
cityfix "Maharashtra" "Rourkela S.T.S" "Raurkela"
cityfix "Maharashtra" "Rourkela C.T.S" "Raurkela"
cityfix "Pondicherry" "Ozhukarai (Oulgarpet)" "Ozhukarai"
cityfix "Punjab" "Amrisar" "Amritsar"
cityfix "Punjab" "Hoshiapur" "Hoshiarpur"
cityfix "Punjab" "Phagwar" "Phagwara"
cityfix "Punjab" "Samara" "Samana"
cityfix "Punjab" "Sunma" "Sunam"
cityfix "Tamil Nad" "Bodinayakanur" "Bodinayakkanur"
cityfix "Tamil Nadu" "Chengaipattu" "Chengalpattu"
cityfix "Tamil Nadu" "Devacottui" "Devakottai"
cityfix "Tamil Nadu" " Kumaramangalam" "Kumarapalaiyam"
cityfix "Tamil Nadu" "Madhavaram" "Madavaram"
cityfix "Tamil Nadu" "Pattukottai" "Pattukkotai"
cityfix "Tamil Nadu" "Ranipettai" "Ranippettai"
cityfix "Tamil Nadu" "St. Thomas Mount-Cum-Pallavaram Cantt" "St. Thomas Mount-Cum-Pallavaram Cantt."
cityfix "Tamil Nadu" "Tindivanama" "Tindivamam"
cityfix "Tamil Nadu" "Thiruvanur" "Thiruvarur"
cityfix "Tamil Nadu" "Tindivanama" "Tindivamam"
cityfix "Tamil Nadu" "Tuticorn" "Tuticorin"
cityfix "Tamil Nadu" "Vanitambadi" "Vaniyambadi"
cityfix "Uttar Pradesh" "Shahjahanpur" "Sahajahanpur"
cityfix "West Bengal" "Bangaoo" "Bangaon"
cityfix "West Bengal" "Basirhab" "Basirhat"
cityfix "West Bengal" "Nathati" "Naihati"

* These are from the original city fix list.
cityfix "Tripura"	"Agartala"	"Agartala"
cityfix "Tripura"	"Agartala City"	"Agartala"
cityfix "Maharashtra"	"Ahamadnagar"	"Ahamadnagar"
cityfix "Maharashtra"	"Ahmadnagar"	"Ahamadnagar"
cityfix "Maharashtra"	"Ahmednagar"	"Ahamadnagar"
cityfix "Maharashtra"	"Ahamadnagar-Cantt"	"Ahmadnagar Cantt."
cityfix "Maharashtra"	"Ahmadnagar Cantt."	"Ahmadnagar Cantt."
cityfix "Maharashtra"	"Ahmednagar CA"	"Ahmadnagar Cantt."
cityfix "Maharashtra"	"Ahmednagar Cant."	"Ahmadnagar Cantt."
cityfix "Gujarat"	"Ahmadabad"	"Ahmedabad"
cityfix "Gujarat"	"Ahmedabad"	"Ahmedabad"
cityfix "Gujarat"	"AHMEDABAD CORP."	"Ahmedabad"
cityfix "Gujarat"	"AHMEDABAD-CORP."	"Ahmedabad"
cityfix "Mizoram"	"Aizawal"	"Aizawl"
cityfix "Mizoram"	"Aizawl"	"Aizawl"
cityfix "Kerala"	"Alappuzha"	"Alappuzha"
cityfix "Kerala"	"Allepey (Alepuzaha)"	"Alappuzha"
cityfix "Kerala"	"Alleppey (Alapuzha)"	"Alappuzha"
cityfix "Haryana"	"Ambala"	"Ambala"
cityfix "Haryana"	"Ambala Cantt."	"Ambala"
cityfix "Maharashtra"	"Amravati"	"Amravati"
cityfix "Maharashtra"	"Amravti Corp."	"Amravati"
cityfix "Maharashtra"	"Amravti M.C"	"Amravati"
cityfix "Gujarat"	"AMRELI"	"Amreli"
cityfix "Gujarat"	"Amreli"	"Amreli"
cityfix "Gujarat"	"ANAND"	"Anand"
cityfix "Gujarat"	"Anand"	"Anand"
cityfix "Andhra Pradesh"	"Anantapur"	"Anantapur"
cityfix "Andhra Pradesh"	"Ananthapur"	"Anantapur"
cityfix "Maharashtra"	"Anjangaon"	"Anjangaon"
cityfix "Maharashtra"	"Anjangoan"	"Anjangaon"
cityfix "Gujarat"	"ANJAR"	"Anjar"
cityfix "Gujarat"	"Anjar"	"Anjar"
cityfix "Andhra Pradesh"	"Ankapalla"	"Ankapalle"
cityfix "Andhra Pradesh"	"Ankapalle"	"Ankapalle"
cityfix "Gujarat"	"ANKLESHVAR"	"Ankleshwar"
cityfix "Gujarat"	"Ankleshwar"	"Ankleshwar"
cityfix "Gujarat"	"Anklesvar"	"Ankleshwar"
cityfix "Gujarat"	"ANKLESVAR"	"Ankleshwar"
cityfix "West Bengal"	"Asansol"	"Asansol"
cityfix "West Bengal"	"Assansol"	"Asansol"
cityfix "West Bengal"	"Ashoknagar  Kalyangarh"	"Ashoknagar  Kalyangarh"
cityfix "West Bengal"	"Ashoknagar/Kalyangarh"	"Ashoknagar  Kalyangarh"
cityfix "West Bengal"	"Ashoknagar-Kalyangarh"	"Ashoknagar  Kalyangarh"
cityfix "Maharashtra"	"Auragabad Corp"	"Aurangabad"
cityfix "Maharashtra"	"Aurangabad"	"Aurangabad"
cityfix "Maharashtra"	"Aurangabad-Corp"	"Aurangabad"
cityfix "Maharashtra"	"Aurangabad Cant."	"Aurangabad Cant."
cityfix "Maharashtra"	"Aurangabad Ct."	"Aurangabad Cant."
cityfix "Maharashtra"	"Aurangabad M.C"	"Aurangabad Cant."
cityfix "Maharashtra"	"Aurangabad-Cantt"	"Aurangabad Cant."
cityfix "West Bengal"	"Baharampur"	"Baharampur"
cityfix "West Bengal"	"Bahrampur"	"Baharampur"
cityfix "Bihar"	"Bakaro Steel City"	"Bakaro Steel City"
cityfix "Bihar"	"Bokaro Steel City"	"Bakaro Steel City"
cityfix "Orissa"	"Balangir"	"Balangiri"
cityfix "Orissa"	"Balangiri"	"Balangiri"
cityfix "Maharashtra"	"Balarpur"	"Ballarpur"
cityfix "Maharashtra"	"Ballarpur"	"Ballarpur"
cityfix "West Bengal"	"Bankuara"	"Bankuara"
cityfix "West Bengal"	"Bankura"	"Bankuara"
cityfix "Maharashtra"	"Baramati"	"Baramati"
cityfix "Maharashtra"	"Barmati"	"Baramati"
cityfix "West Bengal"	"Barddhaman"	"Barddhaman"
cityfix "West Bengal"	"Bardhaman"	"Barddhaman"
cityfix "Rajasthan"	"Barmar"	"Barmar"
cityfix "Rajasthan"	"Barmer"	"Barmar"
cityfix "West Bengal"	"Barrackpur"	"Barrackpur"
cityfix "West Bengal"	"Baruipur"	"Barrackpur"
cityfix "Bihar"	"Bagbera (Mango)"	"Begbera (Mango)"
cityfix "Bihar"	"Begbera (Mango)"	"Begbera (Mango)"
cityfix "Bihar"	"Mango"	"Begbera (Mango)"
cityfix "Karnataka"	"Belagum"	"Belgaum"
cityfix "Karnataka"	"Belgaum"	"Belgaum"
cityfix "Karnataka"	"Bhadravathi"	"Bhadravathi"
cityfix "Karnataka"	"Bhadravati"	"Bhadravati"
cityfix "Karnataka"	"Bhadravati (M)"	"Bhadravati"
cityfix "Karnataka"	"Bhadravati(NTB)"	"Bhadravati (NTB)"
cityfix "Gujarat"	"BHARUCH"	"Bharuch"
cityfix "Gujarat"	"Bharuch"	"Bharuch"
cityfix "Gujarat"	"Bhavnagar"	"Bhavnagar"
cityfix "Gujarat"	"BHAVNAGAR CORP."	"Bhavnagar"
cityfix "Gujarat"	"BHAVNAGAR-CORP."	"Bhavnagar"
cityfix "Andhra Pradesh"	"Bharmavaram"	"Bheemavaram"
cityfix "Andhra Pradesh"	"Bheemanaham"	"Bheemavaram"
cityfix "Andhra Pradesh"	"Bheemavaram"	"Bheemavaram"
cityfix "Andhra Pradesh"	"Bhimavaram"	"Bheemavaram"
cityfix "Andhra Pradesh"	"Bheemunipatam"	"Bhemunipatnam"
cityfix "Andhra Pradesh"	"Bheemunipatnam"	"Bhemunipatnam"
cityfix "Andhra Pradesh"	"Bhemunipatnam"	"Bhemunipatnam"
cityfix "Madhya Pradesh"	"Bhilai Nagar"	"Bhilai"
cityfix "Madhya Pradesh"	"Bhilainagar"	"Bhilai"
cityfix "Rajasthan"	"Bhilvara"	"Bhilwara"
cityfix "Rajasthan"	"Bhilwara"	"Bhilwara"
cityfix "Rajasthan"	"Bhitwara"	"Bhilwara"
cityfix "Maharashtra"	"Bhivandi"	"Bhivandi"
cityfix "Maharashtra"	"Bhiwandi"	"Bhivandi"
cityfix "Gujarat"	"BHUJ"	"Bhuj"
cityfix "Gujarat"	"Bhuj"	"Bhuj"
cityfix "West Bengal"	"Bidhanagar"	"Bidhanagar"
cityfix "West Bengal"	"Bidhannagar"	"Bidhanagar"
cityfix "Bihar"	"Bihar"	"Bihar"
cityfix "Bihar"	"Bihar Sharif"	"Bihar"
cityfix "Karnataka"	"Bijapur"	"Bijapur"
cityfix "Karnataka"	"Bijapura"	"Bijapur"
cityfix "Gujarat"	"BILIMAORA"	"Bilimora"
cityfix "Gujarat"	"BILIMORA"	"Bilimora"
cityfix "Gujarat"	"Bilimora"	"Bilimora"
cityfix "Gujarat"	"Bilimore"	"Bilimora"
cityfix "Madhya Pradesh"	"Bina"	"Bina"
cityfix "Madhya Pradesh"	"Bina Etawa"	"Bina"
cityfix "Andhra Pradesh"	"Bodham"	"Bodhan"
cityfix "Andhra Pradesh"	"Bodhan"	"Bodhan"
cityfix "Gujarat"	"Bersad"	"Borsad"
cityfix "Gujarat"	"Borsad"	"Borsad"
cityfix "Gujarat"	"BORSAD"	"Borsad"
cityfix "Gujarat"	"BOTAD" "Botad"
cityfix "Gujarat"	"Botad"	"Botad"
cityfix "West Bengal"	"Budge Budge"	"Budge Budge"
cityfix "West Bengal"	"Budge-Budge"	"Budge Budge"
cityfix "Uttar Pradesh"	"Bulandshahar"	"Bulandshahar"
cityfix "Uttar Pradesh"	"Bulandshahr"	"Bulandshahar"
cityfix "Maharashtra"	"Buldana"	"Buldhana"
cityfix "Maharashtra"	"Buldhana"	"Buldhana"
cityfix "Kerala"	"Calicut (Kozhikode)"	"Calicut (Kozhikode)"
cityfix "Kerala"	"Kozhikode"	"Calicut (Kozhikode)"
cityfix "Kerala"	"Kozhikode Corporation"	"Calicut (Kozhikode)"
cityfix "Kerala"	"Chalakkudy"	"Chalakkudy"
cityfix "Kerala"	"Chalakudy"	"Chalakkudy"
cityfix "Karnataka"	"Chamarajnagar"	"Chamarajnagar"
cityfix "Karnataka"	"Chamrajnagar"	"Chamarajnagar"
cityfix "West Bengal"	"Chandanagar"	"Chandanagar"
cityfix "West Bengal"	"Chandannagar"	"Chandanagar"
cityfix "West Bengal"	"Chandannagoor"	"Chandanagar"
cityfix "Gujarat"	"CHANDLODIYA"	"CHANDLODIYA"
cityfix "Gujarat"	"CHANLODIA"	"CHANDLODIYA"
cityfix "Kerala"	"Changanacherry"	"Changanacherry"
cityfix "Kerala"	"Changanassery"	"Changanacherry"
cityfix "Tamil Nadu"	"Madras"	"Chennai"
cityfix "Madhya Pradesh"	"Chhindwara"	"Chhindwara"
cityfix "Madhya Pradesh"	"Chinhindwara"	"Chhindwara"
cityfix "Karnataka"	"Chickmagalur"	"Chickmagalur"
cityfix "Karnataka"	"Chikkamagalur"	"Chickmagalur"
cityfix "Karnataka"	"Chikmagalur"	"Chickmagalur"
cityfix "Karnataka"	"Chikmangalore"	"Chickmagalur"
cityfix "Andhra Pradesh"	"Chilakaluripet"	"Chilakaluripet"
cityfix "Andhra Pradesh"	"Chilakaluripeta"	"Chilakaluripet"
cityfix "Tamil Nadu"	"Chinnamanur"	"Chinnamanur"
cityfix "Tamil Nadu"	"Chinnamur"	"Chinnamanur"
cityfix "Kerala"	"Chittur Thathamangalam"	"Chittur Thathamangalam"
cityfix "Kerala"	"Chittur-Thathamangalam"	"Chittur Thathamangalam"
cityfix "Kerala"	"Cochin"	"Cochin"
cityfix "Kerala"	"Kochi"	"Cochin"
cityfix "Kerala"	"Kochi Corporation"	"Cochin"
cityfix "Tamil Nadu"	"Cuddalore"	"Cuddalore"
cityfix "Tamil Nadu"	"Cuddalore City"	"Cuddalore"
cityfix "Andhra Pradesh"	"Cuddapah"	"Cuddapah"
cityfix "Andhra Pradesh"	"Cuddapak"	"Cuddapah"
cityfix "Gujarat"	"DABHOI"	"Dabhoi"
cityfix "Gujarat"	"Dabhoi"	"Dabhoi"
cityfix "Gujarat"	"DAHEGAM"	"DAHEGAM"
cityfix "Gujarat"	"DEHAGAM"	"DAHEGAM"
cityfix "Bihar"	"Darbhanga"	"Darbhanga"
cityfix "Bihar"	"Darbnanga"	"Darbhanga"
cityfix "Karnataka"	"Davanagere"	"Davangere"
cityfix "Karnataka"	"Davangere"	"Davangere"
cityfix "Gujarat"	"DEESA"	"Deesa"
cityfix "Gujarat"	"Deesa"	"Deesa"
cityfix "Uttar Pradesh"	"Dehradun"	"Dehradun"
cityfix "Uttar Pradesh"	"Dehradun Cantt."	"Dehradun"
cityfix "Maharashtra"	"Dehu R. Cant."	"Dehu Road (Cantt.)"
cityfix "Maharashtra"	"Dehu Rd Cant"	"Dehu Road (Cantt.)"
cityfix "Maharashtra"	"Dehu Road (Cantt)"	"Dehu Road (Cantt.)"
cityfix "Maharashtra"	"Dehu Road (Cantt.)"	"Dehu Road (Cantt.)"
cityfix "Maharashtra"	"Dehuroad-Cantt"	"Dehu Road (Cantt.)"
cityfix "Maharashtra"	"Deolali Cant"	"Deolali-Cantt"
cityfix "Maharashtra"	"Deolali Cant."	"Deolali-Cantt"
cityfix "Maharashtra"	"Deolali Cantt."	"Deolali-Cantt"
cityfix "Maharashtra"	"Deolali-Cantt"	"Deolali-Cantt"
cityfix "Andhra Pradesh"	"Dharamavaram"	"Dharamavaram"
cityfix "Andhra Pradesh"	"Dharmavaram"	"Dharamavaram"
cityfix "Gujarat"	"Dholka"	"Dholka"
cityfix "Gujarat"	"DHOLKA"	"Dholka"
cityfix "Gujarat"	"DHORAJI"	"Dhoraji"
cityfix "Gujarat"	"Dhoraji"	"Dhoraji"
cityfix "Gujarat"	"Dhrangadhra"	"Dhrangadhra"
cityfix "Gujarat"	"DHRANGDHRA"	"Dhrangadhra"
cityfix "Bihar"	"Dinapur"	"Dinapur"
cityfix "Bihar"	"Dinapur Nizamat"	"Dinapur"
cityfix "Tamil Nadu"	"Dindigul"	"Dindigul"
cityfix "Tamil Nadu"	"Dindigul City"	"Dindigul"
cityfix "Karnataka"	"Dodballapur"	"Dodballapur"
cityfix "Karnataka"	"Doddaballapura"	"Dodballapur"
cityfix "Gujarat"	"DAHOD"	"Dohad"
cityfix "Gujarat"	"Dohad"	"Dohad"
cityfix "West Bengal"	"Durgapur"	"Durgapur"
cityfix "West Bengal"	"Durgapur (N.A)"	"Durgapur"
cityfix "West Bengal"	"Durgapur (N.A.)"	"Durgapur"
cityfix "Andhra Pradesh"	"Eluru"	"Eluru"
cityfix "Andhra Pradesh"	"Elusau"	"Eluru"
cityfix "West Bengal"	"English Bazar"	"English Bazar"
cityfix "West Bengal"	"Englishbazar"	"English Bazar"
cityfix "Uttar Pradesh"	"Etah"	"Etah"
cityfix "Uttar Pradesh"	"Etawah"	"Etah"
cityfix "Uttar Pradesh"	"Faizabad"	"Faizabad"
cityfix "Uttar Pradesh"	"Faizabad-cum-Ayodhya"	"Faizabad"
cityfix "Haryana"	"Faribadad Complex Admn."	"Faribadad Complex Admn."
cityfix "Haryana"	"Faridabad Complex"	"Faribadad Complex Admn."
cityfix "Haryana"	"Faridabad Complex Admn."	"Faribadad Complex Admn."
cityfix "Uttar Pradesh"	"Farrukhabad-cum Fatehgarh"	"Farrukhabad-cum Fatehgarh"
cityfix "Uttar Pradesh"	"Farrukhabad-cum-Fategarh"	"Farrukhabad-cum Fatehgarh"
cityfix "Uttar Pradesh"	"Farrukhabad-Cum-Fatehgarh"	"Farrukhabad-cum Fatehgarh"
cityfix "Punjab"	"Ferozepur Cantt."	"Ferozepur Cantt."
cityfix "Punjab"	"Firozpur Cantt."	"Ferozepur Cantt."
cityfix "Punjab"	"Ferozepur City"	"Ferozepur City"
cityfix "Punjab"	"Firozpur"	"Ferozepur City"
cityfix "Karnataka"	"Gadag Batigeri"	"Gadag Batigeri"
cityfix "Karnataka"	"Gadag Betgeri"	"Gadag Batigeri"
cityfix "Karnataka"	"Gadag-Betigei"	"Gadag Batigeri"
cityfix "Karnataka"	"Gadag-Betigeri"	"Gadag Batigeri"
cityfix "Andhra Pradesh"	"Gajuvaka"	"Gajuwaka"
cityfix "Andhra Pradesh"	"Gajuwaka"	"Gajuwaka"
cityfix "Gujarat"	"GANDHIDHAM"	"Gandhidham"
cityfix "Gujarat"	"Gandhidham"	"Gandhidham"
cityfix "Gujarat"	"GANDHINAGAR"	"Gandhinagar"
cityfix "Gujarat"	"Gandhinagar"	"Gandhinagar"
cityfix "Gujarat"	"GANDHINAGAR-NA."	"Gandhinagar"
cityfix "Rajasthan"	"Gangapur"	"Gangapur"
cityfix "Rajasthan"	"Gangapur City"	"Gangapur"
cityfix "Rajasthan"	"Gangpur City"	"Gangapur"
cityfix "Karnataka"	"Gangavathi"	"Gangavathi"
cityfix "Karnataka"	"Gangawati"	"Gangawati"
cityfix "Tamil Nadu"	"Gobichettipalaiyam"	"Gobichettipalaiyam"
cityfix "Tamil Nadu"	"Gopichettipalaiyam"	"Gobichettipalaiyam"
cityfix "Gujarat"	"GONDAL"	"Gondal"
cityfix "Gujarat"	"Gondal"	"Gondal"
cityfix "Maharashtra"	"Gondia"	"Gondiya"
cityfix "Maharashtra"	"Gondiya"	"Gondiya"
cityfix "Andhra Pradesh"	"Gudivada"	"Gudivada"
cityfix "Andhra Pradesh"	"Gudiwada"	"Gudivada"
cityfix "Andhra Pradesh"	"Guntakal"	"Guntakal"
cityfix "Andhra Pradesh"	"Guntakul"	"Guntakal"
cityfix "West Bengal"	"Halisahar"	"Halisahar"
cityfix "West Bengal"	"Halishahar"	"Halisahar"
cityfix "Karnataka"	"Hari Har"	"Harihara"
cityfix "Karnataka"	"Harihara"	"Harihara"
cityfix "Gujarat"	"HIMATNAGAR"	"Himatnagar"
cityfix "Gujarat"	"Himatnagar"	"Himatnagar"
cityfix "Maharashtra"	"Hingli"	"Hingoli"
cityfix "Maharashtra"	"Hingoli"	"Hingoli"
cityfix "Maharashtra"	"Hinoli"	"Hingoli"
cityfix "Haryana"	"Hisar"	"Hisar"
cityfix "Haryana"	"Hissar"	"Hisar"
cityfix "Madhya Pradesh"	"Hosangabad"	"Hosangabad"
cityfix "Madhya Pradesh"	"Hoshangabad"	"Hosangabad"
cityfix "Karnataka"	"Hubli Dharwad"	"Hubli Dharwad"
cityfix "Karnataka"	"Hubli-Dharwad"	"Hubli Dharwad"
cityfix "West Bengal"	"Hugli-Chinaurah"	"Hugli-Chinaurah"
cityfix "West Bengal"	"Hugli-Chinsurah"	"Hugli-Chinaurah"
cityfix "West Bengal"	"Hugly-Chinsura"	"Hugli-Chinaurah"
cityfix "Karnataka"	"Iikal"	"Iikal"
cityfix "Karnataka"	"Ilkal"	"Iikal"
cityfix "Madhya Pradesh"	"Jabalpur"	"Jabalpur"
cityfix "Madhya Pradesh"	"Jabalpur Cant"	"Jabalpur Cant"
cityfix "Madhya Pradesh"	"Jabalpur Cantt."	"Jabalpur Cant"
cityfix "Andhra Pradesh"	"Jagityal"	"Jagityal"
cityfix "Andhra Pradesh"	"Jagtial"	"Jagityal"
cityfix "Punjab"	"Jalandhar"	"Jalandhar"
cityfix "Punjab"	"Jalandhar City"	"Jalandhar"
cityfix "Karnataka"	"Jamakandi"	"Jamakandi"
cityfix "Karnataka"	"Jamkhandi"	"Jamakandi"
cityfix "Gujarat"	"Jamnagar"	"Jamnagar"
cityfix "Gujarat"	"JAMNAGAR CORP."	"Jamnagar"
cityfix "Gujarat"	"JAMNAGAR-CORPO."	"Jamnagar"
cityfix "Bihar"	"Jamshedpur"	"Jamshedpur"
cityfix "Bihar"	"Jamshedpur & Tata Nagar Rly." "Colony	Jamshedpur"
cityfix "Gujarat"	"JETPUR"	"Jetpur"
cityfix "Gujarat"	"Jetpur"	"Jetpur"
cityfix "Rajasthan"	"Jhunjhunu"	"Jhunjhunu"
cityfix "Rajasthan"	"Jhunjhunun"	"Jhunjhunu"
cityfix "Bihar"	"Jagsalai"	"Jugsalai"
cityfix "Bihar"	"Jugsalai"	"Jugsalai"
cityfix "Gujarat"	"JUNAGADH"	"Junagarh"
cityfix "Gujarat"	"Junagadh"	"Junagarh"
cityfix "Gujarat"	"Junagarh"	"Junagarh"
cityfix "Maharashtra"	"Kabnoor"	"Kabnoor"
cityfix "Maharashtra"	"Kabnur"	"Kabnoor"
cityfix "Tamil Nadu"	"Kadaiyanallur"	"Kadaiyanallur"
cityfix "Tamil Nadu"	"Kadayanallur"	"Kadaiyanallur"
cityfix "Gujarat"	"KADI"	"Kadi"
cityfix "Gujarat"	"Kadi"	"Kadi"
cityfix "Andhra Pradesh"	"Kadiri"	"Kadiri"
cityfix "Andhra Pradesh"	"Kadisi"	"Kadiri"
cityfix "Andhra Pradesh"	"Kakinada"	"Kakinada"
cityfix "Andhra Pradesh"	"Kakinanda"	"Kakinada"
cityfix "Gujarat"	"KALOL"	"Kalol"
cityfix "Gujarat"	"Kalol"	"Kalol"
cityfix "Maharashtra"	"Kalyan"	"Kalyan"
cityfix "Maharashtra"	"Kalyan Dom Corp."	"Kalyan"
cityfix "Maharashtra"	"Kalyan-Dom. MC"	"Kalyan"
cityfix "Maharashtra"	"Kamptee"	"Kamptee"
cityfix "Maharashtra"	"Kampttee"	"Kamptee"
cityfix "Maharashtra"	"Kamptee Cant."	"Kamptee Cant."
cityfix "Maharashtra"	"Kamptee-Cantt"	"Kamptee Cant."
cityfix "Maharashtra"	"Kamtee Cant"	"Kamptee Cant."
cityfix "West Bengal"	"Kancharapara"	"Kancharapara"
cityfix "West Bengal"	"Kanchrapara"	"Kancharapara"
cityfix "Gujarat"	"KAPADVANJ"	"Kapadvanj"
cityfix "Gujarat"	"Kapadvanj"	"Kapadvanj"
cityfix "Tamil Nadu"	"Karaikkudi"	"Karaikkudi"
cityfix "Tamil Nadu"	"Karaikudi"	"Karaikkudi"
cityfix "Rajasthan"	"Karauli"	"Karauli"
cityfix "Rajasthan"	"Karaull"	"Karauli"
cityfix "Rajasthan"	"Karoli"	"Karauli"
cityfix "Kerala"	"Kasaragod"	"Kasargodu"
cityfix "Kerala"	"Kasargodu"	"Kasargodu"
cityfix "Gujarat"	"KESHOD"	"Keshod"
cityfix "Gujarat"	"Keshod"	"Keshod"
cityfix "Gujarat"	"KHAMBHAT"	"Khambhat"
cityfix "Gujarat"	"Khambhat"	"Khambhat"
cityfix "West Bengal"	"Kharagpur"	"Kharagpur"
cityfix "West Bengal"	"Kharapur Rly. Colony"	"Kharagpur"
cityfix "Maharashtra"	"Khopoli"	"Khopoli"
cityfix "Maharashtra"	"Kopoli"	"Khopoli"
cityfix "Maharashtra"	"Kirkee Cant"	"Kirkee Cant"
cityfix "Maharashtra"	"Kirkee Cant."	"Kirkee Cant"
cityfix "Maharashtra"	"Kirkee Cantt."	"Kirkee Cant"
cityfix "Karnataka"	"Kolar"	"Kolar"
cityfix "Maharashtra"	"Kolhapur"	"Kolhapur"
cityfix "Maharashtra"	"Kolhapur Corp."	"Kolhapur"
cityfix "Maharashtra"	"Kolhapur MC"	"Kolhapur"
cityfix "Maharashtra"	"Kolhapur-Corp"	"Kolhapur"
cityfix "West Bengal"	"Calcutta"	"Kolkata"
cityfix "West Bengal"	"Kolkata"	"Kolkata"
cityfix "West Bengal"	"Konnagar"	"Konnagar"
cityfix "West Bengal"	"Konnagor"	"Konnagar"
cityfix "Madhya Pradesh"	"Korba"	"Korba"
cityfix "Madhya Pradesh"	"Korba (MM)"	"Korba"
cityfix "Andhra Pradesh"	"Kothagadem"	"Kothagadem"
cityfix "Andhra Pradesh"	"Kothagudem (NAC)"	"Kothagadem"
cityfix "Tamil Nadu"	"Kovilpatti"	"Kovilpatti"
cityfix "Tamil Nadu"	"Kovilppati"	"Kovilpatti"
cityfix "Andhra Pradesh"	"Kukatpalle"	"Kukatpally"
cityfix "Andhra Pradesh"	"Kukatpalli"	"Kukatpally"
cityfix "Andhra Pradesh"	"Kukatpally"	"Kukatpally"
cityfix "West Bengal"	"Kulti Barakar"	"Kulti Barakar"
cityfix "West Bengal"	"Kulti Barakar (NM)"	"Kulti Barakar"
cityfix "Tamil Nadu"	"Kumba Konam"	"Kumba Konam"
cityfix "Tamil Nadu"	"Kumbakonam"	"Kumba Konam"
cityfix "Andhra Pradesh"	"Kurnool"	"Kurnool"
cityfix "Andhra Pradesh"	"Kurnoot"	"Kurnool"
cityfix "Andhra Pradesh"	"L. B. Nagar"	"L.B. Nagar"
cityfix "Andhra Pradesh"	"L.B. Nagar"	"L.B. Nagar"
cityfix "Rajasthan"	"Ladnu"	"Ladnu"
cityfix "Rajasthan"	"Ladnun"	"Ladnu"
cityfix "Gujarat"	"LIMBADI"	"Limbdi"
cityfix "Gujarat"	"Limbdi"	"Limbdi"
cityfix "Maharashtra"	"Lonavala"	"Lonawala"
cityfix "Maharashtra"	"Lonawala"	"Lonawala"
cityfix "Andhra Pradesh"	"Macharla"	"Macharla"
cityfix "Andhra Pradesh"	"Macherla"	"Macharla"
cityfix "Andhra Pradesh"	"Machrela"	"Macharla"
cityfix "Andhra Pradesh"	"Madanapalle"	"Madanapalli"
cityfix "Andhra Pradesh"	"Madanapalli"	"Madanapalli"
cityfix "Andhra Pradesh"	"Mahaboobnagar"	"Mahaboobnagar"
cityfix "Andhra Pradesh"	"Mahabubnagar"	"Mahaboobnagar"
cityfix "Andhra Pradesh"	"Mahbubnagar"	"Mahaboobnagar"
cityfix "Gujarat"	"MAHESANA"	"Mahesana"
cityfix "Gujarat"	"Mahesana"	"Mahesana"
cityfix "Gujarat"	"MAHUVA"	"Mahuva"
cityfix "Gujarat"	"Mahuva"	"Mahuva"
cityfix "Kerala"	"Malappuram"	"Malappuram"
cityfix "Kerala"	"Malapuram"	"Malappuram"
cityfix "Andhra Pradesh"	"Mancherial"	"Mancherial"
cityfix "Andhra Pradesh"	"Mancheryal"	"Mancherial"
cityfix "Gujarat"	"MANDAVI"	"Mandvi"
cityfix "Gujarat"	"Mandvi"	"Mandvi"
cityfix "Andhra Pradesh"	"Mangalagiri"	"Mangalagiri"
cityfix "Andhra Pradesh"	"Manglagiri"	"Mangalagiri"
cityfix "Gujarat"	"MANGAROL"	"Mangrol"
cityfix "Gujarat"	"Mangrel"	"Mangrol"
cityfix "Gujarat"	"Mangrol"	"Mangrol"
cityfix "West Bengal"	"Medinipur"	"Medinipur"
cityfix "West Bengal"	"Mednipur"	"Medinipur"
cityfix "Tamil Nadu"	"Melapalaiyam"	"Melapalaiyam"
cityfix "Tamil Nadu"	"Melappalaiyam"	"Melapalaiyam"
cityfix "Tamil Nadu"	"Mettupalaiyam"	"Mettupalaiyam"
cityfix "Tamil Nadu"	"Mettuppalaiyam"	"Mettupalaiyam"
cityfix "Gujarat"	"MODASA"	"Modasa"
cityfix "Gujarat"	"Modasa"	"Modasa"
cityfix "Uttar Pradesh"	"Modi Nagar"	"Modi Nagar"
cityfix "Uttar Pradesh"	"Modinagar"	"Modi Nagar"
cityfix "Punjab"	"Mukatsar"	"Mukatsar"
cityfix "Punjab"	"Muktsar"	"Mukatsar"
cityfix "Maharashtra"	"Greater Bombay"	"Mumbai"
cityfix "Maharashtra"	"Mumbai"	"Mumbai"
cityfix "Madhya Pradesh"	"Katni"	"Murwara"
cityfix "Madhya Pradesh"	"Murwara"	"Murwara"
cityfix "Madhya Pradesh"	"Murwara (Katni)"	"Murwara"
cityfix "Madhya Pradesh"	"Murwara(Katni)"	"Murwara"
cityfix "Gujarat"	"NADIAD"	"Nadiad"
cityfix "Gujarat"	"Nadiad"	"Nadiad"
cityfix "Tamil Nadu"	"Nagapattinam"	"Nagapattinam"
cityfix "Tamil Nadu"	"Nagappattinam"	"Nagapattinam"
cityfix "Tamil Nadu"	"Nagercoil"	"Nagercoil"
cityfix "Tamil Nadu"	"Nagercoil City"	"Nagercoil"
cityfix "Maharashtra"	"Nagpur"	"Nagpur"
cityfix "Maharashtra"	"Nagpur Cor."	"Nagpur"
cityfix "Maharashtra"	"Nagpur Corp."	"Nagpur"
cityfix "Maharashtra"	"Nagpur-Corp"	"Nagpur"
cityfix "West Bengal"	"Naihati"	"Naihati"
cityfix "West Bengal"	"Nalhati"	"Naihati"
cityfix "Maharashtra"	"Nanded-Waghala"	"Nanded-Wagla"
cityfix "Maharashtra"	"Nanded-Wagla"	"Nanded-Wagla"
cityfix "Maharashtra"	"Nandarbar"	"Nandurbar"
cityfix "Maharashtra"	"Nandurbar"	"Nandurbar"
cityfix "Andhra Pradesh"	"Nadyal"	"Nandyal"
cityfix "Andhra Pradesh"	"Nandyal"	"Nandyal"
cityfix "Andhra Pradesh"	"Narasaraopet"	"Narasarapet"
cityfix "Andhra Pradesh"	"Narasarapet"	"Narasarapet"
cityfix "Andhra Pradesh"	"Narayenpeta"	"Narasarapet"
cityfix "Andhra Pradesh"	"Narsapur"	"Narsapur"
cityfix "Andhra Pradesh"	"Narsarapela"	"Narsapur"
cityfix "Maharashtra"	"Nashik"	"Nashik"
cityfix "Maharashtra"	"Nashik Corp."	"Nashik"
cityfix "Maharashtra"	"Nashik M. Cor"	"Nashik"
cityfix "Rajasthan"	"Nasirabad Cantt"	"Nasirabad Cantt"
cityfix "Rajasthan"	"Nasirabad Cantt."	"Nasirabad Cantt"
cityfix "Rajasthan"	"Navalgarh"	"Navalgarh"
cityfix "Rajasthan"	"Nawalgarh"	"Navalgarh"
cityfix "Gujarat"	"Navasari"	"Navasari"
cityfix "Gujarat"	"NAVSARI"	"Navasari"
cityfix "Gujarat"	"Navsari"	"Navasari"
cityfix "Maharashtra"	"Navi Mum Corp."	"Navi Mum Corp."
cityfix "Maharashtra"	"Navi Mum M.C."	"Navi Mum Corp."
cityfix "Maharashtra"	"Navi Mumai"	"Navi Mum Corp."
cityfix "Maharashtra"	"New Bombay"	"Thane Corp."
cityfix "Maharashtra"	"New Bombay (Thane)"	"Thane Corp."
cityfix "Madhya Pradesh"	"Neemach"	"Neemach"
cityfix "Madhya Pradesh"	"Neemuch"	"Neemach"
cityfix "Tamil Nadu"	"Neilikuppam"	"Neilikuppam"
cityfix "Tamil Nadu"	"Nellikuppam"	"Neilikuppam"
cityfix "Andhra Pradesh"	"Nidadavole"	"Nidadavole"
cityfix "Andhra Pradesh"	"Nidadavolu"	"Nidadavole"
cityfix "Andhra Pradesh"	"Nizamabad"	"Nizamabad"
cityfix "Andhra Pradesh"	"Nizimabad"	"Nizamabad"
cityfix "Andhra Pradesh"	"Nuzivid"	"Nuzivid"
cityfix "Andhra Pradesh"	"Nuzvid"	"Nuzivid"
cityfix "Maharashtra"	"Ozar"	"Ozar"
cityfix "Maharashtra"	"Ozar Ct"	"Ozar"
cityfix "Maharashtra"	"Ozar CT"	"Ozar"
cityfix "Pondicherry"	"Ozhukarai"	"Ozhukarai"
cityfix "Pondicherry"	"Ozhukarai Block Area"	"Ozhukarai"
cityfix "Gujarat"	"PADARA"	"Padra"
cityfix "Gujarat"	"PADRA"	"Padra"
cityfix "Andhra Pradesh"	"Palacole"	"Palacole"
cityfix "Andhra Pradesh"	"Palakole"	"Palacole"
cityfix "Gujarat"	"PALANPUR"	"Palanpur"
cityfix "Gujarat"	"Palanpur"	"Palanpur"
cityfix "Gujarat"	"PALITANA"	"Palitana"
cityfix "Gujarat"	"Palitana"	"Palitana"
cityfix "Maharashtra"	"Pandhaprpur"	"Panharpur"
cityfix "Maharashtra"	"Pandharpur"	"Panharpur"
cityfix "Maharashtra"	"Panharpur"	"Panharpur"
cityfix "West Bengal"	"Panihat"	"Panihat"
cityfix "West Bengal"	"Panihati"	"Panihat"
cityfix "Maharashtra"	"Parli"	"Parli-Vaijnath"
cityfix "Maharashtra"	"Parli Vaij"	"Parli-Vaijnath"
cityfix "Maharashtra"	"Parli Vajinath"	"Parli-Vaijnath"
cityfix "Maharashtra"	"Parli-Vaijnath"	"Parli-Vaijnath"
cityfix "Andhra Pradesh"	"Parvathipuram"	"Parvathipuram"
cityfix "Andhra Pradesh"	"Parwathipuram"	"Parwathipuram"
cityfix "Gujarat"	"PATAN"	"Patan"
cityfix "Gujarat"	"Patan"	"Patan"
cityfix "Punjab"	"Patiala"	"Patiala"
cityfix "Punjab"	"Patilala"	"Patiala"
cityfix "Tamil Nadu"	"Pattukkotai"	"Pattukkotai"
cityfix "Tamil Nadu"	"Pattukkottai"	"Pattukkotai"
cityfix "Andhra Pradesh"	"Peddapuram"	"Peddapuram"
cityfix "Andhra Pradesh"	"Pithapuram"	"Peddapuram"
cityfix "Gujarat"	"Petlad"	"Petlad"
cityfix "Gujarat"	"PETLAD"	"Petlad"
cityfix "Maharashtra"	"Pimp-Chin"	"Pimpri-Chinchwad Porpn"
cityfix "Maharashtra"	"Pimp-Chin. Corp."	"Pimpri-Chinchwad Porpn"
cityfix "Maharashtra"	"Pimpri Chinchwad"	"Pimpri-Chinchwad Porpn"
cityfix "Maharashtra"	"Pimpri-Chinchwad Porpn"	"Pimpri-Chinchwad Porpn"
cityfix "Tamil Nadu"	"Poilachi"	"Poilachi"
cityfix "Tamil Nadu"	"Pollachi"	"Poilachi"
cityfix "Andhra Pradesh"	"Pomur"	"Ponnur"
cityfix "Andhra Pradesh"	"Ponnur"	"Ponnur"
cityfix "Gujarat"	"PORBANDAR"	"Porbandar"
cityfix "Gujarat"	"Porbandar"	"Porbandar"
cityfix "Andhra Pradesh"	"Preddatur"	"Preddatur"
cityfix "Andhra Pradesh"	"Prodatur"	"Preddatur"
cityfix "Andhra Pradesh"	"Proddatur"	"Proddutur"
cityfix "Andhra Pradesh"	"Proddutur"	"Proddutur"
cityfix "Tamil Nadu"	"Pudukkotai"	"Pudukkotai"
cityfix "Tamil Nadu"	"Pudukkottai"	"Pudukkotai"
cityfix "Maharashtra"	"Pune Cant"	"Pune Cant"
cityfix "Maharashtra"	"Pune Cant."	"Pune Cant"
cityfix "Maharashtra"	"Pune Cantt."	"Pune Cant"
cityfix "Maharashtra"	"Pune-Cantt"	"Pune Cant"
cityfix "Maharashtra"	"Pune"	"Pune Corp"
cityfix "Maharashtra"	"Pune  Corp."	"Pune Corp"
cityfix "Maharashtra"	"Pune Corp"	"Pune Corp"
cityfix "Andhra Pradesh"	"Qeethullapur"	"Qeethullapur"
cityfix "Andhra Pradesh"	"Qutubullapur"	"Qeethullapur"
cityfix "Karnataka"	"R. Banahatti"	"R. Banahatti"
cityfix "Karnataka"	"Rabkavi-Banhatti"	"R. Banahatti"
cityfix "Karnataka"	"Rabkavi-Baphatti"	"R. Banahatti"
cityfix "Uttar Pradesh"	"Rae Bareli"	"Rae Bareli"
cityfix "Uttar Pradesh"	"Rai Bareli"	"Rae Bareli"
cityfix "Andhra Pradesh"	"Rajahmundri"	"Rajahmundri"
cityfix "Andhra Pradesh"	"Rajahmundry"	"Rajahmundri"
cityfix "Tamil Nadu"	"Rajapalaiyam"	"Rajapalaiyam"
cityfix "Tamil Nadu"	"Rajapalaiyam City"	"Rajapalaiyam"
cityfix "Tamil Nadu"	"Rajapalalyam"	"Rajapalaiyam"
cityfix "Gujarat"	"Rajkot"	"Rajkot"
cityfix "Gujarat"	"RAJKOT CORP."	"Rajkot"
cityfix "Gujarat"	"RAJKOT-CORPO."	"Rajkot"
cityfix "Gujarat"	"Rajkut"	"Rajkot"
cityfix "Madhya Pradesh"	"Rajnanadgaon"	"Rajnanadgaon"
cityfix "Madhya Pradesh"	"Rajnandgaon"	"Rajnanadgaon"
cityfix "Madhya Pradesh"	"Raipur"	"Rajpur"
cityfix "West Bengal"	"Rajpur"	"Rajpur"
cityfix "West Bengal"	"Rajpur Sonarpur"	"Rajpur"
cityfix "Andhra Pradesh"	"Ramachandrapuram"	"Ramachandrapuram"
cityfix "Andhra Pradesh"	"Ramachandray\puram"	"Ramachandrapuram"
cityfix "Andhra Pradesh"	"Ramagunda(NAC)"	"Ramagundam"
cityfix "Andhra Pradesh"	"Ramagundam"	"Ramagundam"
cityfix "Punjab"	"Rampura"	"Rampura"
cityfix "Punjab"	"Rampura Phul"	"Rampura"
cityfix "West Bengal"	"Raniganj"	"Raniganj"
cityfix "West Bengal"	"Rayganj"	"Raniganj"
cityfix "Gujarat"	"RANIP"	"Ranip"
cityfix "Gujarat"	"Ranip"	"Ranip"
cityfix "Maharashtra"	"Ranagiri"	"Ratnagiri"
cityfix "Maharashtra"	"Ratnagiri"	"Ratnagiri"
cityfix "Orissa"	"Raurkela"	"Rourkela"
cityfix "Orissa"	"Rourkela C.T.S."	"Rourkela"
cityfix "Orissa"	"Raurkela Steel Township"	"Rourkela"
cityfix "Orissa"	"Rourkela S.T.S."	"Rourkela"
cityfix "Orissa"	"Rourkela S.T.S"	"Rourkela"
cityfix "Karnataka"	"Roberstsonpeti"	"Roberstsonpeti"
cityfix "Karnataka"	"Robertsonpet"	"Roberstsonpeti"
cityfix "Karnataka"	"Robertsonpeti"	"Roberstsonpeti"
cityfix "Madhya Pradesh"	"Sagar Cant"	"Sagar Cant"
cityfix "Madhya Pradesh"	"Sagar Cantt."	"Sagar Cant"
cityfix "Karnataka"	"Sahabad"	"Sahabad"
cityfix "Karnataka"	"Shahabad"	"Sahabad"
cityfix "Uttar Pradesh"	"Sahajahanpur"	"Sahajahanpur"
cityfix "Uttar Pradesh"	"Sahjahanpur"	"Sahajahanpur"
cityfix "Uttar Pradesh"	"Saharanpur"	"Saharanpur"
cityfix "Uttar Pradesh"	"Sahranpur"	"Saharanpur"
cityfix "Andhra Pradesh"	"Samalkot"	"Samalkot"
cityfix "Andhra Pradesh"	"Samalkota"	"Samalkot"
cityfix "Maharashtra"	"San-Mir-Kup."	"San-Mir-Kup."
cityfix "Maharashtra"	"San-Mir-Kup. Corp."	"San-Mir-Kup."
cityfix "Rajasthan"	"Sardarshahar"	"Sardarshahar"
cityfix "Rajasthan"	"Sardoarshahar"	"Sardarshahar"
cityfix "Gujarat"	"SAVARKUNDALA"	"Savarkundla"
cityfix "Gujarat"	"Savarkundia"	"Savarkundla"
cityfix "Gujarat"	"Savarkundla"	"Savarkundla"
cityfix "Madhya Pradesh"	"Sehora"	"Sehore"
cityfix "Madhya Pradesh"	"Sehore"	"Sehore"
cityfix "West Bengal"	"Serampore"	"Serampore"
cityfix "West Bengal"	"Serampur"	"Serampore"
cityfix "Gujarat"	"SHIHOR"	"SHIHOR"
cityfix "Gujarat"	"SHINOR"	"SHIHOR"
cityfix "Himachal Pradesh"	"Shimla"	"Shimla"
cityfix "Himachal Pradesh"	"Simla"	"Shimla"
cityfix "Maharashtra"	"Shirpur"	"Shirpur-War"
cityfix "Maharashtra"	"Shirpur-War"	"Shirpur-War"
cityfix "Kerala"	"Shoranur"	"Shoranur"
cityfix "Kerala"	"Shornur"	"Shoranur"
cityfix "Gujarat"	"SIDDHAPUR"	"Sidhpur"
cityfix "Gujarat"	"SIDHHAPUR"	"Sidhpur"
cityfix "Gujarat"	"Sidhpur"	"Sidhpur"
cityfix "Maharashtra"	"Solapaur"	"Solapur Corp"
cityfix "Maharashtra"	"Solapur"	"Solapur Corp"
cityfix "Maharashtra"	"Solapur Corp"	"Solapur Corp"
cityfix "Tamil Nadu"	"St. Thomas Mount-Cum-Pallavaram Cantt."	"St. Thomas Mount-Cum-Pallavaram Cantt."
cityfix "Tamil Nadu"	"St. Thomas Mount-cum-Pallavaram Cantt."	"St. Thomas Mount-Cum-Pallavaram Cantt."
cityfix "Rajasthan"	"Sujanagarh"	"Sujanagarh"
cityfix "Rajasthan"	"Sujangarh"	"Sujanagarh"
cityfix "Rajasthan"	"Suratgarh"	"Sujanagarh"
cityfix "Gujarat"	"Surat"	"Surat"
cityfix "Gujarat"	"SURAT CORP."	"Surat"
cityfix "Gujarat"	"SURENDRANAGAR"	"Surendranagar"
cityfix "Gujarat"	"Surendranagar"	"Surendranagar"
cityfix "Andhra Pradesh"	"Tadepallegudem"	"Tadepallegudem"
cityfix "Andhra Pradesh"	"Tadepalligudem"	"Tadepallegudem"
cityfix "Andhra Pradesh"	"Tadepattigudem"	"Tadepallegudem"
cityfix "Andhra Pradesh"	"Tadipatri"	"Tadipatri"
cityfix "Andhra Pradesh"	"Tadpatri"	"Tadipatri"
cityfix "Tamil Nadu"	"Tambaram"	"Tambaram"
cityfix "Tamil Nadu"	"Tamvaram"	"Tambaram"
cityfix "Punjab"	"Taran Taran"	"Taran Taran"
cityfix "Punjab"	"Tarn Taran"	"Taran Taran"
cityfix "Kerala"	"Tellicherry (Thalaserry)"	"Tellicherry (Thalaserry)"
cityfix "Kerala"	"Thalassery"	"Tellicherry (Thalaserry)"
cityfix "Maharashtra"	"Thane Corp"	"Thane Corp."
cityfix "Maharashtra"	"Thane Corp."	"Thane Corp."
cityfix "Maharashtra"	"Thane M. Cor"	"Thane Corp."
cityfix "Maharashtra"	"Thane"	"Thane Corp."
cityfix "Tamil Nadu"	"Thanjavur"	"Thanjavur"
cityfix "Tamil Nadu"	"Thanjavur City"	"Thanjavur"
cityfix "Kerala"	"Thiruvananthapuram"	"Thiruvananthapuram"
cityfix "Kerala"	"Thiruvannanthapuram"	"Thiruvananthapuram"
cityfix "Kerala"	"Trivandrum"	"Thiruvananthapuram"
cityfix "Kerala"	"Thodpuzha"	"Thodpuzha"
cityfix "Kerala"	"Thodupuzha"	"Thodpuzha"
cityfix "Tamil Nadu"	"Tindivamam"	"Tindivamam"
cityfix "Tamil Nadu"	"Tindivanam"	"Tindivamam"
cityfix "Andhra Pradesh"	"Tirupathi"	"Tirupathi"
cityfix "Andhra Pradesh"	"Tirupati"	"Tirupathi"
cityfix "Tamil Nadu"	"Tiruppattur"	"Tiruppattur"
cityfix "Kerala"	"Tirur"	"Tirur"
cityfix "Tamil Nadu"	"Tiruvottiyur"	"Tiruvottiyur"
cityfix "Tamil Nadu"	"Tiruvottyur"	"Tiruvottiyur"
cityfix "Tamil Nadu"	"Tirvottiyur"	"Tiruvottiyur"
cityfix "Maharashtra"	"Ulhansnagar"	"Ulhasnagar MC"
cityfix "Maharashtra"	"Ulhasnagar"	"Ulhasnagar MC"
cityfix "Maharashtra"	"Ulhasnagar Corp."	"Ulhasnagar MC"
cityfix "Maharashtra"	"Ulhasnagar MC"	"Ulhasnagar MC"
cityfix "Gujarat"	"UNJHA"	"Unjha"
cityfix "Gujarat"	"Unjha"	"Unjha"
cityfix "Gujarat"	"UPLETA"	"Upleta"
cityfix "Gujarat"	"Upleta"	"Upleta"
cityfix "Andhra Pradesh"	"Uppal Kalan"	"Uppal Kalan"
cityfix "Andhra Pradesh"	"Uppalkalan"	"Uppal Kalan"
cityfix "West Bengal"	"Uttar Kotrung"	"Uttar Kotrung"
cityfix "West Bengal"	"Uttarpara Kotrung"	"Uttar Kotrung"
cityfix "Gujarat"	"Vadodara"	"Vadodara"
cityfix "Gujarat"	"VADODARA CORP."	"Vadodara"
cityfix "Gujarat"	"VADODARA. CORP."	"Vadodara"
cityfix "Gujarat"	"VALSAD"	"Valsad"
cityfix "Gujarat"	"Valsad"	"Valsad"
cityfix "Tamil Nadu"	"Vaniyambadi"	"Vaniyambadi"
cityfix "Tamil Nadu"	"Vanlyambadi"	"Vaniyambadi"
cityfix "Gujarat"	"VAPI"	"Vapi"
cityfix "Gujarat"	"VAPI INA."	"Vapi"
cityfix "Goa"	"Margao"	"Vasco"
cityfix "Goa"	"Marmugao (Vasco)"	"Vasco"
cityfix "Goa"	"Mormugao"	"Vasco"
cityfix "Goa"	"Mormugao (Vasco)"	"Vasco"
cityfix "Goa"	"Vasco"	"Vasco"
cityfix "Gujarat"	"VEJALPUR"	"Vejalpur"
cityfix "Gujarat"	"Vejalpur"	"Vejalpur"
cityfix "Gujarat"	"VERAVAL PATAN"	"Veraval Patan"
cityfix "Gujarat"	"Veraval Patan"	"Veraval Patan"
cityfix "Gujarat"	"VERAVAL-PATAN"	"Veraval Patan"
cityfix "Andhra Pradesh"	"Vijayawada"	"Vijayawada"
cityfix "Andhra Pradesh"	"Vijaywada"	"Vijayawada"
cityfix "Andhra Pradesh"	"Visakhapatnam"	"Visakhapatnam"
cityfix "Andhra Pradesh"	"Vishakapatnam"	"Visakhapatnam"
cityfix "Andhra Pradesh"	"Vishakhapatnam"	"Visakhapatnam"
cityfix "Andhra Pradesh"	"Vishakhaptanam"	"Visakhapatnam"
cityfix "Gujarat"	"VISNAGAR"	"Visnagar"
cityfix "Gujarat"	"Visnagar"	"Visnagar"
cityfix "Gujarat"	"WADHAVAN"	"Wadhwan"
cityfix "Gujarat"	"Wadhwan"	"Wadhwan"
cityfix "Gujarat"	"WANKANER"	"Wankaner"
cityfix "Gujarat"	"Wankaner"	"Wankaner"
cityfix "Andhra Pradesh"	"Warangal"	"Warangal"
cityfix "Andhra Pradesh"	"Warangel"	"Warangal"
cityfix "Maharashtra"	"Waroda"	"Waroda"
cityfix "Maharashtra"	"Warora"	"Waroda"
cityfix "Andhra Pradesh"	"Yemmiganur"	"Yemmiganur"
cityfix "Andhra Pradesh"	"Yemmiganus"	"Yemmiganur"

* Add to address spellings that differ between data
cityfix "Gujarat" "Ankaleswar" "Ankleshwar"
cityfix "Gujarat" "Ankaleshwar" "Ankleshwar"
cityfix "Haryana" "Yamuna Nagar" "Yamunanagar"
cityfix "Maharashtra" "AGD" "Aurangabad"
cityfix "Oriss" "Rourkela S.T.S" "Raurkela"
cityfix "Orissa" "Rourkela C.T.S" "Raurkela"
cityfix "Rajasthan" "Chittaurgarh" "Chittorgarh"
cityfix "Tamil Nadu" "Thiruvannanthapuram" "Thiruvananthapuram"
* Note: maybe the obs on Chittor are actually Chittorgarh.

* This code is mostly from "Air Pollution Code"
replace city = "Bongaigaon" if city == "Bonbgaigaon" & state == "Assam"
replace state = "Assam" if city == "Bongaigaon" & state == "Bihar"
replace city = "Dhanbad" if state == "Bihar" & (city == "Dhanhad" | city == "Dhanabad")
replace city = "Daman Diu & Nagar Haveli" if city == "Daman, Diu, and Nagar Haveli" | city == "Daman, Diu, and Nagat Haveli"
replace city = "Sindri" if city == "Sindri, Jharia" & state == "Bihar"
replace city = "Dhanbad" if city == "Dahanbad" & state == "Bihar"
replace city = "Cochin" if city == "Ernakulam" & state == "Kerala"
replace city = "Thiruvananthapuram" if city == "Tiruvananthapuram"
replace city = "Korba" if city == "Kroba" & state == "Madhya Pradesh"
replace city = "Chandrapur" if city == "Chandarpur" & state == "Maharashtra"
replace city = "Chandrapur" if city == "Chanderpur" & state == "Maharashtra"
replace city = "Shilong" if city == "Shillong" & state == "Meghalaya" /* this is the only one of this bunch which makes any difference for "city data .do" */
replace city = "Pondicherry" if city == "Pondichery" & state == "Pondicherry"
replace city = "Ludhiana" if city == "Lundhiana" & state == "Punjab"
replace city = "Ludhiana" if city == "Lunhiana" & state == "Punjab"
replace city = "Mandi Gobindgarh" if city == "Mandi Gobind garh" & state == "Punjab"
replace state = "Rajasthan" if city == "Jaipur" & state == "Tamil Nadu"
replace city = "Tuticorin" if city == "Turicorin" & state == "Tamil Nadu"
replace city = "Dehradun" if city == "Dehradoon" & state == "Uttar Pradesh"
replace city = "Gajraula" if city == "Gajroula" & state == "Uttar Pradesh"
replace state = "Tamil Nadu" if city == "Madras" & state == "Uttar Pradesh"
replace city = "Howrah" if city == "Howarh" & state == "West Bengal"
replace state = "Uttar Pradesh" if city == "Varanasi" & state == "West Bengal"
replace city = "Anpara" if city == "Annapara"
replace city = "Vadodara" if city == "Baroda" & state == "Gujarat"
replace city = "Kochi" if city == "Cochin" & state == "Kerala"
replace city = "Thiruvananthapuram" if city == "Trivendrum" & state == "Kerala"
replace city = "Mumbai" if city == "Bombay" & state == "Maharashtra"
replace city = "Nashik" if city == "Nasik" & state == "Maharashtra"
replace city = "Chennai" if city == "Madras" & state == "Tamil Nadu"
replace city = "Kolkata" if city == "Calcutta" & state == "West Bengal"
replace city = "Pondicherry" if city == "Metropolyam"
replace city = "Dhanbad" if city == "Dahanbad" & state == "Bihar"

cap replace city = "Dombivali" if location == "M/s Chemiequip Ltd"

* These deal with Delhi naming problems that were in the original code for cleaning city infant mortality data.
replace city = "Delhi" if city == "Delhi M.C." & state == "Delhi"
replace city = "Delhi" if city == "New Delhi M.C." & state == "Delhi"
replace city = "Delhi" if city == "Delhi M. Corp." & state == "Delhi"
replace city = "Delhi" if city == "N.D.M.C." & state == "Delhi"
replace city = "Delhi" if city == "Dellhi M. Corp." & state == "Delhi"
replace city = "Delhi" if city == "New Delhi Municipal Corporation" & state == "Delhi"
replace city = "Delhi" if city == "Delhi Municipal Corporation" & state == "Delhi"
replace city = "Delhi" if city == "Delhi Cantt" & state == "Delhi"
replace city = "Delhi" if city == "Delhi Cantt." & state == "Delhi"
replace city = "Delhi" if city == "M.C.D" & state == "Delhi"
replace city = "Delhi" if city == "N.D.M.C" & state == "Delhi"

* These deal with other naming problems in the city-level infant mortality data. These are state-year cells where there are multiple cities 
*	with identical birth and mortality data, and in almost every case the cities just differ by typos. To choose which version is more 
*	correct I look up the two cities in google maps and note when it's not obvious which is correct--JSS
replace city = "Tadipatri" if city == "Tadapatri" & state == "Andhra Pradesh"
replace city = "Repalle" if city == "Reppalle" & state == "Andhra Pradesh"
replace city = "Narsaraopet" if city == "Narasarapet" & state == "Andhra Pradesh"
replace city = "Proddatur" if city == "Proddutur" & state == "Andhra Pradesh"
replace city = "Vizianagaram" if city == "Vazianagaram" & state == "Andhra Pradesh"
replace city = "Proddatur" if city == "Preddatur" & state == "Andhra Pradesh"
replace city = "Proddatur" if city == "Proddattur" & state == "Andhra Pradesh"
replace city = "Sahibganj" if city == "Sahipganj" & state == "Bihar"
replace city = "Danapur" if city == "Dinapur" & state == "Bihar"
replace city = "Danapur" if city == "Dinapur Nizama" & state == "Bihar"
replace city = "Hajipur" if city == "Hazipur" & state == "Bihar"
replace city = "Jamshedpur" if city == "Jamshedpur & Tata Nagar Rly. Colony" & state == "Bihar"
replace city = "Jamshedpur" if city == "Jameshedpur" & state == "Bihar"
replace city = "Dholka" if city == "Dnolka" & state == "Gujarat"
replace city = "Nadiad" if city == "Nandiad" & state == "Gujarat"
replace city = "Petlad" if city == "Patlad" & state == "Gujarat"
replace city = "Rewari" if city == "Rowari" & state == "Haryana"
replace city = "Hosapete" if city == "Hospet" & state == "Karnataka"
replace city = "Hosapete" if city == "Shospet" & state == "Karnataka"
replace city = "Kottayam" if city == "Kuttayam" & state == "Kerala"
replace city = "Palghat" if city == "Palakkad" & state == "Kerala"
replace city = "Quilon" if city == "Kollam" & state == "Kerala"
replace city = "Bina" if city == "Bina Stawa" & state == "Madhya Pradesh"
replace city = "Sagar Cant" if city == "Sagar Cantt" & state == "Madhya Pradesh"
replace city = "Jabalpur Cant" if city == "Jabalpur Cantt" & state == "Madhya Pradesh"
replace city = "Kurasia" if city == "Khurasia" & state == "Madhya Pradesh"
replace city = "Chalisgaon" if city == "Bhalisgaon" & state == "Madhya Pradesh" 
replace city = "Bid" if city == "Beed" & state == "Maharashtra" /* there are cities called both beed and bid in maharasthra, but we have identical city-level IM under both these city names, so arbitrarily choose that it's bid */
replace city = "Brajarajnagar" if city == "Barajarajnagar" & state == "Orissa"
replace city = "Baripada" if city == "Baripeda" & state == "Orissa"
replace city = "Rourkela" if city == "Raurkela" & state == "Orissa"
replace city = "Bhubaneswar" if city == "Bhubanswar" & state == "Orissa"
replace city = "Mansa" if city == "Mensa" & state == "Punjab"
replace city = "Ganganagar" if city == "Shri Ganganagar" & state == "Rajasthan"
replace city = "Puliyangudi" if city == "Pulliyangudi" & state == "Tamil Nadu"
replace city = "Kumaramangalam" if city == "Kumarapalaiyam" & state == "Tamil Nadu"
replace city = "Bodinayakkanur" if city == "Bodinayakanur" & state == "Tamil Nadu"
replace city = "Panruti" if city == "Paaruti" & state == "Tamil Nadu"
replace city = "Arkonam" if city == "Arakkonam" & state == "Tamil Nadu"
replace city = "Pallavaram" if city == "Pahavaram" & state == "Tamil Nadu"
replace city = "Uthagamandalam (Ootacamund)" if city == "Uthagamandalam" & state == "Tamil Nadu"
replace city = "Paramakkudi" if city == "Paramakudi" & state == "Tamil Nadu"
replace city = "Palayankottai" if city == "Palayamkottai" & state == "Tamil Nadu"
replace city = "Tiruchirapalli" if city == "Tiruchchirappalli" & state == "Tamil Nadu"
replace city = "Mettur" if city == "Mattur" & state == "Tamil Nadu"
replace city = "Kambam" if city == "Kumbam" & state == "Tamil Nadu"
replace city = "Krishnagiri" if city == "Karishanagiri" & state == "Tamil Nadu"
replace city = "Virudhunagar" if city == "Vriudunadar" & state == "Tamil Nadu"
replace city = "Virudhunagar" if city == "Virudunagar" & state == "Tamil Nadu"
replace city = "Dharmapuri" if city == "Dharampuri" & state == "Tamil Nadu"
replace city = "Mettur" if city == "Mattur" & state == "Tamil Nadu"
replace city = "Bahraich" if city == "Bhraich" & state == "Uttar Pradesh"
replace city = "Etah" if city == "Farrukhabad-cum Fatehgarh" & state == "Uttar Pradesh"
replace city = "Budaun" if city == "Badaun" & state == "Uttar Pradesh"
replace city = "Jalpaiguri" if city == "Jalpaigari" & state == "West Bengal"
replace city = "Jalpaiguri" if city == "Jalpalgurd" & state == "West Bengal"
replace city = "New Barrackpur" if city == "North Barrackpur" & state == "West Bengal" /* neither name has a match so arbitrarily choose one */
replace city = "Medinipur" if city == "Panskura" & state == "West Bengal" /* both are cities but looking at other obs confirms that it should be medinipur */

* One manual addition for a city which is sometimes missing a state code
replace state = "Bihar" if city == "Sindri"

* The Indian 2001 census just lists one city Durg-Bhilai Nagar, and the two cities of Durg and Bhilai are adjacent. The pollution data calls it Bhilai while the mortality data calls it Durg.
replace city = "Durg-Bhilai Nagar" if city == "Durg" | city == "Bhilai"

*********************************************
* Clean location names (these "locations" are the locations of the various air pollution monitors)

* Preliminary location replacements
replace location = "AVM Building" if location == "AVM Jewellery Building"
replace location = "BRC Udhna" if location == "B.R. C. Udhna" | location == "B.R.C , Udhna" | location == "B.R.C, Udhna" | location == "B.R.C. Udhana" | location == "BRC High School, Udhna" 
replace location = "Bankmore" if location == "Bank-more"

* AGRA
replace location = "Agra University" if location == "Agra Universtity" & state == "Uttar Pradesh"
replace location = "Taj Mahal" if location == "Tajmahal" & city == "Agra"
replace location = "ESI Hospital, Agra" if location == "ESI Hospital" & city == "Agra"

* AHMEDABAD
replace location = "AECO, Sabarmati" if location == "AECO Sabarmati" & city == "Ahmedabad" & state == "Gujarat"
replace location = "Cadila Bridge, Narol" if (location == "Cadilla Bridge, Narol" | location == "Cadilla Narol") & city == "Ahmedabad" & state == "Gujarat"
replace location = "GIDC, Naroda" if (location == "G.I.D.C.Naroda" | location == "GIDC Naroda" | location == "G.I.D.C., Naroda" | location == "Naroda GIDC" | location == "Naroda, GIDC" | location == "Narada, G I D C") & city == "Ahmedabad" & state == "Gujarat"
replace location = "LD Engineering College" if (location == "L.D. Engineering College" | location == "L.D.Engineering College") & city == "Ahmedabad" & state == "Gujarat"

* "AZL Behrampura/L.D. Engg." appears to be its own entry for the year 2002. There is already data for 2002 under LD Engineering College
replace location = "RC High School" if (location == "R.C. High School" | location == "R.C. High School, Mirzapur") & city == "Ahmedabad" & state == "Gujarat"
replace location = "Shardaben Hospital" if (location == "Shardaben Hospital, Ahmedabad" | location == "Shardaben Hospital, Saraspur") & city == "Ahmedabad" & state == "Gujarat"

* ALWAR
replace location = "MIA" if location == "M.I.A." & city == "Alwar" 
replace location = "RIICO Pump House, Alwar" if (location == "RIICO Pump House" | location == "RIICO Office Pump House") & city == "Alwar" 
replace city = "Alwar" if location == "Gaurav Solvex" & city == "" & state == "Rajasthan"

* Ajanta Chemicals (MIA) and MIA are two separate locations shown only for 93 & 94
replace location = "Gaurav Solvex Ltd" if location == "Gaurav Solvex" & city == "Alwar"
replace location = "Regional Office, Alwar" if location == "Regional Office" & city == "Alwar"

* ANGUL
* IN 1992, THE EXCEL FILE SHOWS NALCO listed as just a location--the city space is blank. It should be ANGUL. I PUT 1992 NALCO into ANGUL
replace city = "Angul" if (location == "NALCO" | location == "NALCO Township") & state == "Orissa"
replace location = "Reg. Office, Angul" if (location == "Regional Office" | location == "RO, Angul" | location == "R.O., Angul Township") & city == "Angul" 
replace location = "NALCO Township" if (location == "Angul Township, NALCO" | location == "NALCO Nagar" | location == "NALCO Township") & city == "Angul"
* 92/93 data for NALCO is different for NALCO Township so it will remain separate
replace location = "Reg. Office, Angul" if location == "Industrial Estate, Angul" & city == "Angul"

* ANKLESWHAR
replace location = "Durga Traders, Bhavna Farms" if (location == "Durga Traders, Bhavna Farms Society" | location == "Durga Traders, Bhavna Farmsociety" | location == "Durga Traders, Bhawna Farms Society") & city == "Ankleshwar" 
replace location = "Rallis India Ltd" if location == "Rallis India Ltd(Pharma)" | location == "Rallis India Ltd. ( Pharma)"

* ANPARA
replace location = "Anpara Colony" if (location == "Annapara Colony" | location == "Anapara Colony" | location == "Anpara Colony") & city == "Anpara" 

* AURANGABAD
replace location = "Reg. Off. MPC Board, Aurangabad" if location == "Regional Office, MPC Board" & city == "Aurangabad"

* BANGALORE
replace location = "AMCO Batteries" if location == "Amco Batteries" & city == "Bangalore"
replace location = "Anand Rao Circle" if (location == "Ananda Rao Circle" | location == "Anand Rao Circles") & city == "Bangalore"
replace location = "Jayanagar Police Station" if location == "Jayanagar Police Statition" & city == "Bangalore"
replace location = "Karnataka Soaps Detergents" if location == "Karnataka Soaps & Detergents (ASEA), Penya" | location == "Karnataka Soaps & Detergents(ASEA)"

* BHILAI
replace location = "Laghu Udyog Nigam" if (location == "Laghu Udhyog Nigam" | location == "Laghu Udhyong Nigam" | location == "Laghu Udyog Nigam" | location == "M.P Laghu Udyong Nigam Ltd" | location == "MP Laghu Udyog Nigam") & city == "Bhilai"

foreach loc in "Visak Hostel" "Visak Hostel, Sec.-15" "Visak Hostel, Sector-15" "Visak Hostel, Sec.-14" "Visak Hostel, Sector-14" "Visak Hostel, Sec.-13" "Visak Hostel, Sector-13" "Visak Hostel, Sec.-12" "Visak Hostel, Sector-12" "Visak Hostel, Sec.-11" "Visak Hostel, Sector-11" "Visak Hostel, Sec.-10" "Visak Hostel, Sector-10" "Visak Hostel, Sec.-9" "Visak Hostel, Sector-9" "Visak Hostel, Sec.-8" "Visak Hostel, Sector-8" "Visak Hostel, Sec.-7" "Visak Hostel, Sector-7" "Visak Hostel, Sec.-6" "Visak Hostel, Sector-6" "Visak Hostel, Sec.-5" "Visak Hostel, Sector-5" "Viask Hostel Sector-4" "Visak Hostel, Sector-4" "Visak Hostel, Sec.-4" "Visak Hostel, Sector -4" "Visak Hostel, Sec 4" "Visak Hostel, Sector 4" "Visak Hostel, Sector 5" "Visak Hostel, Sector 6" "Visak Hostel, Sector 7" "Visak Hostel, Sector 8" "Visak Hostel, Sector 9" "Visak Hostel, Sector 10" "Visak Hostel, Sector 11" "Visak Hostel, Sector 12" "Visak Hostel, Sector 13" "Visak Hostel, Sector 14" "Visak Hostel, Sector 15" {
	replace location = "Visak Hotel" if location == "`loc'" & city == "Bhilai"
}
replace location = "5/32 Bungalow Office" if (location == "5/32 Bunglow Office" | location == "Bungalow Office Building" | location == "Bunglow Office Building" | location == "RO Bangllow Office Bldg" | location == "RO, 5/32 Bungallow Office Bldg" | location == "Regional Office, 5/32 Bungalow Office Building") & city == "Bhilai"

* This is a SEPARATE location***location == "ACC Jamul Guest House"
* (BIT)is not a city. SINDRI
replace city = "Sindri" if city == "BIT"
* 1997 data has blank data

* BHOPAL
replace location = "Govindpura" if location == "Govindura" & city == "Bhopal"
replace location = "Hamida Road" if location == "Hamidia Road" & city == "Bhopal"
replace location = "South TT Nagar" if (location == "South T.T. Nagar" | location == "TT Nagar")& city == "Bhopal"

* BONGAIGON
replace location = "BRPL Export Hostel" if (location == "BRPL Exports Hostel" | location == "BRPL Expert Hostel") & city == "Bongaigaon"

* CHANDIGARH
replace location = "CPCB Office, Chandigarh" if location == "C.P.C.B. Office" & city == "Chandigarh"
replace location = "CPCB Office, Chandigarh" if location == "CPCB Office" & city == "Chandigarh"
replace location = "Environment Society" if location == "Envi-Society" & city == "Chandigarh"
replace location = "Modern Food Indl. Area" if (location == "Modern Food Industrial Area" | location == "Modern Food, Industrial Area" ) & city == "Chandigarh"
replace location = "Sector 17 C" if location == "Sec.-17 C" & city == "Chandigarh"

* CHANDRAPUR
replace location = "Administrative Building" if (location == "Administrative Bldg." | location == "Administrative Building, DIC" ) & city == "Chandrapur"
replace location = "MIDC Chandrapur" if (location == "M.I.D.C. Chandrapur" | location == "MIDC Chanadrapur" | location == "MIDC Chandrapur" | location == "MIDC Chnadrapur") & city == "Chandrapur"
replace location = "Regional Office, Bapat Nagar" if (location == "Sub Regional Office, Bapat Nagar" | location == "Bapat Nagar, Dombivali") & city == "Chandrapur"
replace location = "MPC Board, Chandrapur" if location == "MPC Board" & city == "Chandrapur"

* CHENNAI
replace location = "Thiruvottiyur" if (location == "Thirovittyur"| location == "Thiruvottiyur" ) & city == "Chennai" 
replace location = "Purasawakkam" if (location == "Puruswakkam" | location == "Puvaswakkam") & city == "Chennai"
replace location = "Santhome" if location == "Senthome" & city == "Chennai"

* CHITTOR
replace location = "RIICO, Chittor" if (location == "RIICO" | location == "RICCO") & city == "Chittor"

* COIMBATORE
replace location = "SIDCO Office" if location == "SIDCP Office" & city == "Coimbatore"
replace location = "Collector's Office" if (location == "Collectors Office" | location == "Distt. Collectors Office" ) & city == "Coimbatore"
replace location = "Sai Baba Colony" if (location == "Saibaba Colony" | location == "Saibaba Colony/Poniarajapuram" | location == "Ponniyarajapuram") & city == "Coimbatore"

* DAMAN DIU & NAGAR HAVELI
replace location = "Piperia Industrial Estate" if (location == "Piperia Indusstrial Estate" | location == "Piper Industrial Estate, Silwasa" | location == "Piperia Indl. Estate" | location == "Piperia Industrial Estate, Silwasa" ) & state == "Daman & Diu + Dadra & Nagar Haveli"
replace city = "Silvassa" if location == "Piperia Industrial Estate" & city == "Daman Diu & Nagar Haveli"

* This has changed the city from Daman Diu & Nagar Haveli to Silvassa
replace location = "PWD Office, Silvassa" if (location == "P.W.D Office, Silwasa" | location == "PWD Office, Silwasa") & state == "Daman & Diu + Dadra & Nagar Haveli" 
replace location = "PWD Office, Daman" if (location == "P.W.D. Office" | location == "PWD Office") & state == "Daman & Diu + Dadra & Nagar Haveli"

* DAMAN
replace location = "Daman (Somnath)" if location == "AMS IV, Somnath" & city == "Daman"

* DAMTAL
replace location = "Damtal" if location == " Damtal" & city == "Damtal"
replace location = "Old Road Damtal" if location == "Station No. 2, Old Ridge" & city == "Damtal"
replace location = "Regional Office, Damtal" if (location == "Station No. 1, Near Regional Office" | location == "Regional Office") & city == "Damtal"

* DEHRADUN
replace location = "Raipur Road" if location == "Raipur Road, Dehradun" & city == "Dehradun" 
replace location = "ESI Dispensary, Najafgarh Road" if location == "E.S.I Dispensary, Najafgarh Rd." | location == "E.S.I Dispensary, Najafgarh Road" | location == "E.S.I. Disp., Najafgarh Road" | location == "E.S.I. Dispensary, Najafgarh Rd" | location == "E.S.I. Dispensary, Najafgarh Road" | location == "E.S.I. Dispensary, Nazafgarh Road" | location == "ESI Disp, Najafgarh Road" | location == "ESI Disp., Najafgarh Road" | location == "ESI Dispensary Najafgarh Rd" | location == "ESI Dispensary, Najafargh Road Delhi"
* ESI Hospital, Agra is a different location. Both are listed in 1990 separately

* DELHI
replace location = "Shahdara" if location == "Shahadra" & city == "Delhi"
replace location = "Navyug School Sarojini Nagar" if (location == "N.Y School, Sarojini Nagar" | location == "Netaji Nagar PO / NY School, Sarojani Nagar") & city == "Delhi"
replace location = "Navyug School Sarojini Nagar" if (location == "Netaji Nagar Post Office" | location == "Netaji Nagar, Post Office") & city == "Delhi"
* There are 24 data points for this locale for 2001 b/c the data appears twice***

* DHANBAD
replace location = "Bankmore" if (location == "104, Bank - More" | location == "Bank-more" ) & city == "Dhanbad"
replace location = "Regional Office, Dhanbad" if (location == "R.O. Dhanbad" | location == "Regional Office" | location == "Regional Office Dhanbad") & city == "Dhanbad"
* There are 24 data points for this locale for 1997 b/c the data appears twice, second time the data is just a placeholder in the Jharkhand state***

replace location = "FCI Main Hospital" if location == "Near Police Station (FCI)"
replace city = "Sindri" if location == "FCI Main Hospital" & city == "Dhanbad"

* These cities are adjacent, and the RSP college obs have different city names but form a complete non-overlapping no-gap panel
cap ta month year if location == "RSP College"
replace city = "Dhanbad" if (city == "Sindri" | city == "Jharia") & location == "RSP College"

* DIMAPUR

* DOMBIVALI
replace city = "Dombivali" if location == "M/S Chemiequip Ltd., Ambarnath"
replace location = "Chemiequip Ltd." if (location == "Chemiequip Ltd.. Ambarnath" | location == "M/s Chemiequip Ltd" | location == "M/s Chemiequip Ltd, Ambarnath" | location == "M/s Chemiquip Ltd." | location == "M/S Chemiequip Ltd., Ambarnath") & city == "Dombivali"

replace location = "MIDC Phase II, Dombivali" if (location == "MIDC Phase-II" | location == "MIDC Phase-ll" | location == "MIDC Phase II") & city == "Dombivali"
replace city = "Dombivali" if location == "MIDC Phase II, Dombivali" & city == "Mumbai"

* FARIDABAD                       
replace location = "Escorts Medical Center" if (location == "Escort Medical Centre" | location == "Escorts Medical Centre")& city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No 63 Sec 9" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-10"  & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-11" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-12" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-13" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-14" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-15" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-16" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-17" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-18" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-19" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-20" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 266, Sec-9" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 63 Sec-9" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No. 63, Sec.-9" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "Kothi No.266, Sec-9"  & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-10" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-11" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-12" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-13" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-14" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-15" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-16" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-17" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-18" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-19" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-20" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "R.C.Kothi No. 63, Sec.-9" & city == "Faridabad"
replace location = "Kothi No. 63" if location == "RC Kothi No. 63 Sec. 9"  & city == "Faridabad"

* GAJRAULA
replace location = "Indira Chowk" if(location == "Indira Chowk, J.P. Nagar" | location == "Indira Chowk, JP Nagar" | location == "Indra Chowk") & city == "Gajraula"
replace location = "Ranaq Auto Ltd" if (location == "Ranuaq Auto Ltd" | location == "Raunao Ltd, Gajroula" | location == "Raunaq Ltd." | location == "Ranaq Auto Ltd" | location == "Raunao Ltd, Gajroula" | location == "Raunaq Ltd.") & city == "Gajraula" 
replace location = "Ranaq Auto Ltd" if location == "Raunao Ltd, Gajraula" & city == "Moradabad"
replace city = "Gajraula" if location == "Ranaq Auto Ltd" & city == "Moradabad"

* GHAZIABAD                          
replace location = "Indira Chowk" if location == "Indira Chowk, JP Nagar" & city == "Ghaziabad"
replace location = "Bulandshahar Rd" if (location == "Buland Shahar Rd" | location == "Bulandshahar Rd. Inustrial Area") & city == "Ghaziabad"

* GOBINDGARH
* COULD THE LOCATIONS UNDER THIS CITY BE FURTHER CONSOLIDATED???
replace location = "Malhotra Steels" if (location == "Malhotra Steels Mandi" | location == "Malhotra Steels, Ludhiana" | location == "Malhotra Steels, Mandi") & city == "Gobindgarh"
replace location = "Malhotra Steels" if location == "M/S Malhotra Steels Industrials Corps" & city == "Gobindgarh"
replace location = "Punjab Steel Mill" if location == "Punjab Steel Mills Mandi" & city == "Gobindgarh"
replace location = "Punjab Steel Mill" if location == "Punjab Steel Mills" & city == "Gobindgarh"

* GUWAHATI
replace location = "Brijhoria Science College" if location == "Birjhoria Science College" & city == "Guwahati"
replace location = "Gopal Brothers H.S. School" if location == "Gopal Brothers H.S. School, G. Puri" & city == "Guwahati"
replace location = "Head Office, Bamunimadam" if location == "Head Office (Bamuniamaidan)" & city == "Guwahati"
replace location = "Head Office, Bamunimadam" if location == "Head Office Bamuniamaidan" & city == "Guwahati"
replace location = "Head Office, Bamunimadam" if location == "Head Office Bamunimadam" & city == "Guwahati"
replace location = "Pan Bazar" if location == "Paltan Bazar" & city == "Guwahati"
replace location = "Pan Bazar" if location == "Panbazar" & city == "Guwahati"

* HALDIA
replace location = "WBIDC" if location == "WBHDC" & city == "Haldia"
replace location = "WBIDC" if location == "WBIC" & city == "Haldia"
replace location = "WBIDC" if location == "WBIIDC" & city == "Haldia"

* HOWRAH
replace location = "Howrah Municipal Corporation" if location == "Howrah Municipal Corportation" & city == "Howrah"
replace location = "Howrah Municipal Corporation" if location == "Municipal Corporation" & city == "Howrah"
replace location = "Naskarpara Pump House" if location == "N P. House (Ghllseri)" & city == "Howrah"
replace location = "Naskarpara Pump House" if location == "N.P. House" & city == "Howrah"
replace location = "Naskarpara Pump House" if location == "NP House, Ghuseri" & city == "Howrah"
replace location = "Naskarpara Pump House" if location == "Naskarpara Pump House (Ghuseri)" & city == "Howrah"
replace location = "Naskarpara Pump House" if location == "Naskarpara Pump House(Ghuseri)" & city == "Howrah"
replace location = "Naskarpara Pump House" if location == "Naskarpara Pump House(Ghuseri)," & city == "Howrah"

* HYDERABAD
replace location = "ABIDS Circle" if location == "ABIDS" | location == "Abids" | location == "ABIDS Circle General Post Office Buildin" | location == "ABIDS, Hyderabad" | location == "ABIDS Circle Hyderabad"
replace location = "Banjara Hills" if location == "Banjara Hills, Hyderabad"
replace location = "Nacharam Industrial Estate" if location == "Nacharam" | location == "Nacharam, Industrial Estate, Premises of" | location == "Nacharam, Hyderabad"
replace location = "NEERI, Tarnaka" if location == "Tarnaka" & city == "Hyderabad"
replace location = "NEERI, Tarnaka" if location == "Tarnaka NEERI Lab" | location == "Tarnaka, NEERI Lab. IICT Campus, Hyderab" | location == "Tarnaka, Hyderabad" | location == "Tarnaka"
replace location = "Uppal" if city == "Hyderabad" & (location == "UPPAL" | location == "Uppal, Hyderabad" | location == "Uppal, Modern Foods & Industries IDA, Hy" | location == "Uppal, Modern Foods & Industries IDA, Hyderabad")
replace location = "CITD Balanagar" if location == "C.I.T.D., Balanagar, Hyderabad" | location == "C.I.T.D., Balanagar, Plot no. A1 to A8,"
replace location = "Basni Industrial Area" if location == "Basni Indl Area"
replace location = "AK Road" if location == "A.K. Road" | location == "A K Road"
replace location = "BRC Udhna" if location == "BRC Udhana" | location == "BRC, Udhna" 
replace location = "RSP College" if location == "R.S.P. College"

* INDORE
replace location = "Assoc. of Industries, Pologround" if location == "Association at Inds Pologround" & city == "Indore"
replace location = "Assoc. of Industries, Pologround" if location == "Association of Industries, Pologround" & city == "Indore"
replace location = "MIG Colony" if location == "M I G Colony" & city == "Indore"
replace location = "Assoc. of Industries, Pologround" if location == "MP Laghu Udyong Nigam, Pologround" & city == "Indore"
replace location = "Assoc. of Industries, Pologround" if location == "Polaground" & city == "Indore"
replace location = "Assoc. of Industries, Pologround" if location == "Pologround" & city == "Indore"

* JABALPUR
* Napier Town only lists entries for 1992-95, Ravindra is only listed for 96, and Industrial Estate Ricchai is listed for 92-95

* JAIPUR
* Data point for 1995 Malviya, doesn't exist in original spreadsheet--it's blank. There is only data in 2001-03
replace location = "Jhotwara Industrial Area" if location == "Jothwara Agra Industry" & city == "Jaipur"
replace location = "Jhotwara Industrial Area" if location == "Jothwara Industrial Area" & city == "Jaipur"
replace location = "Jhotwara Industrial Area" if location == "Jothwara Industry Area" & city == "Jaipur"
replace location = "PHED Gandhi Nagar, Jaipur" if location == "PHED Gandhi Nagar" & city == "Jaipur"
replace location = "PHED Gandhi Nagar, Jaipur" if location == "PHED, Gandhi Nagar" & city == "Jaipur"
replace location = "PHED Gandhi Nagar, Jaipur" if location == "PHED, Gondipur" & city == "Jaipur"
replace location = "PHED Gandhi Nagar, Jaipur" if location == "PHED,Gandhi Nagar" & city == "Jaipur"
replace location = "PHED Gandhi Nagar, Jaipur" if location == "Gandhi Nagar" & city == "Jaipur"
replace location = "Jhalna Doongri Board Office" if location == "Board Office (Jhalna Doongri)" & city == "Jaipur"
replace location = "Jhalna Doongri Board Office" if location == "Jhalna Doongri" & city == "Jaipur"

* JALANDHAR
replace location = "Inderson's Leather Pvt Ltd" if location == "Inderson's Leather P.Ltd" & city == "Jalandhar"
replace location = "Inderson's Leather Pvt Ltd" if location == "Inderson's Leather Pvt. Ltd." & city == "Jalandhar"
replace location = "Sporting Shop" if location == "Beat All Sports" & city == "Jalandhar"
replace location = "Sporting Shop" if location == "Jeb Sports" & city == "Jalandhar"
replace location = "Sporting Shop" if location == "M/s Pubjab Maltex Pvt Ltd" & city == "Jalandhar"
replace location = "Sporting Shop" if location == "M/s Zed Sports" & city == "Jalandhar"
replace location = "Sporting Shop" if location == "M/s Zed Sports Complex" & city == "Jalandhar"
replace location = "Regional Office, Jalandhar" if location == "Regional Office" & city == "Jalandhar"

* JAMSHEDPUR
replace location = "Burma Mines Water Tower" if location == "Burmamilles Water Tower" & city == "Jamshedpur"
replace location = "Burma Mines Water Tower" if location == "Burmamines Water Tower" & city == "Jamshedpur"
replace location = "Burma Mines Water Tower" if location == "Burmanmines Water Tower" & city == "Jamshedpur"
replace location = "Golmuri Vehicle Testing Center" if location == "Golmuri" & city == "Jamshedpur"

* JHARIA
replace location = "MADA" if location == "M.A.D.A" & city == "Jharia"
replace location = "MADA" if location == "M.A.D.A." & city == "Jharia"

* RECHECK BOOKS, RSP College is listed under 3 separate cities***
replace location = "RSP College" if location == "R.S.P College" & city == "Jharia"

* JODPHUR
replace location = "Basni Industrial Area" if location == "RIICO Office, Basni Industrial Area" & city == "Jodhpur"
replace location = "Regional Office, Jodphur" if location == "Regional Office" & city == "Jodhpur"
replace location = "Regional Office, Jodphur" if location == "Regional Office/Maha Mandir Police Thane" & city == "Jodhpur"
replace location = "Regional Office, Jodphur" if location == "Mahamandir Corperation Building" & city == "Jodhpur"

replace location = "Agricultural University" if (location == "Agricultural University" | location == "Agriculture University" | location == "Agriculutre University") & city == "Kanpur"
replace location = "Deputy Ka Parao" if location == "Deputy Ka Parav" & city == "Kanpur"
replace location = "Forest and Training Center" if location == "Forest & Training Centre, Kidwai Nagar" & city == "Kanpur"
replace location = "Forest and Training Center" if location == "Forest &Training Centre" & city == "Kanpur"
replace location = "Forest and Training Center" if location == "Kidwai Nagar" & city == "Kanpur"
replace location = "JK Apartment" if location == "JK Apartments" & city == "Kanpur"
replace location = "Kotwali" if location == "Kotwali Bara Chauraha" & city == "Kanpur"
replace location = "Lajpat Nagar" if location == "Lajpat Nagar, Telephone Exhange" & city == "Kanpur"
replace location = "Lajpat Nagar" if location == "Lajpat Najar" & city == "Kanpur"
replace location = "Lajpat Nagar" if location == "Lajpat nagar" & city == "Kanpur"
replace location = "SP Engg Works" if location == "M/s Associated Chemical Pvt, Fajalganj" & city == "Kanpur"
replace location = "SP Engg Works" if location == "S P Engg Works, Fazalganj" & city == "Kanpur"
replace location = "SP Engg Works" if location == "S.P.Engg. Works,Fazalganj" & city == "Kanpur"
replace location = "SP Engg Works" if location == "SP Engg Works, Fazalganj" & city == "Kanpur"
replace location = "SP Engg Works" if location == "SP Engg Works, Razalganj" & city == "Kanpur"
replace location = "SP Engg Works" if location == "SP Engg. Works" & city == "Kanpur"
replace location = "Lajpat Nagar" if location == "Telephone Exchange, Lajpat Nagar" & city == "Kanpur"
replace location = "Head Post Office, Kanpur" if location == "HPO Govind Nagar" & city == "Kanpur"
replace location = "Head Post Office, Kanpur" if location == "Head Post Office" & city == "Kanpur"

************************
***Kotwali is apparently the police  office, and it's possible the HPO has been confused as the Post Office, when it may really be the Police Office???
************************

* KOCHI
* In 1993 Cochin became Kochi

replace location = "Cochin Port Trust" if location == "B.I.M.G. Road/Cochin Port Trust" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "BIMG Road/Cochin Port Trust" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "Cochin Port Trust (M.G. Rd.)" & city == "Kochi"
replace location = "Cochin Refineries" if location == "C.R.L Guest House (FACH)" & city == "Kochi"
replace location = "Cochin Refineries" if location == "C.R.L. Guest House, Thiruvomkulam" & city == "Kochi"
replace location = "Cochin Refineries" if location == "CRL Guest House" & city == "Kochi"
replace location = "Cochin Refineries" if location == "CRL Guest House (FACH)" & city == "Kochi"
replace location = "Cochin Refineries" if location == "CRL Guest House - FACT/Cochin Refineries Ltd" & city == "Kochi"
replace location = "Cochin Refineries" if location == "Cochin Refineries Ltd Guest House" & city == "Kochi"
replace location = "Cochin Refineries" if location == "FACT Udyogmandal" & city == "Kochi"
replace location = "Cochin Refineries" if location == "FACT/Cochin Refineries Ltd Guest House" & city == "Kochi"
replace location = "Cochin Refineries" if location == "FACT/Cochin Refineries Ltd Guest House, Ambalamughal" & city == "Kochi"
replace location = "Cochin Refineries" if location == "FACT/Udyag Mandal" & city == "Kochi"
replace location = "Cochin Refineries" if location == "Thiruvomkulam, C.R.L. Guest House" & city == "Kochi"
replace location = "Cochin Refineries" if location == "Thiruvomkulam, C.R.L. Guest House (FACH)" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "M G Road, Allahabad Bank (SPS" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "M.G. Road, Allahabad Bank (SPS)" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "MG Road" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "MG Road, Allahabad Bank (SPS)" & city == "Kochi"
replace location = "Cochin Port Trust" if location == "MG Road, Cochin Port Trust" & city == "Kochi"
replace location = "Eloor" if location == "Ellor" & city == "Kochi"
replace location = "Eloor" if location == "Eloor, Cochin" & city == "Kochi"
replace location = "Ernakulum" if location == "Ernakulam North" & city == "Kochi"
replace location = "Ernakulum" if location == "Ernakulum North" & city == "Kochi"
replace location = "Kalamassery" if location == "Kamassery" & city == "Kochi"
replace location = "NEERI, Kochi" if location == "CSIR Complex" & city == "Kochi"
replace location = "NEERI, Kochi" if location == "CSIR Complex, NEERI Lab" & city == "Kochi"
replace location = "PHED, Kochi" if location == "PHED" & city == "Kochi"
replace location = "CESE, Mandeville Garden (Gariohat)" if location == "CECE, Mandevitle Garden (Gariohat)" & city == "Kolkata"
replace location = "CESE, Mandeville Garden (Gariohat)" if location == "CESE Mandvitle Garden" & city == "Kolkata"
replace location = "CESE, Mandeville Garden (Gariohat)" if location == "CESE, Mandeville Gardell (Gariohal)" & city == "Kolkata"
replace location = "CESE, Mandeville Garden (Gariohat)" if location == "CESE, Mandeville Garden (Gariahat)" & city == "Kolkata"
replace location = "CESE, Mandeville Garden (Gariohat)" if location == "CESE, Mandevitle Garden (Gariohat)" & city == "Kolkata"
replace location = "Cossipore" if location == "Cossipore Police Station" & city == "Kolkata"
replace location = "Kasba" if location == "NERRI Zonal Lab,Kasba" & city == "Kolkata"
replace location = "Lal Bazar" if location == "Lal Bazzar" & city == "Kolkata"
replace location = "Lal Bazar" if location == "Lal Bazzar, Dalhousie" & city == "Kolkata"
replace location = "Lal Bazar" if location == "Lal-Bazar" & city == "Kolkata"
replace location = "Gitanjali Bhawan" if location == "Gitanjali Bhawan, Old Bus Stand" & city == "Korba"
replace location = "Gitanjali Bhawan" if location == "Gitanjali Shawan" & city == "Korba"
replace location = "NTPC Colony, Pragati Nagar" if location == "NTPC Colony, Pragti Ngr." & city == "Korba"
replace location = "NTPC Colony, Pragati Nagar" if location == "Patgati Nagar NTPC Colony" & city == "Korba"
replace location = "NTPC Colony, Pragati Nagar" if location == "Pragati Nagar NTPC Colony" & city == "Korba"
replace location = "NTPC Colony, Pragati Nagar" if location == "Pragati Nagar, NTPC Colony" & city == "Korba"
replace location = "Regional Office, Akelgarh" if location == "Akelgarh (RO)" & city == "Kota"
replace location = "Regional Office, Akelgarh" if location == "Akelgarh (Regional Office)" & city == "Kota"
replace location = "Regional Office, Akelgarh" if location == "Akelgarh Regional Office" & city == "Kota"
replace location = "Regional Office, Anantpura" if location == "Anantpura" & city == "Kota"
replace location = "Borkhera" if location == "Barkhera" & city == "Kota"
replace location = "Regional Office, Anantpura" if location == "RICO Office, Anatpura" & city == "Kota"
replace location = "Regional Office, Anantpura" if location == "RIICO Office" & city == "Kota"
replace location = "Regional Office, Anantpura" if location == "RIICO Office, Anantpura" & city == "Kota"
replace location = "Veterinary Hospital" if location == "Veternary Hospital" & city == "Kota"
replace location = "Veterinary Hospital" if location == "Vetrenary Hosipital" & city == "Kota"
replace location = "Veterinary Hospital" if location == "Vetrinary Hospital" & city == "Kota"

replace state = "Kerala" if city == "Chingavanam"

replace location = "M/S Carborundum Univ Ltd" if location == "Carborandum Univ. Ltd, Kanjokode" & city == "Calicut (Kozhikode)"
replace location = "M/S Carborundum Univ Ltd" if location == "M/S Carborundum Universal LtD. Kanjikkode" & city == "Palakkad"
replace location = "M/S Carborundum Univ Ltd" if location == "M/S Carborundum Universal LtD. Kanjikkode" & city == "Calicut (Kozhikode)"
replace location = "Mavoor/Nallalam" if location == "Mavoor" & city == "Calicut (Kozhikode)"
replace location = "Mavoor/Nallalam" if location == "Mayur" & city == "Calicut (Kozhikode)"
replace location = "Mavoor/Nallalam" if location == "Nallalam" & city == "Calicut (Kozhikode)"
replace location = "Goyal Market" if location == "Goyel Market" & city == "Lucknow"
replace location = "Kapoor Hotel" if location == "Kapoor Hotel, Hazratganj" & city == "Lucknow"
replace location = "Kapoor Hotel" if location == "Kapoor Hotel, Hazratjanj" & city == "Lucknow"
replace location = "Kapoor Hotel" if location == "Kapoor Hptel, Hazratgang" & city == "Lucknow"
replace location = "Kapoor Hotel" if location == "Kapoorthala Complex" & city == "Lucknow"

* LUDHIANA
replace location = "Clock Tower" if location == "Clock Tower MC Office" | location == "Near Clock Tower" & city == "Ludhiana"

* CHECK CLOCK TOWER DATA***
replace location = "Hero Cycle GT Road" if location == "Hero Cycle, G.T. Road" & city == "Ludhiana"
replace location = "Rita Sewing Machine" if location == "Rita Sewing Machines" & city == "Ludhiana"

replace location = "Rita Sewing Machine" if location == "Rita Sewing Machines" & city == "Gobindgarh"
replace city = "Ludhiana" if location == "Rita Sewing Machine" & city == "Gobindgarh"

replace location = "Clock Tower" if location == "Rita Clock Tower" & city == "Ludhiana"
replace location = "Office of PPCB, Ludhiana" if location == "Office of PPCB" & city == "Ludhiana"
	* Office of PPCB looks like it's something different==> check this OUT???**** only 12 data points for 2001 shown
replace location = "Malhotra Steels" if location == "Malhotra Steels, Ludhiana" | location == "Punjab Steel Mills, Ludhiana"

* MADURAI
replace location = "Kunnathur Chatram" if location == "Kumathur Chatram" & city == "Madurai"
replace location = "Kunnathur Chatram" if location == "Kunnathur Chatram East Avani Moolai Street" & city == "Madurai"
replace location = "Fenner (I) Ltd" if location == "Tenner(s) Ltd, Employees Association Bldg." & city == "Madurai"
replace location = "M.K. Evening College" if location == "M.K. University Evening College" & city == "Madurai"
replace location = "M.K. Evening College" if location == "M.K Evening College"

* MORADABAD
replace location = "Indira Chowk" if location == "Indra Chowk, Gajroula" & city == "Moradabad"
* MORADABAD is NOT the same as GAJRAULA. BUT, CHECK with MANDI GOBINDGARH AND MALHOTRA STEELS!!!***
replace location = "Kopri Ward Office" if location == "Residential, Kopri Ward Office, Thane East"

* MUMBAI
replace location = "Bandra" if location == "Vinoba Bhawan, Bandra" & city == "Mumbai"
* Thane West and Shahu Market are two separate locations since they are both separately listed in year 2000

replace location = "Thane West" if location == "Industrial, Thane West"
replace location = "Thane West" if location == "Thane (W)"
replace location = "Shahu Market" if location == "Commerical, Shaha Market, Thane West"

* MUNDI GOBINDGARH)
* Mundi Gobindgarh altoghether is not a city, it should be listed as Gobindgarh***
replace city = "Gobindgarh" if city == "Mandi Gobindgarh"

* MYSORE
replace location = "Institute of Education" if location == "Institute of Education, Saraswathipuram" & city == "Mysore"
replace location = "Institute of Education" if location == "Institute of Education, Saraswthipuram" & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "K.I.A.D Bldg.,Metagulli" & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "KIAD Bldg., Metagulli" & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "K.I.A.D.B Bldg" & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "K.I.A.D.B. Bldg." & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "K.I.A.D.B. Building" & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "KIADB Bldg" & city == "Mysore"
replace location = "K.I.A.D.B. Bldg" if location == "KIADB Building" & city == "Mysore"
replace location = "K.R. Circle" if location == "K.R. Circle (Visw. Bldg.)" & (city == "Mysore" | (city == "" & state == "Haryana"))
replace location = "K.R. Circle" if location == "K.R. Circle, (Visw. Bldg.)" & city == "Mysore"
replace location = "K.R. Circle" if location == "K.R. Circle, Visvesvaraya Bldg" & city == "Mysore"
replace location = "K.R. Circle" if location == "K.R. Circle,Visweseraiya Bldg." & city == "Mysore"
replace location = "K.R. Circle" if location == "KR Circle, Visweseraiya Bldg" & city == "Mysore"
replace location = "KSPCB Bldg Hebbal Ind Area, Mysore" if location == "KSPCB Building Hebbal Industrial Area"

* KR Circle was listed under Haryana and Karnataka***
replace state = "Karnataka" if location == "K.R.Circle (Visw. Bldg)" & state == "Haryana"
replace city = "Mysore" if location == "K.R.Circle (Visw. Bldg)" 
replace location = "K.R. Circle" if location == "K.R.Circle (Visw. Bldg)" & city == "Mysore"

* NAGDA
replace location = "BCI Labour Club" if location == "B C I Labour Club" & city == "Nagda"
replace city = "Nagda" if location == "Nagda" & city == "" & state == "Madhya Pradesh"
replace location = "Chem Div Labour Club" if location == "Chemical Div. Labour Club" & city == "Nagda"
replace location = "Chem Div Labour Club" if location == "Chemical Division" & city == "Nagda"
replace location = "Chem Div Labour Club" if location == "Chemical Division Labour Club" & city == "Nagda"
replace location = "Chem Div Labour Club" if location == "Chemical Division, Nagda" & city == "Nagda"
replace location = "Grasim" if location == "Grasim Kalyan Kendra" & city == "Nagda"
replace location = "Grasim" if location == "Grasim Labor Club" & city == "Nagda"
replace location = "Grasim" if location == "Grasim Labour Club" & city == "Nagda"

* NAGPUR
replace location = "Gram Panchayat Bhavan" if location == "Gram Panchayat Bhavan, Kanhan"  & city == "Nagpur"
replace location = "Gram Panchayat Bhavan" if location == "Gram Panchayat Bhawan, Kanhan"  & city == "Nagpur"
replace location = "Gram Panchayat Bhavan" if location == "Gram Panchayat, Bhawan"  & city == "Nagpur"
replace location = "Hingna Road" if location == "Higna"  & city == "Nagpur"
replace location = "Hingna Road" if location == "Hingma"  & city == "Nagpur"
replace location = "Hingna Road" if location == "Hingna"  & city == "Nagpur"
replace location = "MIDC Hingna" if location == "MIDC Hingma" & city == "Nagpur"
replace location = "MIDC Hingna" if location == "MIDC Office, Hingma" & city == "Nagpur"
replace location = "MIDC Hingna" if location == "MIDC Office, Hingna" & city == "Nagpur"
replace location = "MIDC Hingna" if location == "MIDC, Hingna" & city == "Nagpur"
* MIDC Office, Hingna and MIDC Office Hinga Road are listed as two separate entries only in year 1999***
* Hingna Road is missing data in 1999, figure out which is which, CHECK ORIGINAL 1999
replace location = "MIDC Hingna" if location == "MIDC Office, Hingna Road" & city == "Nagpur"
replace location = "MRD Bank, Ganeshpath" if location == "MRD Bank, Ganesphpath" & city == "Nagpur"
replace location = "MRD Bank, Ganeshpath" if location == "MRD Bank, Goneshpeth" & city == "Nagpur"
replace location = "NEERI, Nagpur" if location == "Neeri" & city == "Nagpur"
replace location = "NEERI, Nagpur" if location == "NEERI" & city == "Nagpur"
replace location = "Panchayat Samiti, Kanhan" if location == "Panchayat Samiti Kanhan" & city == "Nagpur"
replace location = "Sokta Bhawan, Gandhi Bagh" if location == "Sokta Bhawar, Gandhibagh" & city == "Nagpur"
replace location = "Reg. Off. MPC Board, Nagpur" if location == "Regional Office, MPC Board" & city == "Nagpur"

* NASHIK
replace location = "MIDC Satpur" if location == "VIP Industrial Area, MIDC Satpura" & city == "Nashik" 
replace location = "Regional Office, Nashik" if location == "Regional Office" & city == "Nashik"
* CHECKED OUT THE REGIONAL OFFICE DATA listed for Nashik and it is only listed for one year 1994

* NOIDA
* This city only has two listings, M/s Dinsons India Pvt Ltd and M/s Gee Pee Electroplating & Engg. Work
* This IS a separate city

* PANAJI
* PAONTA SAHIB
* The 1997 data shows 24, but really there are no data points in a duplicated Poanta Sahib Town entry. DELETE??

replace location = "Gondhpur Industrial Area" if location == "Industrial Area, Gondhpur" & city == "Paonta Sahib"
replace location = "Gondhpur Industrial Area" if location == "Industrial Area, Gondhpur Paonta" & city == "Paonta Sahib" 
replace location = "PS Industrial Area" if location == "P.S. Industrial Area" & city == "Paonta Sahib"
replace location = "Industrial Area, Paonta Sahib" if location == "PS Industrial Area" & city == "Paonta Sahib"
replace location = "Industrial Area, Paonta Sahib" if location == "Paonta Sahib Town" & city == "Paonta Sahib"
replace location = "Industrial Area, Paonta Sahib" if location == "Industrial Area" & city == "Paonta Sahib"

replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Indl. Area, Sect.-1"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -1"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -10"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -11"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -12"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -2"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -3"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -4"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -5"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -6"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -7"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -8"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sec -9"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sector 1"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sector I"
replace location = "Vikram Farm Indl. Area" if location == "Vikram Farm Industrial Area, Sector-1"

* PARWANOO
replace location = "Regional Office Parwanoo" if location == "Regional Office" & city == "Parwanoo"

* PATIALA
* Patiala only has one listing as Patiala for yr 1993

* PATNA

* PONDA
replace location = "Head Office, Ponda" if location == "Head Office" & city == "Ponda" | location == "Ponda" & city == "Ponda"

* PONDICHERRY              
replace location = "PIDC Ind Estate" if location == "PIDC Ind Estate Metropolyam"
replace location = "PIDC Ind Estate" if location == "PIDC Ind. Estate"
replace location = "PIDC Ind Estate" if location == "PIDC Indl. Estate"
replace location = "PIDC Ind Estate" if location == "PIDC Industrial Estate"
replace location = "PIDC Ind Estate" if location == "PIPDIC Industrial Estate, Mettupalayam"
replace location = "PIDC Ind Estate" if location == "PIPDIC Metupalayam"
replace location = "Sectional Office" if location == "Sectional Office Upstairs" & state == "Pondicherry"
replace location = "Sectional Office" if location == "SO Building" & state == "Pondicherry"
replace location = "French Institute" if location == "FRENCH Institute" & state == "Pondicherry"
replace location = "Housing Office" if location == "Housing Board's Office" & state == "Pondicherry"
* Pondicherry has one listing if Agriculture Department in 2001, but it's not the same as those listed under Kanpur
* Agricultural Department onlys shows data for 2001 here under Pondicherry and it appears to be the only one in the spreadsheet
* Chamber of Commerce only shows data for 2002 & 2003

* PUNE
* Pimpri-Chinchwad is municipality in western India, in Maharashtra state, with a population of over 1 million.
* Pimpri-Chinchwad is a twin city of Pune and one of the biggest industrial centres in Asia.
* One of the most important village of pimpri Chinchwad is Bhosari
replace location = "Chinchwad" if location == "Chindwad" & city == "Pune Corp"
replace location = "Chinchwad" if location == "Chingawad" & city == "Pune Corp"
replace location = "Bhosari" if location == "Bhosai" & city == "Pune Corp"
replace location = "PCMC Chinchwad" if location == "PCMC Chinchawad" & city == "Pune Corp"
replace location = "Poud Phata" if location == "Poud Phata (Kothrud)"
replace location = "Poud Phata" if location == "Pound Phata (Kothrud)"
replace location = "Pune University" if location == "Poona University" & city == "Pune Corp"
replace location = "Pune University" if location == "Pune University Gate" & city == "Pune Corp"
replace location = "Pune University" if location == "University" & city == "Pune Corp"
replace location = "Pune University" if location == "University Gate" & city == "Pune Corp"
replace location = "Pune University" if location == "University Gate Mandvi" & city == "Pune Corp"
replace location = "Vehicular Road" if location == "Vehicular Traffic" & city == "Pune Corp"

* RAIPUR
replace location = "M/S Wool Worth India Pvt Ltd" if location == "M/S Wood Works I.P.Ltd. , Urla" & city == "Raipur"
replace location = "M/S Wool Worth India Pvt Ltd" if location == "M/S Wool Worth I.Pvt. Ltd." & city == "Raipur"
replace location = "M/S Wool Worth India Pvt Ltd" if location == "M/s Wool Worth India Pvt Ltd" & city == "Raipur"
replace location = "M/S Wool Worth India Pvt Ltd" if location == "M/s Woolworth India Pvt. Ltd. Urla" & city == "Raipur"
replace location = "M/S Wool Worth India Pvt Ltd" if location == "Woolworth LtD, Urla" & city == "Raipur"
replace location = "MPEB Substation Urla" if location == "MPEB Birgaon, Urla" & city == "Raipur"
replace location = "MPEB Substation Urla" if location == "MPEB Sub Station" & city == "Raipur"
replace location = "MPEB Substation Urla" if location == "MPEB Sub Station, Birgaon" & city == "Raipur"
replace location = "MPEB Substation Urla" if location == "MPEB Sub Station, Birgaon, Urla" & city == "Raipur"
replace location = "MPEB Substation Urla" if location == "MPEB Sub. Station, Urla" & city == "Raipur"
replace location = "MPEB Substation Urla" if location == "Urla" & city == "Raipur"
replace location = "New Hig, Hirapur" if location == "New Hig-888, Hirapur" & city == "Raipur"
replace location = "New Hig, Hirapur" if location == "New Hig-9, Hirapur" & city == "Raipur"

* RAJKOT
replace location = "Sardhara Industrial Corporation" if location == "S. Indl. Copn. 80 ft Road" & city == "Rajkot"
replace location = "Sardhara Industrial Corporation" if location == "Sardhara Industrial Corporation,80 ft road" & city == "Rajkot"
replace location = "Sardhara Industrial Corporation" if location == "Sardhara Industrial Corporation,80Ft.Road" & city == "Rajkot"
replace location = "St. Mary's School" if location == "St.Mary's School" & city == "Rajkot"
replace location = "Regional Office GPCB, Rajkot" if location == "Regional Office, GPCB" & city == "Rajkot"

* RAYAGADA
replace location = "Regional Office, Rayagada" if location == "Regional Office, Orissa" & city == "Rayagada"

* ROURKELA
replace location = "IDL-POST" if location == "IDL-POST (Sonaparbat)" & city == "Rourkela"
replace location = "IDL-POST" if location == "IDL-Police Outpost Sonaparbat" & city == "Rourkela"
replace location = "Municipality Office" if location == "Municiapality Office" & city == "Rourkela"
replace location = "Municipality Office, Rourkela" if location == "Municipality Office" & city == "Rourkela"
replace location = "Regional Office, Rourkela" if location == "Regional Office, Orissa SPCB" & city == "Rourkela"
replace city = "Rayagada" if city == "Jaykaypur"

* SALEM
replace location = "Sowdeswari College" if location == "Sowdeswari College Bldg" & city == "Salem"

* SATNA
replace location = "Regional Office, Satna" if location == "Regional Office, Madhya Pradesh SPCB" & city == "Satna"
replace location = "Bharhut Nagar" if location == "HIG-37, Bharhut Nagar" & city == "Satna"
replace location = "Industrial Area SD Office, Satna" if location == "Indl Area SD Office" & city == "Satna"
replace location = "Industrial Area SD Office, Satna" if location == "Industrial Area" & city == "Satna"
replace location = "Industrial Area SD Office, Satna" if location == "Industrial Area (SD Office)" & city == "Satna"
replace location = "Industrial Area SD Office, Satna" if location == "Industrial Area, Satna" & city == "Satna"
replace location = "Pushpraj Colony" if location == "Puspraj Coly, Bharat Nagar" & city == "Satna"
replace location = "Pushpraj Colony" if location == "Vipra Niwas Pushpraj Colony" & city == "Satna"

* SHILONG
replace location = "State Boards Office Permises" if location == "Boards Office Permises, Moninagar"  & city == "Shilong"

* SHIMLA
replace location = "Near Bus Stand" if location == "Bus Stand" & city == "Shimla"
replace location = "Near Bus Stand" if location == "Near Bus Stand Winter Field" & city == "Shimla"
replace location = "Near Bus Stand" if location == "Near Bus Stand, Station II (Winterfield)" & city == "Shimla"
replace location = "Near Bus Stand" if location == "Near Bus Stand, Winter Field" & city == "Shimla"
replace location = "Near Bus Stand" if location == "Near Bus Stand, Winterfield" & city == "Shimla"
replace location = "Tekka Beach Ridge" if location == "Tekka Bench Ridge" & city == "Shimla"

* SILVASSA
* Only==> Piperia Industrial Estate is listed under Silwasa for 1995
* for prior years, Piperia Industrial Estate is listed under Daman, Diu & Nagar Haveli
replace city = "Silvassa" if city == "Silwasa" & state == "Daman & Diu + Dadra & Nagar Haveli"

* SINDRI
replace location = "FCI Main Hospital" if location == "BIT Sindri" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "FCI Main Hospital Police Station, Sindri" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "FCI Main Hospital Station" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "FCI Main Hospital. BIT" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "Near Police Station (FCI Main Hospital)" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "Near Police Station(FCI Main Hospital" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "Near Police Station(FCI Main Hospital)" & city == "Sindri"
replace location = "FCI Main Hospital" if location == "P.Station (FCI Main Hospital)" & city == "Sindri"

* SURAT
replace location = "AIR Building" if location == "A.I.R.Building" & city == "Surat"
replace location = "AIR Building" if location == "Air India Building" & city == "Surat"
replace location = "SVR Engg College" if location == "S.V.R Engg College" & city == "Surat"
replace location = "SVR Engg College" if location == "S.V.R. Engg. College" & city == "Surat"
replace location = "SVR Engg College" if location == "SVR Engg. College" & city == "Surat"
replace location = "TT Nagar, Surat" if location == "Near India Office" & city == "Surat"

* TALCHER: Talcher is a city and a municipality in Anugul district in the Indian state of Orissa
replace location = "TTPS Colony" if location == "T.T.P.S. Colony" & city == "Talcher"

* THANE
replace location = "Thane West" if location == "Balkum/Kolshet Thane West" & city == "Thane Corp."
replace location = "Color Chem Ltd." if location == "Kolshet/Color Chem. Ltd." & city == "Thane Corp."
replace location = "Shahu Market" if location == "Sahu Market" & city == "Thane Corp."
replace location = "Shahu Market" if location == "Shahu Market, Thane West" & city == "Thane Corp."

* THIRUVANANTHAPURAM
replace location = "SV Raja" if location == "GV Raja School" & city == "Thiruvananthapuram"
replace location = "Shahu Market" if location == "Hi-Tech Chackai" & city == "Thiruvananthapuram"
replace location = "Shahu Market" if location == "Palmood" & city == "Thiruvananthapuram"
replace location = "Pattor RO" if location == "Patore RO" & city == "Thiruvananthapuram"
replace location = "Pattor RO" if location == "Pattor" & city == "Thiruvananthapuram"
replace location = "Pattor RO" if location == "Pattor R.O." & city == "Thiruvananthapuram"
replace location = "Pattor RO" if location == "Pattor Road" & city == "Thiruvananthapuram"
replace location = "SMV School" if location == "S.M.V. School" & city == "Thiruvananthapuram"
replace location = "SV Raja" if location == "S.V. Raja School" & city == "Thiruvananthapuram"
replace location = "Travancore Sulphate Ltd" if location == "Travancore" & city == "Thiruvananthapuram"
replace location = "Travancore Sulphate Ltd" if location == "Travancore Salphate Ltd" & city == "Thiruvananthapuram"
replace location = "Travancore Sulphate Ltd" if location == "Travancore Sulphate Ltd." & city == "Thiruvananthapuram"
replace location = "Travancore Sulphate Ltd" if location == "Travancore Suphate Ltd." & city == "Thiruvananthapuram"
replace location = "Regional Office, Pattor" if location == "Pattor RO"

* TUTICORIN
replace location = "Chemical Research Centre" if location == "Chemical Reasearch Centre" & city == "Tuticorin"
replace location = "Chemical Research Centre" if location == "Chemical Reseach Center" & city == "Tuticorin"
replace location = "Chemical Research Centre" if location == "Chemical Research Station" & city == "Tuticorin"
replace location = "Tuticorin" if location == "Tuticorin Tamil Nadu" & city == "Tuticorin"

* UDAIPUR
replace location = "DIC" if location == "D.I.C./M.I.A." & city == "Udaipur"
replace location = "Regional Office, Udaipur" if location == "Regional Office" & city == "Udaipur"
replace location = "Regional Office, Udaipur" if location == "Regional Office, MIA" & city == "Udaipur"

* VADODARA
replace location = "CETP, Nandesari" if location == "CETP" & city == "Vadodara"
replace location = "CETP, Nandesari" if location == "CETP Nandesari" & city == "Vadodara"
replace location = "Gujurat Pollution Control Board" if location == "GPCB Office, Geri Vasahat" & city == "Vadodara"
replace location = "Gujurat Pollution Control Board" if location == "GPCB Race Course" & city == "Vadodara"
replace location = "Gujurat Pollution Control Board" if location == "Gujrat Pollution Control" & city == "Vadodara"
replace location = "Gujurat Pollution Control Board" if location == "Gujrat Pollution Control Board" & city == "Vadodara"
replace location = "IPCL" if location == "I.P.C.L" & city == "Vadodara"
replace location = "Nyaya Mandir" if location == "Nyay Mandir" & city == "Vadodara"
replace location = "Nyaya Mandir" if location == "Nyaymandir" & city == "Vadodara"
replace location = "Gujurat Pollution Control Board" if location == "Regional Office, GPCB, Race Course" & city == "Vadodara"

* VAPI
replace location = "Regional Office GPCB, Vapi" if location == "G.P.C.B." & city == "Vapi"
replace location = "Regional Office GPCB, Vapi" if location == "GPCB" & city == "Vapi"
replace location = "Vapi" if location == "Vapi High School" & city == "Vapi"
replace location = "Vapi" if location == "Vapi Nagar Falka" & city == "Vapi"
replace location = "Vapi" if location == "Vapi Nagar Palika" & city == "Vapi"

* VARANASI
replace location = "Bhajubir" if location == "Bhojubir" & city == "Varanasi"

* VASCO
replace location = "Vasco" if location == "On the roof of Fuse Call Office of Electricity Department" & city == "Vasco"

* VISHAKHAPATNAM
replace location = "Police Barracks" if location == "Civil Defence Building, Jagdamba Centre" & city == "Visakhapatnam"
replace location = "Police Barracks" if location == "Civil Defense Building, Jagdamba Centre" & city == "Visakhapatnam"
replace location = "Industrial Estate, Merripalem" if location == "Industrial Estate, Marripalem" & city == "Visakhapatnam"

* YAMUNA NAGAR
replace location = "M/s Bellapur Industries" if location == "Bellapur Industries" & city == "Yamuna Nagar"
replace location = "M/s Bellapur Industries" if location == "M/s Ballapur Industries" & city == "Yamuna Nagar"

* Additional location typos found. Note in the pollution dataset, every city appears in only one state, so we don't need to add state restrictions to this stuff.
replace location = "Civil Defense Building, Jagdamba Centre" if location == "Civil Defence Building, Jagdamba Centre" & city == "Visakhapatnam"

************************************************************************
* The air pollution file has cities and we need it to have districts, so do the following.

cap pr drop citydist
pr de citydist
	replace district = "`3'" if state == "`1'" & city == "`2'"
end

citydist "Andhra Pradesh"	"Hyderabad"	"Hyderabad and Rangareddi"
citydist "Andhra Pradesh"	"Visakhapatnam"	"Visakhapatnam"
citydist "Assam"	"Bongaigaon"	"Bongaigaon"
citydist "Assam"	"Guwahati"	"Kamrup"
citydist "Bihar"	"Dhanbad"	"Dhanbad"
citydist "Bihar"	"Jamshedpur"	"Singhbhum"
citydist "Bihar"	"Jharia"	"Dhanbad"
citydist "Bihar"	"Patna"	"Patna"
citydist "Bihar"	"Sindri"	"Dhanbad"
citydist "Chandigarh"	"Chandigarh"	"Chandigarh"
citydist "Daman & Diu + Dadra & Nagar Haveli"	"Daman"	"Daman & Diu"
citydist "Daman & Diu + Dadra & Nagar Haveli"	"Daman Diu & Nagar Haveli"	"Daman & Diu"
citydist "Daman & Diu + Dadra & Nagar Haveli"	"Silvassa"	"Dadra & Nagar Haveli"
citydist "Delhi"	"Delhi"	"Delhi"
citydist "Goa"	"Panaji"	"Goa"
citydist "Goa"	"Ponda"	"Goa"
citydist "Goa"	"Vasco"	"Goa"
citydist "Gujarat"	"Ahmedabad"	"Ahmadabad"
citydist "Gujarat"	"Ankleshwar"	"Bharuch"
citydist "Gujarat"	"Jamnagar"	"Jamnagar"
citydist "Gujarat"	"Rajkot"	"Rajkot"
citydist "Gujarat"	"Surat"	"Surat"
citydist "Gujarat"	"Vadodara"	"Vadodara"
citydist "Gujarat"	"Vapi"	"Valsad"
citydist "Haryana"	"Faridabad"	"Faridabad"
citydist "Haryana"	"Yamuna Nagar"	"Yamuna Nagar"
citydist "Himachal Pradesh"	"Damtal"	"Kangra"
citydist "Himachal Pradesh"	"Paonta Sahib"	"Sirmaur"
citydist "Himachal Pradesh"	"Parwanoo"	"Solan"
citydist "Himachal Pradesh"	"Shimla"	"Shimla"
citydist "Karnataka"	"Bangalore"	"Bangalore (R+U)"
citydist "Karnataka"	"Mysore"	"Mysore"
citydist "Kerala"	"Kochi"	"Ernakulam"
citydist "Kerala"	"Kottayam"	"Kottayam"
citydist "Kerala"	"Calicut (Kozhikode)"	"Kozhikode"
citydist "Kerala"	"Palakkad"	"Palakkad"
citydist "Kerala"	"Thiruvananthapuram"	"Thiruvananthapuram"
citydist "Madhya Pradesh"	"Bhilai"	"Durg"
citydist "Madhya Pradesh"	"Bhopal"	"Bhopal"
citydist "Madhya Pradesh"	"Indore"	"Indore"
citydist "Madhya Pradesh"	"Jabalpur"	"Jabalpur"
citydist "Madhya Pradesh"	"Korba"	"Korba"
citydist "Madhya Pradesh"	"Nagda"	"Ujjain"
citydist "Madhya Pradesh"	"Raipur"	"Raipur"
citydist "Madhya Pradesh"	"Satna"	"Satna"
citydist "Maharashtra"	"Aurangabad"	"Aurangabad"
citydist "Maharashtra"	"Chandrapur"	"Chandrapur"
citydist "Maharashtra"	"Dombivali"	"Thane"
citydist "Maharashtra"	"Mumbai"	"Mumbai (Suburban) and Mumbai"
citydist "Maharashtra"	"Nagpur"	"Nagpur"
citydist "Maharashtra"	"Nashik"	"Nashik"
citydist "Maharashtra"	"Pune Corp"	"Pune"
citydist "Maharashtra"	"Solapur Corp"	"Solapur"
citydist "Maharashtra"	"Thane Corp."	"Thane"
citydist "Meghalaya"	"Shilong"	"East Khasi Hills"
citydist "Nagaland"	"Dimapur"	"Kohima"
citydist "Orissa"	"Angul"	"Dhenkanal"
citydist "Orissa"	"Rayagada"	"Koraput"
citydist "Orissa"	"Rourkela"	"Sundargarh"
citydist "Orissa"	"Talcher"	"Anugul"
citydist "Pondicherry"	"Pondicherry"	"Pondicherry"
citydist "Punjab"	"Gobindgarh"	"Fatehgarh Sahib"
citydist "Punjab"	"Jalandhar"	"Jalandhar"
citydist "Punjab"	"Ludhiana"	"Ludhiana"
citydist "Punjab"	"Patiala"	"Patiala"
citydist "Rajasthan"	"Alwar"	"Alwar"
citydist "Rajasthan"	"Chittor"	"Chittaurgarh"
citydist "Rajasthan"	"Jaipur"	"Jaipur"
citydist "Rajasthan"	"Jodhpur"	"Jodhpur"
citydist "Rajasthan"	"Kota"	"Kota"
citydist "Rajasthan"	"Udaipur"	"Udaipur"
citydist "Tamil Nadu"	"Chennai"	"Chennai"
citydist "Tamil Nadu"	"Coimbatore"	"Coimbatore"
citydist "Tamil Nadu"	"Madurai"	"Madurai"
citydist "Tamil Nadu"	"Salem"	"Salem"
citydist "Tamil Nadu"	"Tuticorin"	"Thoothukkudi"
citydist "Uttar Pradesh"	"Agra"	"Agra"
citydist "Uttar Pradesh"	"Anpara"	"Mirzapur"
citydist "Uttar Pradesh"	"Dehradun"	"Dehradun"
citydist "Uttar Pradesh"	"Gajraula"	"Moradabad"
citydist "Uttar Pradesh"	"Ghaziabad"	"Ghaziabad"
citydist "Uttar Pradesh"	"Kanpur"	"Kanpur Nagar"
citydist "Uttar Pradesh"	"Lucknow"	"Lucknow"
citydist "Uttar Pradesh"	"Moradabad"	"Moradabad"
citydist "Uttar Pradesh"	"Noida"	"Gautambudhnagar"
citydist "Uttar Pradesh"	"Varanasi"	"Varanasi"
citydist "West Bengal"	"Haldia"	"Medinipur"
citydist "West Bengal"	"Howrah"	"Howrah"
citydist "West Bengal"	"Kolkata"	"Kolkata"

************************************************************************
* closing steps
cap la var statecode "Unique numeric state identifier"
cap la var districtcode "Unique numeric district identifier"

* In datasets which have no variable for a certain geographic identifier (city, district, distcode, location) so for which we
*	 created an identifier which is always missing, drop that created identifier
count
loc temp = r(N)
count if district == ""
if r(N) == `temp' drop district 
count if distcode == ""
if r(N) == `temp' drop distcode
count if location == ""
if r(N) == `temp' drop location
count if city == ""
if r(N) == `temp' drop city
